# elocalibration.tcl.
# Provides for interactive calibration of elo touch screen.
# Execute as follows: wish8.4 elocalibration.tcl
# NOTE: this should run out of rcS, which calls /sbin/poweroff
# after completion.

set family helvetica
set big_font [font create -family $family -weight bold -size -16]
set huge_font [font create -family $family -weight bold -size -24]

proc eventloopStart {} {

        global forever;

        set forever 1;

        if {[info commands tk] != {}} {
            tkwait variable forever;
        } else {
            vwait forever;
        }

        return;
}

proc eventloopStop {} {

        global forever;

        set forever 0;

        return;
}

proc readCoordinates {fh} {

        global iteration;
        global values_x;
        global values_y;
	global xCenter yCenter;
	global huge_font;

        set iteration [expr $iteration + 1];

        if {[gets $fh line] > 0} {

                scan $line "%d, %d" x y;

		if {$iteration < 5} {
        		set values_x($iteration) $x;
                	set values_y($iteration) $y;
		} else {
                	scan $line "%d, %d" xCenter yCenter;
                        eventloopStop;
		}
        }

        switch $iteration {
                1 { place .label2 -x 530 -y 0 }
                2 { place .label2 -x 530 -y 450 }
                3 { place .label2 -x 10 -y 450 }
		4 { .label2 configure -text "X" -font $huge_font;
		    place .label2 -x 320 -y 240;
  		    .validate configure -text "To validate calibration, touch X in center"
  		    .info configure -text "If bad calibration, cal process will restart"
		  }
        }

}


proc calculateValues {} {

        global values_x;
        global values_y;
        global xCenter;      # from user touching center
        global yCenter;
        
        set xlow [expr ($values_x(1) + $values_x(4)) / 2]
        set xhigh [expr ($values_x(2) + $values_x(3)) / 2]

        set ylow [expr ($values_y(1) + $values_y(2)) / 2]
        set yhigh [expr ($values_y(3) + $values_y(4)) / 2]

        # determine touch screen coordinates for screen center
        
        set xTemp [expr ($xhigh - $xlow) / 2]
        set xCal [expr ($xTemp + $xlow)]
                        
        set yTemp [expr ($yhigh - $ylow) / 2]
        set yCal [expr ($yTemp + $ylow)]
                                        
        set calOk "true"

        # validate coordinates 0
        # second and fourth points are in corners
        if {$values_x(2) < 3000} {
            set calOk "false"
        }
        if {$values_y(2) < 3000} {
            set calOk "false"
        }
        if {$values_x(4) > 1000} {
            set calOk "false"
        }
        if {$values_y(4) > 1000} {
            set calOk "false"
        }
 
        # validate coordinates 1
        set errorRange 120
        if {$xCal < [expr ($xCenter - $errorRange)]} {
           set calOk "false"
        } elseif {$xCal > [expr ($xCenter + $errorRange)]} {
           set calOk "false"
        } elseif {$yCal < [expr ($yCenter - $errorRange)]} {
           set calOk "false"
        } elseif {$yCal > [expr ($yCenter + $errorRange)]} {
               set calOk "false"
        }
        
        puts "xCenter $xCenter" 
        puts "yCenter $yCenter" 
        puts "xCal $xCal" 
        puts "yCal $yCal" 
        
        puts $calOk 
        
        if {$calOk == "true"} {
          set conf [open "/etc/elotouch.conf" w]
          puts $conf {#!/bin/sh}
          puts $conf "export XLOW=$xlow"
          puts $conf "export XHIGH=$xhigh"
          puts $conf "export YLOW=$ylow"
          puts $conf "export YHIGH=$yhigh"
          close $conf
        }

        return $calOk;
}

set screenHeight [expr [lindex [wm maxsize .] 1] + 28]
set screenWidth [expr [lindex [wm maxsize .] 0] + 15]
set offset "-0-0"
wm geometry . "${screenWidth}x${screenHeight}${offset}"


label .label1 -text "Touchscreen Calibration"
.label1 configure -font $huge_font
pack .label1 -padx 50 -pady 150
label .label2 
label .validate -font $huge_font -text ""
place .validate -x 80 -y 300
label .info -font $huge_font -text ""
place .info -x 80 -y 350

set fh [open "|eloconfig -r 100" r];
fconfigure $fh -buffering line -blocking 0;
fileevent $fh readable [list readCoordinates $fh ];

set done "false"
while {$done == "false"} {
  . configure -cursor hand2
  .label2 configure -text "Press Corner" -font $big_font
  .validate configure -text "" 
  .info configure -text ""

  # get calibration values from corners
  set iteration 0

  # displays prompt at upper left corner
  place .label2 -x 0 -y 0

  eventloopStart;

  puts "$values_x(1) $values_y(1)";
  puts "$values_x(2) $values_y(2)";
  puts "$values_x(3) $values_y(3)";
  puts "$values_x(4) $values_y(4)";
  
  set done [calculateValues];
}

# eloconfig is still running, so poweroff
exit
