##############################################################################
#
# vc/src/tcl/autofarm.tcl
#
# Main AutoFarm screen --- used for row lineup and AutoSteer modes.
#
# 20020411 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop

    # title and field boundary indicator
    label .ftop.l1 -text "MANUAL STEERING"
    place .ftop.l1 -relx 0.25 -x -20 -y 10 -anchor n
    canvas .ftop.c1 -width 200 -height 20 -relief sunken \
            -borderwidth 1 -background orange
    .ftop.c1 create text 100 12 -font $small_font -anchor c -tag boundaryText
    place .ftop.c1 -relx 0.25 -x -20 -y 40 -anchor n

    # slider frames
    frame .ftop.s0
    pack .s0 -in .ftop.s0 -fill both -expand yes
    raise .s0
    place .ftop.s0 -x 15 -y 100 -anchor nw
    frame .ftop.sx       ;# frame for the optional second slider

    # cancel, setup, and field-boundary-alarm buttons
    SnazzyButton::create .ftop.cancel btnKhakiU btnKhakiD 0.5 \
        "beepOnce; post $DISP_BTN9_SIG 9" "Return to\nMain Menu"
    place .ftop.cancel -x 15 -rely 1.0 -y -10 -anchor sw            
    SnazzyButton::create .ftop.setup btnBlueM5U btnBlueM5D 0.5 \
        "beepOnce; post $DISP_BTN1_SIG 1" "Setup"
    SnazzyButton::create .ftop.alarm btnBlueM5U btnBlueM5D 0.5 \
        "beepOnce; post $DISP_BTN2_SIG 2" "Turn\nOff\nAlarm"
    SnazzyButton::create .ftop.lowacc btnBlueM5U btnBlueM5D 0.5 \
        "beepOnce; post $DISP_BTN3_SIG 3" "Accuracy:"
    SnazzyButton::create .ftop.futureuse btnBlueM5U btnBlueM5D 0.5 \
        "beepOnce; post $DISP_BTN4_SIG 4" "Future Use"

    # large and small nudges
    # we place all nudge widgets in a frame because we
    # need to easily take it off/on the screen to show controller data
    frame .ftop.nudges -width 320 -height 200
    place .ftop.nudges -relx 0.80 -y 10 -anchor n
    frame .ftop.data
    label .ftop.nudges.llarge -font $medium_font -text "Large Nudge" 
    place .ftop.nudges.llarge -relx 0.5 -y 20 -anchor n            
    label .ftop.nudges.elarge -text "10.0" -font $medium_font -width 12
    place .ftop.nudges.elarge -relx 0.5 -y 42 -anchor n            
    SnazzyButton::create .ftop.nudges.largeleft btnBigLeftNudgeU \
                     btnBigLeftNudgeD 0.5 "beepOnce; post $DISP_BTN8_SIG 0"
    place .ftop.nudges.largeleft -relx 0.5 -x -50 -y 40 -anchor e
    SnazzyButton::create .ftop.nudges.largeright btnBigRightNudgeU \
                     btnBigRightNudgeD 0.5 "beepOnce; post $DISP_BTN8_SIG 1"
    place .ftop.nudges.largeright -relx 0.5 -x 50 -y 40 -anchor w

    label .ftop.nudges.lsmall -font $medium_font -text "Small Nudge" 
    place .ftop.nudges.lsmall -relx 0.5 -y 90 -anchor n            
    label .ftop.nudges.esmall -text "1.0" -font $medium_font -width 10
    place .ftop.nudges.esmall -relx 0.5 -y 112 -anchor n            
    SnazzyButton::create .ftop.nudges.smallleft btnSmallLeftNudgeU \
               btnSmallLeftNudgeD 0.5 "beepOnce; post $DISP_BTN7_SIG 0"
    place .ftop.nudges.smallleft -relx 0.5 -x -60 -y 110 -anchor e
    SnazzyButton::create .ftop.nudges.smallright btnSmallRightNudgeU \
               btnSmallRightNudgeD 0.5 "beepOnce; post $DISP_BTN7_SIG 1"            
    place .ftop.nudges.smallright -relx 0.5 -x 60 -y 110 -anchor w

    # tractor display
    frame .ftop.td
    pack .tractorDisplay -in .ftop.td -fill both -expand yes
    raise .tractorDisplay
    place .ftop.td -relx 0.80 -rely 1.0 -anchor s 
    
    # STOP/GO buttons
    label .ftop.lstopgo -text "STOP\nAUTOSTEER" -font $big_font
    place .ftop.lstopgo -relx 0.5 -rely 1.0 -y -170 -anchor n
    SnazzyButton::create .ftop.stop btnBigStopU btnBigStopD 0.5 \
                    "beepOnce; post $DISP_BTN0_SIG 0"
    SnazzyButton::create .ftop.go btnBigGoU btnBigGoD 0.5 \
                    "beepOnce; post $DISP_BTN0_SIG 1"                

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {cancelBtn setupBtn largeNudgeLbl largeNudge \
            smallNudgeLbl smallNudge alarmBtn } {
        SnazzyButton::setText .ftop.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.setup $setupBtn 0.5
        SnazzyButton::setText .ftop.alarm $alarmBtn 0.5                
        .ftop.nudges.llarge configure -text $largeNudgeLbl
        .ftop.nudges.elarge configure -text $largeNudge
        .ftop.nudges.lsmall configure -text $smallNudgeLbl
        .ftop.nudges.esmall configure -text $smallNudge

        pack .ftop -fill both -expand yes
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr

    proc actConfigureSecondSlider { sliderNum } {
        place forget .ftop.s0
        place forget .ftop.sx
        pack .s$sliderNum -in .ftop.sx -fill both -expand yes
        raise .s$sliderNum
        place .ftop.s0 -x 15 -y 80 -anchor nw
        place .ftop.sx -x 15 -y 180 -anchor nw
    }

    proc actConfigureAlarmBtn { } {
        place .ftop.alarm -x 130 -rely 1.0 -y -125 -anchor sw
    }
    
    proc actConfigureLowAccBtn { } {
        place .ftop.lowacc -x 130 -rely 1.0 -y -60 -anchor sw
    }

    proc actToggleAccuracyMode {toggleBtn} {
        SnazzyButton::setText .ftop.lowacc $toggleBtn 0.5        
    }

    proc actRemoveAlarmBtn { } {
        place forget .ftop.alarm
    }
    
    proc actFieldBoundary { color text } {
        .ftop.c1 configure -background $color
        .ftop.c1 itemconfigure boundaryText -text $text
    }

    proc actConfigureRowlineup { beginLbl manualLbl manualSteeringText \
                                 lowAccEna } {
        place forget .ftop.stop
        .ftop.lstopgo configure -text $beginLbl
        .ftop.l1 configure -text $manualLbl
        place .ftop.go -relx 0.5 -rely 1.0 -y -10 -anchor s            
        place .ftop.setup -x 15 -rely 1.0 -y -125 -anchor sw
        if {$lowAccEna == "1"} {            
          place .ftop.lowacc -x 130 -rely 1.0 -y -60 -anchor sw
        }
        TractorDisplay::actConfigureRowlineup $manualSteeringText
    }

    proc actConfigureAutosteer { stopLbl autoLbl } {
        place forget .ftop.go
        place forget .ftop.setup
        place forget .ftop.lowacc
        .ftop.lstopgo configure -text $stopLbl
        .ftop.l1 configure -text $autoLbl
        place .ftop.stop -relx 0.5 -rely 1.0 -y -10 -anchor s            
        TractorDisplay::actConfigureAutosteer
    }

    proc actConfigTractorIcon { tractorType__ tractorColor__ \
            implWidth__ implOffset__} {
        # Delegate to the .tractorDisplay component
        TractorDisplay::actConfigTractorIcon \
                $tractorType__ $tractorColor__ $implWidth__ $implOffset__
    }

    proc actVehicleDispData { velDispText__ Vx__ VxMax__ \
            headingError__ posError__ \
            passWidth__ fanAngle__ rowNumText__ nudgeDistText__ \
            turboMessageText__ ENHANCED_RLM__ \
            ERLM_HE_ENTER__ ERLM_HE_EXIT__ \
            ERLM_YC_ENTER__ ERLM_YC_EXIT__ \
            inTightMode__} {

        # Delegate to the .tractorDisplay component
        TractorDisplay::actVehicleDispData $velDispText__ $Vx__ $VxMax__ \
                $headingError__ $posError__ $passWidth__ $fanAngle__ \
                $rowNumText__ $nudgeDistText__ \
                $turboMessageText__ $ENHANCED_RLM__ $ERLM_HE_ENTER__ \
                $ERLM_HE_EXIT__ $ERLM_YC_ENTER__ $ERLM_YC_EXIT__ \
                $inTightMode__
    }

    proc actSteerCodeDisp { turningWheelText__ killText__ clutchText__ \
            parkText__ resetReqText__ roadingText__ comsBadText__ \
            notReadyText__ inxUnsText__ } {

        # Delegate to the .tractorDisplay component
        TractorDisplay::actSteerCodeDisp $turningWheelText__ $killText__ \
                $clutchText__ $parkText__ $resetReqText__ $roadingText__ \
                $comsBadText__ $notReadyText__ $inxUnsText__
    }

    proc actMarkPixels { xPixels yPixels xStart yStart xEnd yEnd } {
        # Delegate to the .tractorDisplay component
        TractorDisplay::actMarkPixels $xPixels $yPixels \
                $xStart $yStart $xEnd $yEnd
    }

    proc actSurveyMarkPixels { xPixels yPixels northID eastID } {
        # Delegate to the .tractorDisplay component
        TractorDisplay::actSurveyMarkPixels $xPixels $yPixels $northID $eastID
    }

    proc actSliderValue { sliderNum val notch } {
        Sliders::actSliderValue $sliderNum $val $notch
    }
    
    proc actConfigureData { } {
        place forget .ftop.nudges
        pack .contDataDisplay -in .ftop.data -side bottom -fill both -expand yes
        raise .contDataDisplay
        place .ftop.data -relx 1.0 -x -20 -y 10 -anchor ne
    }

    proc actRemoveData { } {
        place forget .ftop.data
        place .ftop.nudges -relx 0.80 -y 10 -anchor n
    }

    proc actPlotContData { } {
        ContDataDisplay::actPlotContData
    }

    proc actConfigureContDataMsg { msg__ } {
        ContDataDisplay::actConfigureContDataMsg $msg__
    }
    
}
