#############################################################################
#
# vc/src/tcl/commonobjects.tcl
#
# Defines various common display objects (i.e. Tk frame) objects that can be 
# packed into various screens, e.g. the Navigation frame, the Configuration 
# frame, the Tractor frame, the Calibration frame, etc.
#
# 20020327 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################



#=============================================================================
# .cutFillDisp
#
# The cutfill-data display. 
#=============================================================================
namespace eval CutFillDisp {

    # define the containing frame
    frame .cutFillDisp

    # define the canvas
    canvas .cutFillDisp.c -width 400 -height 400 -relief sunken \
            -borderwidth 1 -background white
    pack .cutFillDisp.c -side bottom -anchor s

    # bind <ButtonPress-1> to DISP_CANVAS1_SIG to enable record on/off
    #bind .cutFillDisp.c <ButtonPress-1> { beepOnce; post $DISP_CANVAS1_SIG 0 }

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Grade info
    .cutFillDisp.c create rectangle 0 0 150 65 \
         -fill gray85  -tags {cdInfo area1b}
    .cutFillDisp.c create text 10  12 -text "Grade Points:"\
        -font $medium_font -anchor w -tags {cdInfo gradePointTag}
    .cutFillDisp.c create text 110 12 -text "--"\
        -font $medium_font -anchor w -tags {cdInfo gradePoints}
    .cutFillDisp.c create text 10 27 -text "North Tower:"\
        -font $medium_font -anchor w -tags {cdInfo northTowerTag}
    .cutFillDisp.c create text 110 27 -text ""\
        -font $medium_font -anchor w -tags {cdInfo northTowerPos}
    .cutFillDisp.c create text 10 42 -text "East Tower:"\
        -font $medium_font -anchor w -tags {cdInfo eastTowerTag}
    .cutFillDisp.c create text 110 42 -text ""\
        -font $medium_font -anchor w -tags {cdInfo eastTowerPos}
    # make the area active.  This must come last to create proper Z order
    .cutFillDisp.c create rectangle 0 0 150 65 \
        -fill "" -outline "" -tags {cdInfo area1}
    .cutFillDisp.c bind area1 <ButtonPress-1> \
        { beepOnce; post $DISP_CANVAS1_SIG 1 }



#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Fall info
    # row 1
    .cutFillDisp.c create rectangle 245 0 400 65 \
        -fill "" -fill gray85  -tags {cdInfo area0b}
    .cutFillDisp.c create text 250 12 -text "Slope Mode"\
        -font $medium_font -anchor w -tags {cdInfo slopeModeTag}
    .cutFillDisp.c create text 360 12 -text ""\
        -font $medium_font -anchor w -tags {cdInfo slopeMode}

    # row 2
    .cutFillDisp.c create text 250 27 -text "Fall Angle:"\
        -font $medium_font -anchor w -tags {cdInfo mainFallAngleTag}
    .cutFillDisp.c create text 330 27 -text "--"\
        -font $medium_font -anchor w -tags {cdInfo mainFallAngle}

    # row 3
    .cutFillDisp.c create text 250 42 -text "North Fall:"\
        -font $medium_font -anchor w -tags {cdInfo mainFallTag}
    .cutFillDisp.c create text 330 42 -text "--"\
        -font $medium_font -anchor w -tags {cdInfo mainFall}

    # row 4
    .cutFillDisp.c create text 250 57 -text "East Fall:"\
        -font $medium_font -anchor w -tags {cdInfo sideFallTag}
    .cutFillDisp.c create text 330 57 -text "--"\
        -font $medium_font -anchor w -tags {cdInfo sideFall}

    # make the area active.  This must come last to create proper Z order
    .cutFillDisp.c create rectangle 245 0 400 65 \
        -fill "" -outline "" -tags {cdInfo area0}
    .cutFillDisp.c bind area0 <ButtonPress-1> \
        { beepOnce; post $DISP_CANVAS1_SIG 0 }

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Vehicle Position
    .cutFillDisp.c create text 10 350 -text "North:"\
        -font $huge_font -anchor w -tags {cdInfo northGridTag}
    .cutFillDisp.c create text 90 350 -text "--"\
        -font $huge_font -anchor w -tags {cdInfo northGrid}
    .cutFillDisp.c create text 10 385 -text "East"\
        -font $huge_font -anchor w -tags {cdInfo eastGridTag}
    .cutFillDisp.c create text 90 385 -text "--"\
        -font $huge_font -anchor w -tags {cdInfo eastGrid}
#    .cutFillDisp.c create text 90 385 -text "--"\
\#        -font $huge_font -anchor w -tags {cdInfo eastGrid}

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Sat info
    .cutFillDisp.c create text 220 350 -text "Blade Sats:"\
        -font $huge_font -anchor w -tags {cdInfo bladeSatsTag}
    .cutFillDisp.c create text 360 350 -text "--"\
        -font $huge_font -anchor w -tags {cdInfo bladeSats}
    .cutFillDisp.c create text 220 385 -text "Base Sats:"\
        -font $huge_font -anchor w -tags {cdInfo baseSatsTag}
    .cutFillDisp.c create text 360 385 -text "--"\
        -font $huge_font -anchor w -tags {cdInfo baseSats}

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Blade offset
    .cutFillDisp.c create text 155 220 -text ""\
        -font $huge_font -anchor w -tags {cdInfo bladeOffset}
    .cutFillDisp.c create rectangle 100 200 300 250 \
        -fill "" -outline "" -tags {cdInfo area2}
    .cutFillDisp.c bind area2 <ButtonPress-1> \
        { beepOnce; post $DISP_CANVAS1_SIG 2 }

    # Other text
    .cutFillDisp.c create text 200 160 -text ""\
        -font $big_font  -anchor c -tags {cdInfo msgText}

    .cutFillDisp.c create text 200 140 -text ""\
        -font $huge_font  -anchor c -tags {cdInfo alertText}

    .cutFillDisp.c create text 200 7 -text "N"\
        -font $tiny_font  -anchor c -tags {cdInfo compassNorth}

    .cutFillDisp.c create text 240 50 -text "E"\
        -font $tiny_font  -anchor c -tags {cdInfo compassNorth}

    .cutFillDisp.c create text 160 50 -text "W"\
        -font $tiny_font  -anchor c -tags {cdInfo compassNorth}


    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Graphics drawing procs
    proc actDrawJunkTcl {} {
        global big_font small_font tiny_font
        source /tmp/junk.tcl
    }

    proc actDrawThis {script__} {
        global big_font small_font tiny_font
        eval $script__
    }

    proc actConfigGradeFloat { left__ bottom__ right__ top__ } {
        .cutFillDisp.c coords cdFloatBar $left__ $bottom__ $right__ $top__
    }

    proc actDrawFallArrow { left__ bottom__ right__ top__ } {
        .cutFillDisp.c coords fallArrow $left__ $bottom__ $right__ $top__
    }

    proc actDrawHeadingArrow { left__ bottom__ right__ top__ } {
        .cutFillDisp.c coords headingArrow $left__ $bottom__ $right__ $top__
    }


    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Text update procs
    proc actShowAlert {  msgText__  } {
       .cutFillDisp.c itemconfigure alertText -text $msgText__ -fill "Red"
    }

    proc actShowMsg {  msgText__  } {
       .cutFillDisp.c itemconfigure msgText -text $msgText__ -fill "Black"
    }

    proc actFallDataDisp { mainFallAngle__   mainFall__ sideFall__} {
        .cutFillDisp.c itemconfigure mainFallAngle -text $mainFallAngle__
        .cutFillDisp.c itemconfigure mainFall -text $mainFall__
        .cutFillDisp.c itemconfigure sideFall -text $sideFall__
    }

    proc actNumSats { numBase__ baseColor__ numRover__ roverColor__ } {
	.cutFillDisp.c itemconfigure baseSats -text $numBase__ -fill $baseColor__
	.cutFillDisp.c itemconfigure bladeSats -text $numRover__ -fill $roverColor__
    }

    proc actGradePointDisp { gradePointTag__ gradePoints__ } {
        .cutFillDisp.c itemconfigure gradePointTag -text $gradePointTag__
        .cutFillDisp.c itemconfigure gradePoints -text $gradePoints__
    }

    proc actBladeOffsetDisp { bladeOffset__ color__} {
        .cutFillDisp.c itemconfigure bladeOffset -text $bladeOffset__ -fill $color__
    }

    proc actDualFallDataDisp { mainFallAngle__  mainFall__ sideFall__} {

        .cutFillDisp.c itemconfigure mainFallAngle -text $mainFallAngle__
        .cutFillDisp.c itemconfigure mainFall -text $mainFall__
        .cutFillDisp.c itemconfigure sideFall -text $sideFall__
    }

    proc actAlignedFallDataDisp { mainFallAngle__   fieldAngle__ mainFall__} {

        .cutFillDisp.c itemconfigure mainFallAngle -text $mainFallAngle__
	.cutFillDisp.c itemconfigure sideFall      -text $fieldAngle__
        .cutFillDisp.c itemconfigure mainFall      -text $mainFall__
    }

    proc actGridDataDisp { northGridTag__ northGrid__   eastGridTag__ eastGrid__ } {

        .cutFillDisp.c itemconfigure northGridTag -text $northGridTag__
        .cutFillDisp.c itemconfigure northGrid -text $northGrid__
        .cutFillDisp.c itemconfigure eastGridTag -text $eastGridTag__
        .cutFillDisp.c itemconfigure eastGrid -text $eastGrid__
    }



    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~Mode config procs
    proc actConfigureAlignedSlope { } {
	.cutFillDisp.c itemconfigure mainFallTag -text "Main Fall"
	.cutFillDisp.c itemconfigure sideFallTag -text ""
	.cutFillDisp.c itemconfigure sideFall -text ""
    }

    proc actConfigureDualSlope { } {
	.cutFillDisp.c itemconfigure mainFallTag -text "North Fall"
	.cutFillDisp.c itemconfigure sideFallTag -text "East Fall"
    }

    proc actConfigureLaserGradeMode { northTag__ northLocation__ eastTag__ eastLocation__} {
	.cutFillDisp.c itemconfigure northTowerTag -text $northTag__ 
	.cutFillDisp.c itemconfigure northTowerPos -text $northLocation__ 
	.cutFillDisp.c itemconfigure eastTowerTag -text  $eastTag__ 
	.cutFillDisp.c itemconfigure eastTowerPos -text  $eastLocation__
    }

    proc actConfigureGPSGradeMode { } {
	.cutFillDisp.c itemconfigure northTowerTag -text ""
	.cutFillDisp.c itemconfigure eastTowerTag -text ""
	.cutFillDisp.c itemconfigure northTowerPos -text ""
	.cutFillDisp.c itemconfigure eastTowerPos -text ""
    }

    proc actConfigureAlignedSlopeMode { mainFall__ fallAngle__ fieldAngle__ slopeMode__} {
	.cutFillDisp.c itemconfigure sideFallTag      -text $fieldAngle__
	.cutFillDisp.c itemconfigure sideFall         -text ""
	.cutFillDisp.c itemconfigure mainFallTag      -text $mainFall__
	.cutFillDisp.c itemconfigure mainFallAngleTag -text $fallAngle__
	.cutFillDisp.c itemconfigure slopeModeTag     -text $slopeMode__
    }

    proc actConfigureDualSlopeMode { mainFall__ sideFall__ fallAngle__ slopeMode__} {
	.cutFillDisp.c itemconfigure sideFallTag -text $sideFall__
	.cutFillDisp.c itemconfigure mainFallTag -text $mainFall__
	.cutFillDisp.c itemconfigure mainFallAngleTag -text $fallAngle__
	.cutFillDisp.c itemconfigure slopeModeTag -text $slopeMode__
    }

}



namespace eval AutoLevelImages { 
    # Up arrows
    image create photo bigUpNudgeD -format gif -file ${tclPath}gif/btnBigIncreaseNudgeD.gif
    image create photo UpNudgeD -format gif   -file ${tclPath}gif/btnBigIncreaseNudgeD.gif
    image create photo bigUpNudgeU -format gif \
            -file ${tclPath}gif/btnBigIncreaseNudgeU.gif
    image create photo UpNudgeU -format gif \
            -file ${tclPath}gif/btnBigIncreaseNudgeU.gif
#${tclPath}gif/arrow_up.gif

    #Down arrows
    image create photo bigDownNudgeU -format gif \
            -file ${tclPath}gif/btnBigDecreaseNudgeU.gif
    image create photo bigDownNudgeD -format gif \
            -file ${tclPath}gif/btnBigDecreaseNudgeU.gif
    image create photo downNudgeD -format gif \
            -file ${tclPath}gif/btnBigDecreaseNudgeD.gif
    image create photo downNudgeU -format gif \
            -file ${tclPath}gif/btnBigDecreaseNudgeU.gif
#           -file ${tclPath}gif/arrow_down.gif
}




#=============================================================================
# .CalibrationDataDisp
#
# The calibration-data display. 
#=============================================================================
namespace eval  CalibrationDataDisp {

    # define the containing frame
    frame .calibrationDataDisp

    # define the canvas
    canvas .calibrationDataDisp.data -width 400 -height 300 -relief sunken \
            -borderwidth 2 -background gray85
    pack .calibrationDataDisp.data -side bottom -anchor s

    proc actDrawThis {script__} {
        global big_font small_font tiny_font
        eval $script__
    }
}

#=============================================================================
# .CalibrationTimeLineDisp
#
# The calibration-timeline display. 
#=============================================================================
namespace eval  CalibrationTimeLineDisp {

    # define the containing frame
    frame .calibrationTimeLineDisp

    # define the canvas
    canvas .calibrationTimeLineDisp.c -width 400 -height 100 -relief sunken \
            -borderwidth 2 -background gray85
    pack .calibrationTimeLineDisp.c -side bottom -anchor s

    proc actDrawThis {script__} {
        global big_font small_font tiny_font
        eval $script__
    }
}
