##############################################################################
#
# vc/src/tcl/databasediff.tcl
#
# Screen to show database diff.
#
# 20040802 QC - created
#
# Copyright (c) 2004 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Database Compare"
    label .ftop.subtitle -font $big_font -text \
               [format "%-41s %-25s %-20s" "Param Name" "Current" "Default"]     

    frame .ftop.input
    scrollbar .ftop.input.sbar -orient vertical -width 40 \
                -command [list .ftop.input.txt yview] 
    text .ftop.input.txt -width 64 -height 14 -font $big_font \
                -tabs {3.5i 5.5i} \
                -yscrollcommand [list .ftop.input.sbar set]

    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel \
                 btnKhakiForSatVUU btnKhakiForSatVUD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To Previous Menu"
        
    pack .ftop.input2.cancel -side left

    # Pack .ftop
    pack .ftop.title -side top -pady 10
    pack .ftop.subtitle -side top -padx 10 -anchor sw
    pack .ftop.input -side top -padx 10
    pack .ftop.input2 -side bottom -anchor sw -padx 5 -pady 5
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { titleLbl returnBtn } {
        .ftop.title configure -text $titleLbl
        SnazzyButton::setText .ftop.input2.cancel $returnBtn 0.5
 
        # Pack the list box
        pack .ftop.input.txt -side left -fill both
        pack .ftop.input.sbar -side left -fill y

        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actListboxInsert { paramName currentValue defaultValue } {
        .ftop.input.txt insert end  \
       [format "%s\t%-11.6f\t%-9.6f\n" $paramName $currentValue $defaultValue]
    }

    proc actNoDiff { msg } {
        .ftop.input.txt insert end $msg
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
