##############################################################################
#
# vc/src/tcl/fieldboundary.tcl
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop
    
    # NOTE: using place for positioning imported frames (-in option)
    #       craches Tcl interpreter. Therefore pack must be used.
    pack .configDisplay -in .ftop -side left \
            -anchor n -padx 10 -pady 10
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor n -padx 10 -pady 10
    raise .navDisplay

    label .ftop.title -text "Choose points along boundary"
    place .ftop.title -relx 0.5 -rely 0.3 -anchor n

    set canvasX 250
    set canvasY 250
    SnazzyButton::create .ftop.b0 btnRedM2U btnRedM2D 0.5 \
                         "beepOnce; post $DISP_BTN0_SIG 0" "Cancel\nBoundary"
    place .ftop.b0 -relx 1.0 -x -20 -rely 0.41 -anchor ne            
    SnazzyButton::create .ftop.b1 btnBlueM2U btnBlueM2D 0.5 \
             "beepOnce; post $DISP_BTN1_SIG 1" "Finished"
    place .ftop.b1 -relx 1.0 -x -20 -rely 0.41 -y [expr $canvasY/2] -anchor e
    SnazzyButton::create .ftop.b2 btnBlueM2U btnBlueM2D 0.5 \
              "beepOnce; post $DISP_BTN2_SIG 2" "Pick\nPoint"           
    place .ftop.b2 -relx 1.0 -x -20 -rely 0.41 -y $canvasY -anchor se            

    canvas .ftop.c -width $canvasX -height $canvasY \
                   -relief sunken -borderwidth 1
                   
    place .ftop.c -relx 1.0 -x -120 -rely 0.4 -anchor ne            

    label .ftop.l1 -text "North:" -font $big_font
    place .ftop.l1 -x 15 -rely 0.4 -anchor nw
    label .ftop.e1 -text "xx" -font $big_font -anchor w \
                -width 18 -relief sunken -borderwidth 2
    place .ftop.e1 -x 260 -rely 0.4 -anchor ne

    label .ftop.l2 -text "East:" -font $big_font
    place .ftop.l2 -x 15 -rely 0.4 -y 35 -anchor nw
    label .ftop.e2 -text "xx" -font $big_font -anchor w \
                -width 18 -relief sunken -borderwidth 2
    place .ftop.e2 -x 260 -rely 0.4 -y 35 -anchor ne

    label .ftop.l3 -text "Number of Corners:\n(Maximum 200)" \
          -font $big_font
    place .ftop.l3 -x 15 -rely 0.4 -y 60 -anchor nw
    label .ftop.e3 -text "xx" -font $big_font -anchor w \
                -width 6 -relief sunken -borderwidth 2
    place .ftop.e3 -x 260 -rely 0.4 -y 70 -anchor ne 
    label .ftop.l4 -text "Area:" -font $big_font
    place .ftop.l4 -x 15 -rely 0.4 -y 105 -anchor nw
    label .ftop.e4 -text "xx" -font $big_font -anchor w \
                -width 18 -relief sunken -borderwidth 2
    place .ftop.e4 -x 260 -rely 0.4 -y 105 -anchor ne

    SnazzyButton::create .ftop.cancel btnKhakiU btnKhakiD 0.5 \
                  "beepOnce; post $DISP_BTN9_SIG 9" "Cancel\nField"
    place .ftop.cancel -x 15 -rely 0.42 -y $canvasY -anchor sw            

# add this back when/if we are ready to support multiple zones
#    SnazzyButton::create .ftop.zones btnBlueU btnBlueD 0.5 \
\#              "beepOnce; post $DISP_BTN8_SIG 2" "Edit\nZones"           
#    place .ftop.zones -x 155 -rely 0.42 -y $canvasY -anchor sw

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {titleLbl northLbl eastLbl cancelBtn pickBtn\
                   finishedBtn cancelBoundaryBtn pointsLbl areaLbl} {

        global huge_font big_font colorGood color3 color0
        
        .ftop.title configure -text $titleLbl -font $huge_font

        .ftop.l1 configure -text $northLbl
        .ftop.l2 configure -text $eastLbl
        .ftop.l3 configure -text $pointsLbl
        .ftop.l4 configure -text $areaLbl
        SnazzyButton::setText .ftop.cancel $cancelBtn 0.5
#        .ftop.cancel configure -text $cancelBtn
        
        SnazzyButton::setText .ftop.b0 $cancelBoundaryBtn 0.5
        SnazzyButton::setText .ftop.b1 $finishedBtn 0.5
        SnazzyButton::setText .ftop.b2 $pickBtn 0.5
#        .ftop.b0 configure -text $cancelBoundaryBtn \
#                -background $color0 -activebackground $color0
#        .ftop.b1 configure -text $finishedBtn \
#                -background $color3 -activebackground $color3
#        .ftop.b2 configure -text $pickBtn \
#                -background $color3 -activebackground $color3
        .ftop.e3 configure -text "0"
                
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    proc actDisplayPosition {north east} {
        .ftop.e1 configure -text $north
        .ftop.e2 configure -text $east
    }

    proc clearField {} {
        .ftop.e3 configure -text 0
        .ftop.e4 configure -text 0
        catch {.ftop.c delete field}
    }

    proc actAddPoint {n x y area} {
        if {$n == 1} {
           catch {.ftop.c delete field}
           .ftop.c create polygon $x $y \
                   -fill green -outline black -tags field
        } else {
           .ftop.c insert field 0 "$x $y"
        }
        .ftop.e3 configure -text $n
        .ftop.e4 configure -text $area
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    #-------------------------------------------------------------------------

}
