##############################################################################
#
# vc/src/tcl/rmRcvrTypeCheck.tcl
#
# Roof Module Receiver Type Checking
#
# 20051017 SSJ - created
#
# Copyright (c) 2005 Novariant Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames
    # components) 
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

    # Display Frame - displays up to 3 lines of text
    label .ftop.display.l0 \
                -text "Verifying System's AutoLevel Capability" \
                -font $huge_font
    label .ftop.display.l1 -text " " \
                           -font $medium_font
    #label .ftop.display.l2 -text " " \
    #                       -font $medium_font
    #label .ftop.display.l3 -text " " \
    #                       -font $big_font

    # Input frame 
    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.b0 btnBlueU btnBlueD 0.2 \
                         "beepOnce; post $DISP_BTN0_SIG 0"

    #SnazzyButton::create .ftop.input.r1.b1 btnAcceptU btnAcceptD 0.2 \
    #                     "beepOnce; post $DISP_BTN1_SIG 1"
    # Exit button
    SnazzyButton::create .ftop.input.exit btnKhakiU btnKhakiD 0.2 \
                         "beepOnce; post $DISP_BTN9_SIG 9"

    # Pack the display and input frames
    pack .ftop.display.l0 -side top -pady 5 -fill both -expand yes
    pack .ftop.display.l1 -side top -pady 5 -fill both -expand yes
    #pack .ftop.display.l2 -side top -pady 5 -fill both -expand yes
    #pack .ftop.display.l3 -side top -pady 5 -fill both -expand yes
    pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw
    pack .ftop.input.r1 -side bottom -anchor se
    pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
    #pack .ftop.input.r1.b1 -side right

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { commLbl } {
		global big_font

        .ftop.display.l1 configure -text $commLbl -font $big_font
		.ftop.input.exit configure -state disabled
		.ftop.input.r1.b0 configure -state disabled
		#.ftop.input.r1.b1 configure -state disabled
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }


    proc actDispInfoStrg { infoLbl } {
		global big_font
	
        .ftop.display.l1 configure -text $infoLbl -font $big_font
    }

    proc actShowReturnBtn {} {
        pack forget .ftop.input.r1.b0

		.ftop.input.exit configure -state normal
        SnazzyButton::setText .ftop.input.exit "Return to\nPrevious\nMenu" 0.5
    }

    proc actShowOkBtn {} {
        pack forget .ftop.input.exit

		.ftop.input.r1.b0 configure -state normal
        SnazzyButton::setText .ftop.input.r1.b0 "Ok" 0.5
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
