##############################################################################
#
# vc/src/tcl/satvu.tcl
#
# SatVU screen
#
# 20040114 QC - created
#
# Copyright (c) 2004 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in Exit

    frame .ftop
    
    frame .ftop.display
    
    label .ftop.display.l \
           -text "Predicting GPS sensor performance" \
           -font $huge_font
    set canvasWidth 610 
    set canvasHeight 300
    set flipVdop 1
    set colorVdop #ff7070
    set timeStepMinutes 5
    
    set canvasCenterX 100
    set canvasCenterY 100
    
    canvas .ftop.display.c -width $Screen::canvasWidth \
                           -height $Screen::canvasHeight \
           -relief sunken -borderwidth 1 -background $color6
    bind .ftop.display.c <ButtonRelease-1> { set Screen::canvasCenterX %x; \
                                           set Screen::canvasCenterY %y; \
                        set myCursor [list @${tclPath}nocursor "black"]; \
                        . configure -cursor $myCursor; \
                                  post $DISP_BTN6_SIG $Screen::canvasCenterX;}      

    bind .ftop.display.c <ButtonPress-1> {. configure -cursor sb_down_arrow;}

    pack .ftop.display.l -side top
    pack .ftop.display.c -side top
    pack .ftop.display -side top
    
    frame .ftop.input
    pack .ftop.input -side bottom -padx 5 -pady 5 -fill both -expand yes
    
    frame .ftop.input.c5
    SnazzyButton::create .ftop.input.c5.exit btnRedForSatVUU btnRedForSatVUD 0.5 \
           "beepOnce; post $DISP_BTN9_SIG 9;" "Exit"
    pack .ftop.input.c5.exit -side left
    pack .ftop.input.c5 -side left -anchor sw

    frame .ftop.input.c3
    SnazzyButton::create .ftop.input.c3.dayup btnBlueForSatVUU \
           btnBlueForSatVUD 0.5 "beepOnce; post $DISP_BTN3_SIG 3;" "Day +"   
    pack .ftop.input.c3.dayup -side right
    pack .ftop.input.c3 -side right -anchor se    

    frame .ftop.input.c4
    SnazzyButton::create .ftop.input.c4.daydown btnBlueForSatVUU \
           btnBlueForSatVUD 0.5 "beepOnce; post $DISP_BTN4_SIG 4;" "Day -"    
    pack .ftop.input.c4.daydown -side right -padx 5
    pack .ftop.input.c4 -side right -anchor se    

    frame .ftop.input.c2
    frame .ftop.input.c2.r2
    label .ftop.input.c2.r2.l0 -text "Lat: 0.00" -font $medium_font
    label .ftop.input.c2.r2.l1 -text "Lon: 0.00" -font $medium_font
    pack .ftop.input.c2.r2.l0 -side top -pady 0
    pack .ftop.input.c2.r2.l1 -side top -pady 0
    pack .ftop.input.c2.r2 -side top -pady 0

    frame .ftop.input.c2.r3
    label .ftop.input.c2.r3.l0 -text "Elevation Mask: 15 degrees" \
                               -font $medium_font
    pack .ftop.input.c2.r3.l0 -side top    
    pack .ftop.input.c2.r3 -side top    

    frame .ftop.input.c2.r1
    label .ftop.input.c2.r1.l0 -text "Today: 00 00 0000" -foreground magenta \
                               -font $medium_font
    pack .ftop.input.c2.r1.l0 -side top   
    pack .ftop.input.c2.r1 -side top   
    pack .ftop.input.c2 -side bottom -fill x

    set sky_size 380
    set sky_r [expr $sky_size/2]
    set pi [expr 2*asin(1)]

    frame .ftop.trackstat
    label .ftop.trackstat.title -text "Skyplot for" -font $huge_font
    canvas .ftop.trackstat.skyplot -width $sky_size \
       -height $sky_size -background $color6
    label .ftop.trackstat.l -text \
       "Press on any part of the map to return to SatVU" -font $medium_font

    bind .ftop.trackstat.skyplot <ButtonRelease-1> {post $DISP_BTN5_SIG 5;}

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {elevmaskLbl elevmask dayLbl degLbl exitBtn} {
      .ftop.input.c2.r3.l0 configure -text "$elevmaskLbl: $elevmask $degLbl"
      SnazzyButton::setText .ftop.input.c3.dayup "$dayLbl +" 0.5
      SnazzyButton::setText .ftop.input.c4.daydown "$dayLbl -" 0.5
      SnazzyButton::setText .ftop.input.c5.exit $exitBtn 0.5
      pack .ftop -fill both -expand yes
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {

        destroy .ftop

    }
   
    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr
    proc packSkyplot {titleLbl curYear curMon curDay curHour curMin curSec} {
      global Screen::sky_r Screen::pi
      pack forget .ftop.display
      pack forget .ftop.input

      .ftop.trackstat.title configure -text \
        "$titleLbl $curMon $curDay $curYear $curHour:$curMin:$curSec"
      pack .ftop.trackstat.title -side top -padx 10
      pack .ftop.trackstat.l -side bottom
      pack .ftop.trackstat.skyplot -side bottom -padx 20
      pack .ftop.trackstat -side top -fill both -expand yes

      plotcirc $Screen::sky_r
      plotcirc [expr 2*$Screen::sky_r/3]
      plotcirc [expr $Screen::sky_r/3]

      polplotline 0
      polplotline $Screen::pi/4
      polplotline $Screen::pi/2
      polplotline 3*$Screen::pi/4
      
    }

    proc clearPol {} {
      foreach id [.ftop.trackstat.skyplot find all] {
         .ftop.trackstat.skyplot delete $id
      }
      plotcirc $Screen::sky_r
      plotcirc [expr 2*$Screen::sky_r/3]
      plotcirc [expr $Screen::sky_r/3]

      polplotline 0
      polplotline $Screen::pi/4
      polplotline $Screen::pi/2
      polplotline 3*$Screen::pi/4
    }

    proc polplot {sv az el} {
        global Screen::pi Screen::sky_r
        .ftop.trackstat.skyplot create text \
         [expr $Screen::sky_r + $Screen::sky_r*($Screen::pi/2-$el)/$Screen::pi*2*sin($az)] \
         [expr $Screen::sky_r - $Screen::sky_r*($Screen::pi/2-$el)/$Screen::pi*2*cos($az)] \
         -text $sv -font small_font 
    }

    proc plotcirc {r} {
        .ftop.trackstat.skyplot create oval \
        [expr $Screen::sky_r-$r+2] [expr $Screen::sky_r-$r+2] \
        [expr $Screen::sky_r + $r] [expr $Screen::sky_r + $r] -outline blue
    }

    proc polplotline {ang} {
        .ftop.trackstat.skyplot create line \
          [expr $Screen::sky_r - $Screen::sky_r*sin($ang)] \
          [expr $Screen::sky_r - $Screen::sky_r*cos($ang)] \
          [expr $Screen::sky_r + $Screen::sky_r*sin($ang)] \
          [expr $Screen::sky_r + $Screen::sky_r*cos($ang)] -fill blue
    }

    proc pleaseStandBy {infoLbl} {
      global Screen::standByMode
      global huge_font
      clearCanvas .ftop.display.c

      .ftop.display.c create text 300 150 -font $huge_font \
           -text $infoLbl
    }

    proc packSatvu {} {

      clearCanvas .ftop.trackstat.skyplot
      pack forget .ftop.trackstat
      
      pack .ftop.display -side top
      pack .ftop.input -side bottom -padx 5 -pady 5 -fill both -expand yes
     
    }

    proc almDownloadFailed {} {
      global huge_font
      clearCanvas .ftop.display.c
      .ftop.display.c create text 300 150 -font $huge_font \
           -text "Almanac downloading failed, please examine GPS"
    }

    proc configTitle {titleLbl curYear curMonth curDay} {
      .ftop.display.l configure -text \
                    "$titleLbl $curMonth $curDay $curYear"
    }

    proc actConfigDateTimeLbl {dayLbl datetime} {
      .ftop.input.c2.r1.l0 configure -text "$dayLbl: $datetime"
    }

    proc actConfigLatLonLbl {lat lon} {
      .ftop.input.c2.r2.l0 configure -text "Lat: $lat"
      .ftop.input.c2.r2.l1 configure -text "Lon: $lon"
    }

    proc plotAxisTicksLines {timeLbl numofsat numofsatmsg} {
      global Screen::canvasWidth Screen::canvasHeight
      global Screen::timeStepMinutes Screen::colorVdop Screen::flipVdop

      clearCanvas .ftop.display.c
      plotAxis $timeLbl $numofsat $numofsatmsg
      plotTicks
      plotLines
    }

    proc clearTimeLine {} {
      # clear the time line if it already exists
      global Screen::yTimeLine
      foreach id [.ftop.display.c find all] {
        if {$id == $Screen::yTimeLine} {
          .ftop.display.c delete $id
        }
      }
    }

    proc plotTimeLine {curHour curMin curSec} {
      global Screen::canvasHeight Screen::canvasWidth
      # clear the time line if it already exists
      .ftop.display.c delete timeline

      if {$curHour % 2 == 0} {
        set tempMinute [string trimleft $curMin "0"]
        if {$tempMinute == ""} {
           set minuteOffset 0
        } else { 
           set minuteOffset [expr (48*$tempMinute)/120]
        }
      } else {
        set tempMinute [string trimleft $curMin "0"]
        if {$tempMinute == ""} {
           set minuteOffset 24
        } else {
           set minuteOffset [expr (48*$tempMinute)/120 + 24]
        }
      }
      
      .ftop.display.c create line \
                              [expr ($curHour/2)*48+20+$minuteOffset] \
                              [expr $Screen::canvasHeight-20] \
                              [expr ($curHour/2)*48+20+$minuteOffset] \
                              50 -fill magenta -width 1 -tag timeline
    }


    proc plotData {x y1 y11 y2 y22} {
      global Screen::canvasWidth Screen::canvasHeight
      global Screen::timeStepMinutes Screen::colorVdop Screen::flipVdop

      if {(6.0 < $y11) || ($y11 < 0.0)} {
        set y11 6
      }

      set x2 [expr ($x + 1)]
      set x1 $x
      if {(6.0 < $y22) || ($y22 < 0.0)} {
        set y22 6
      }        

      if {$Screen::flipVdop} {
          # Flip vpod upside down
          set y22 [expr 12-2*$y22]
          set y11 [expr 12-2*$y11]
      }
      
      .ftop.display.c create line \
           [expr 20 + $x1 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y11 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           [expr 20 + $x2 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y11 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           -fill $Screen::colorVdop -width 2 -stipple gray50
      .ftop.display.c create line \
           [expr 20 + $x2 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y11 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           [expr 20 + $x2 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y22 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           -fill $Screen::colorVdop -width 2 -stipple gray50
      .ftop.display.c create line \
           [expr 20 + $x1 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y1 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           [expr 20 + $x2 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y1 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           -fill blue -width 2
      .ftop.display.c create line \
           [expr 20 + $x2 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y1 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           [expr 20 + $x2 * $Screen::timeStepMinutes * \
                      ($Screen::canvasWidth - 34) / 1440] \
           [expr ($Screen::canvasHeight - 20 - $y2 * \
                      ($Screen::canvasHeight - 20) / 14)] \
           -fill blue -width 2
    }


    #-------------------------------------------------------------------------
    # Local procedures
    #-------------------------------------------------------------------------
    proc clearCanvas {me} {
      foreach id [$me find all] {
         $me delete $id
      }
    }

    proc plotAxis {timeLbl numofsat numofsatmsg} {

      global Screen::canvasHeight Screen::canvasWidth Screen::colorVdop

      # plot the timeAxis and the satAxis
      .ftop.display.c create line 20 0 20 [expr ($Screen::canvasHeight -20)] \
            -width 2 -arrow first
      .ftop.display.c create line 20 [expr ($Screen::canvasHeight - 20)] \
            $Screen::canvasWidth [expr ($Screen::canvasHeight-20)] \
            -width 2 -arrow last

      .ftop.display.c create text 80 8 -text $numofsat -fill blue
      .ftop.display.c create text 85 23 -text "($numofsatmsg)" \
            -fill blue

      .ftop.display.c create text [expr $Screen::canvasWidth-15] \
            [expr $Screen::canvasHeight-30] -text $timeLbl

      .ftop.display.c create line [expr $Screen::canvasWidth - 70] 20 \
            [expr $Screen::canvasWidth - 40] 20 -fill $Screen::colorVdop \
            -width 2 -stipple gray50
      .ftop.display.c create text [expr $Screen::canvasWidth - 20] 20 \
            -text "VDOP" -fill $Screen::colorVdop

    }

    proc plotTicks {} {

      global Screen::canvasHeight Screen::canvasWidth Screen::colorVdop 
      global small_font

      # plot the timeAxis ticks and texts
      set num 12
      set timenum 24
      while {$num > 0} {
        .ftop.display.c create line [expr $num * 48 + 20] \
                                    [expr $Screen::canvasHeight - 20] \
                                    [expr $num * 48 + 20] \
                                    [expr $Screen::canvasHeight - 15]
        if {$num == 12} {
          .ftop.display.c create text [expr $num * 48 + 10] \
                                    [expr $Screen::canvasHeight - 5] \
                                    -text "$timenum:00"
        } else {
          .ftop.display.c create text [expr $num * 48 + 10] \
                                    [expr $Screen::canvasHeight - 5] \
                                    -text "$timenum:00"
        }
        set num [expr $num-1]
        set timenum [expr $timenum-2]
      }

      # plot the satAxis ticks and texts
      set num 6
      set satnum 12
      while {$num > 0} {
        .ftop.display.c create line 20 \
                            [expr $Screen::canvasHeight - $num*40 - 20] \
                            15 [expr $Screen::canvasHeight - $num*40 - 20]
        .ftop.display.c create text 6 \
                            [expr $Screen::canvasHeight - $num*40 - 20] \
                            -text $satnum -fill blue -font $small_font
        set num [expr $num-1]
        set satnum [expr $satnum-2]
      }

      # plot the RIGHT axis ticks and texts
      set num 5
      set satnum 1
      while {$num > 0} {
        .ftop.display.c create text \
                      [expr $Screen::canvasWidth - 3] \
                      [expr $Screen::canvasHeight - $num * 40 - 20] \
                      -text $satnum -fill $Screen::colorVdop -font $small_font
        set num [expr $num-1]
        set satnum [expr $satnum+1]
      }
    }

    proc plotLines {} {

      global Screen::canvasHeight Screen::canvasWidth
      global color6

      # plot the 4,6,8,10 lines
      set end [expr $Screen::canvasWidth - 10]
      .ftop.display.c create line 20 \
        [expr $Screen::canvasHeight-20- 2*($Screen::canvasHeight - 20) / 14] \
        $end [expr $Screen::canvasHeight-20-2*($Screen::canvasHeight-20)/14] \
        -fill black -width 1 -stipple gray25
      .ftop.display.c create line 20 \
        [expr $Screen::canvasHeight-20- 4*($Screen::canvasHeight - 20) / 14] \
        $end [expr $Screen::canvasHeight-20-4*($Screen::canvasHeight-20)/14] \
        -fill black -width 1 -stipple gray25
      .ftop.display.c create line 20 \
        [expr $Screen::canvasHeight-20- 6*($Screen::canvasHeight - 20)/14] \
        $end [expr $Screen::canvasHeight-20-6*($Screen::canvasHeight-20)/14] \
        -fill black -width 1 -stipple gray25
      .ftop.display.c create line 20 \
        [expr $Screen::canvasHeight-20- 8*($Screen::canvasHeight - 20) / 14] \
        $end [expr $Screen::canvasHeight-20-8*($Screen::canvasHeight-20)/14] \
        -fill black -width 1 -stipple gray25
      .ftop.display.c create line 20 \
        [expr $Screen::canvasHeight-20-10*($Screen::canvasHeight - 20) / 14] \
        $end [expr $Screen::canvasHeight-20-10*($Screen::canvasHeight-20)/14] \
        -fill black -width 1 -stipple gray25

      .ftop.display.c create line 0 0 5 5 -fill $color6 -width 1 -tag timeline
    }

}




