##############################################################################
#
# vc/src/tcl/tractorDisplay.tcl
#
# Screen to display details about and edit tractor. Used when
# adding a tractor.
#
# 20021003 QC - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "??Space for title"

    # Input frame
    frame .ftop.input

    # Row 1
    frame .ftop.input.r1
    label .ftop.input.r1.l -text "Name:" -font $big_font -width 10 -anchor e
    label .ftop.input.r1.e -text "foo" -font $big_font \
           -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r1.l -side left -pady 5 
    pack .ftop.input.r1.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r1.b btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_BTN2_SIG 2;" "Change"
#    button .ftop.input.r1.b -text "Change" -justify right \
#            -height 2 -width 8 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN2_SIG 2; } 
       
    # Row 2
    frame .ftop.input.r2
    label .ftop.input.r2.l -text "Type:" -font $big_font -width 10 -anchor e
    label .ftop.input.r2.e -text "Hitched or Towed" -font $big_font \
          -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r2.l -side left -pady 5 -anchor w
    pack .ftop.input.r2.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r2.b btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_BTN3_SIG 3;" "Change"
#    button .ftop.input.r2.b -text "Change" -justify right \
#            -height 2 -width 8 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN3_SIG 3; }
          
    # Row 3
    frame .ftop.input.r3
    label .ftop.input.r3.l -text "Color:" -font $big_font -width 10 -anchor e
    label .ftop.input.r3.e -text "BLUE OR RED" -font $big_font \
          -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r3.l -side left -pady 5 -anchor w
    pack .ftop.input.r3.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r3.b btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_BTN4_SIG 4;" "Change"
#    button .ftop.input.r3.b -text "Change" -justify right \
#            -height 2 -width 8 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN4_SIG 4; }

    # Pack rows
    pack .ftop.input.r1 -side top -pady 5 -anchor w -fill x
    pack .ftop.input.r2 -side top -pady 5 -anchor w -fill x
    pack .ftop.input.r3 -side top -pady 5 -anchor w -fill x
   
    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel btnKhakiU btnKhakiD 0.5 \
             "beepOnce; post $DISP_BTN0_SIG 0 \"button 0\";" "Cancel"
    SnazzyButton::create .ftop.input2.accept btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN1_SIG 1 \"button 1\";" "Accept"       
#    button .ftop.input2.cancel -text "Cancel" \
#            -width 10 -height 6 \
#            -background $color5 -activebackground $color5 \
#            -command {beepOnce; post $DISP_BTN0_SIG 0 "button 0"; }
#    button .ftop.input2.accept -text "Accept" \
#            -width 10 -height 6 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN1_SIG 1 "button 1"; }
        
    pack .ftop.input2.cancel -side left -padx 10 -pady 10
    pack .ftop.input2.accept -side right -padx 10 -pady 10

    # Pack .ftop
    pack .ftop.title -side top -pady 10 -fill both -expand yes
    pack .ftop.input -side top -pady 10 -pady 5
    pack .ftop.input2 -side bottom -anchor se -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {

        eval $packProc__
        pack .ftop -fill both -expand yes

    }


    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }


    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actDisplayTractor {name__ type__ color__ interface__} {
        .ftop.input.r1.e configure -text $name__
        .ftop.input.r2.e configure -text $type__
        .ftop.input.r3.e configure -text $color__
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
    proc packAdd {addTrac nameLbl typeLbl colorLbl cancelBtn acceptBtn} {

        .ftop.title configure -text $addTrac
        .ftop.input.r1.l configure -text $nameLbl
        .ftop.input.r2.l configure -text $typeLbl
        .ftop.input.r3.l configure -text $colorLbl
        SnazzyButton::setText .ftop.input2.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.input2.accept $acceptBtn 0.5
#        .ftop.input2.cancel configure -text $cancelBtn
#        .ftop.input2.accept configure -text $acceptBtn
                
        pack .ftop -fill both -expand yes

    }
}
