##############################################################################
#
# vc/src/tcl/language.tcl
#
# Screen to display language selection.
#
# 20030110 QC - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop
    
    
    frame .ftop.display         ;# Display Frame
    frame .ftop.display.logo    ;# Display Frame for Logo
    frame .ftop.display.text    ;# Display Frame for Text
    frame .ftop.input           ;# Input Frame
    
    # Create secret button
    button .ftop.s -height 1 -width 5 \
            -command {beepOnce; post $DISP_BTN8_SIG 8 } \
            -borderwidth 0 -state normal \
            -background $color6 -highlightbackground $color6 \
            -activebackground $color6
    pack .ftop.s -side top -anchor ne
    
    pack .ftop.input -side bottom -fill both -expand yes -anchor sw
    pack .ftop.display -side top -fill both -expand yes 
     
    # Create Logo
    image create photo gifImage -format gif -file ${tclPath}gif/AFLogo.gif
    label .ftop.display.logo.l0 -image gifImage

    # First row of buttons
    frame .ftop.input.r1   
    SnazzyButton::create .ftop.input.r1.b0 AutoSteer5U AutoSteer5D 0.2 \
                         "beepOnce; post $DISP_BTN0_SIG 0" "AutoSteer"
    SnazzyButton::create .ftop.input.r1.b1 AutoLevelU AutoLevelD 0.2 \
                         "beepOnce; post $DISP_BTN1_SIG 1" "AutoLevel"
    SnazzyButton::create .ftop.input.r1.b2 grayup graydown 0.5 \
                         "beepOnce; post $DISP_BTN2_SIG 2" "AutoSteer\nSim"
    SnazzyButton::create .ftop.input.r1.b3 grayup graydown 0.5 \
                         "beepOnce; post $DISP_BTN3_SIG 3" "Sync\nUser\nData"
    
    # Second row of buttons
    frame .ftop.input.r2
    SnazzyButton::create .ftop.input.r2.b4 grayup graydown 0.5 \
                         "beepOnce; post $DISP_BTN4_SIG 4" "Button 4"
    SnazzyButton::create .ftop.input.r2.b5 grayup graydown 0.5 \
                         "beepOnce; post $DISP_BTN5_SIG 5" "Button 5"
    SnazzyButton::create .ftop.input.r2.b6 grayup graydown 0.5 \
                         "beepOnce; post $DISP_BTN6_SIG 6" "Button 6"
    SnazzyButton::create .ftop.input.r2.b7 grayup graydown 0.5 \
                         "beepOnce; post $DISP_BTN7_SIG 7" "Button 7"

    # pack the exit button
    SnazzyButton::create .ftop.input.r1.exit ExitU ExitD 0.2 \
                         "beepOnce; guiExit" "Exit\n"
    pack .ftop.input.r1.exit -side left -padx 5 -pady 3 -anchor sw
    pack .ftop.input.r1 -side bottom -anchor s -fill both -expand yes
    pack .ftop.input.r2 -side bottom -anchor s -fill both -expand yes

    # create text to diaply language options
    label .ftop.display.text.l1 -text "Select Operation" -font $huge_font
    label .ftop.display.text.l2 -text "Choisissez la Manoeuvre" -font $huge_font
    label .ftop.display.text.l3 -text "Whlen Sie einen Vorgang" -font $huge_font
    label .ftop.display.text.l4 -text "Elegir Operacin" -font $huge_font

    # pack text
    pack .ftop.display.logo.l0 -side top -pady 0
    pack .ftop.display.text.l1 -side top -pady 2
    pack .ftop.display.text.l2 -side top -pady 2
    pack .ftop.display.text.l3 -side top -pady 2
    pack .ftop.display.text.l4 -side top -pady 2
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {btn0 yFrac0 btn1 yFrac1 btn2 yFrac2 btn3 yFrac3 \
                   btn4 yFrac4 btn5 yFrac5 btn6 yFrac6 btn7 yFrac7} {
        
      # Max number of buttons allowed on first row, not including the 
      # exit button
      set numBtnFirstRow 4
    
      # Total number of buttons to display
      set maxNumBtns 8
    
      # Total number of buttons packed
      set totalBtns 0
    
      # Set the text and pack all buttons defined 
      for {set btnNum 0} {$btnNum < $maxNumBtns} {incr btnNum} {
        set btnName [subst -novariables {$btn[format $btnNum]}]
        eval set btnValue $btnName
        if {$btnValue != "!"} {
          set yFracName [subst -novariables {$yFrac[format $btnNum]}]
          eval set yFracNum $yFracName
          if {$btnNum < $numBtnFirstRow} {
            eval {SnazzyButton::setText .ftop.input.r1.b$btnNum} $btnName \
                                                                 $yFracNum  
            eval {pack .ftop.input.r1.b$btnNum} -side right -padx 3 \
                                                -pady 3 -anchor se
          } else {
              eval {SnazzyButton::setText .ftop.input.r2.b$btnNum} $btnName \
                                                                   $yFracNum  
              eval {pack .ftop.input.r2.b$btnNum} -side right -padx 3 \
                                                  -pady 3 -anchor se
          }
          incr totalBtns
        } 
      }
        
      # If there is a second row of button pack the logo and text at the
      # top of the screen.
      if {$totalBtns <= $numBtnFirstRow} {
        pack .ftop.display.logo -side top -padx 5 -fill both -expand yes
        pack .ftop.display.text -side top -padx 10 -fill both -expand yes
      } else {
          pack .ftop.display.logo -side left -padx 5 -fill both -expand yes
          pack .ftop.display.text -side right -padx 10 -fill both -expand yes
      }
                  
      pack .ftop -fill both -expand yes
    }

    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
