##############################################################################
#
# vc/src/tcl/calByAveraging.tcl
#
# Calibration by averaging screens
#
# 20030220 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames
    # and uses .configDisplay, and .navDisplay components)
    frame .ftop.input
    frame .ftop.display
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes
    pack .configDisplay -in .ftop -side left -anchor nw -fill y -expand yes \
            -pady 10 -padx 10
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor ne -pady 10 -padx 10
    raise .navDisplay

    # Display frame - displays up to 5 lines of text
    label .ftop.display.l0 -text "line 0"
    label .ftop.display.l1 -text "line 1" -font $big_font
    label .ftop.display.l2 -text "line 2" -font $big_font
    label .ftop.display.l3 -text "line 3" -font $big_font
    label .ftop.display.l4 -text "line 4" -font $big_font

    set barWidth 400
    set barHeight 20
    canvas .ftop.display.c -width $barWidth -height $barHeight \
                      -relief sunken -borderwidth 1 -background $color6
    .ftop.display.c \
            create rectangle 0 0 $barWidth $barHeight -fill green \
            -outline black -tags percentbar
    .ftop.display.c coords percentbar 0 0 0 $Screen::barHeight
    .ftop.display.c create text \
                      [expr $barWidth/2] [expr $barHeight/2] -text "0%" \
                      -font $small_font -anchor c -tags percentext

    # Input frame 
    #   - Cancel button 
    SnazzyButton::create .ftop.input.cancel btnKhakiU btnKhakiD 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Cancel"

    #   - up to two rows of 2 rows of up to 4 buttons each
    #   - or a scrolling listbox, with up to two rows of 2 rows 2 buttons each
    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.b0 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 0" "Button 0"
    SnazzyButton::create .ftop.input.r1.b1 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN1_SIG 1" "Button 0"
    SnazzyButton::create .ftop.input.r1.b2 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 2" "Button 0"
    SnazzyButton::create .ftop.input.r1.b3 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN3_SIG 3" "Button 0"

    frame .ftop.input.r2
    SnazzyButton::create .ftop.input.r2.b4 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN4_SIG 4" "Button 0"
    SnazzyButton::create .ftop.input.r2.b5 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN5_SIG 5" "Button 0"
    SnazzyButton::create .ftop.input.r2.b6 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN6_SIG 6" "Button 0"
    SnazzyButton::create .ftop.input.r2.b7 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN7_SIG 7" "Button 0"
    
    # Transducer configuration buttons
    frame .ftop.input.tc
    frame .ftop.input.tc.r1
    frame .ftop.input.tc.r2
    SnazzyButton::create .ftop.input.tc.r1.b0 btnBlueM9U btnBlueM9D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 1" \
            "1 - Left Pressure\n2 - Right Pressure"
            
    SnazzyButton::create .ftop.input.tc.r2.b0 btnBlueM9U btnBlueM9D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 2" \
            "1 - Right Pressure\n2 - Left Pressure"
            
    SnazzyButton::create .ftop.input.tc.r1.b1 btnBlueM9U btnBlueM9D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 3" \
            "1 - Single Pressure\n2 - Not connected"
               
    SnazzyButton::create .ftop.input.tc.r2.b1 btnBlueM9U btnBlueM9D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 4" \
            "1 - Left Pressure\n2 - Right Pressure"
            
    SnazzyButton::create .ftop.input.tc.r1.b2 btnBlueM9U btnBlueM9D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 5" \
            "1 - Single Pressure\n2 - Temperature"
            
    SnazzyButton::create .ftop.input.tc.r2.b2 btnBlueM9U btnBlueM9D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 6" \
            "1 - Temperature\n2 - Single Pressure"
    
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
        eval $packProc__
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr
    proc actConfigureL1 { line1__ } {
        global big_font
        .ftop.display.l1 configure -text $line1__ -font $big_font
    }

    proc actConfigureL2 { line2__ } {
        global big_font
        .ftop.display.l2 configure -text $line2__ -font $big_font
    }

    proc actPackBtn0 { text__ } {
        .ftop.input.r1.b0 configure -text $text__
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
    }

    proc actForgetBtn0 {} {
        pack forget .ftop.input.r1.b0
    }

    proc actForgetBtn1 {} {
        pack forget .ftop.input.r1.b1
    }

    proc actForgetTc {} {
        pack forget .ftop.input.tc
        pack .ftop.input.r1 -side bottom -anchor se
    }

    proc actConfigurePercentBar { percent__ } {
        # {MLE-040122: Tcl is too smart here; explain to Qinghe how to fix...}

        set w [expr 0.01*$percent__*$Screen::barWidth]
        .ftop.display.c coords percentbar 0 0 $w $Screen::barHeight 
        set msg [format "%3.0f%%" $percent__]
        .ftop.display.c itemconfigure percentext -text $msg
    }

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    proc packCalDeereTrackStep1 {title__ line1__ line2__ btn0__ cancel__} {

        global huge_font big_font small_font color6 medium_font

        .ftop.input.cancel configure -text $cancel__
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        
        .ftop.display.l0 configure -text $title__ -font $huge_font
        .ftop.display.l1 configure -text $line1__ -font $medium_font \
          -justify left
        .ftop.display.l2 configure -text $line2__ -font $big_font
        pack .ftop.display.l0 -side top -pady 2
        pack .ftop.display.l1 -side top -pady 5
        pack .ftop.display.l2 -side top -pady 5

        pack .ftop.display.c -side top -padx 5 -pady 0
        
        .ftop.input.r1.b0 configure -text $btn0__
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se
    }


    proc packCalTransducer {title__ line1__ line2__ \
            btn0__ btn1__ btn2__ btn4__ btn5__ btn6__ cancel__} {

        global huge_font big_font

        .ftop.input.cancel configure -text $cancel__
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        
        .ftop.display.l0 configure -text $title__ -font $huge_font
        .ftop.display.l1 configure -text $line1__ -font $big_font
        .ftop.display.l2 configure -text $line2__ -font $big_font
        pack .ftop.display.l0 -side top -pady 2
        pack .ftop.display.l1 -side top -pady 5
        pack .ftop.display.l2 -side top -pady 5

        .ftop.input.tc.r2.b0 configure -text $btn4__
        pack .ftop.input.tc.r2.b0 -side left -padx 2 -pady 2
        .ftop.input.tc.r2.b1 configure -text $btn5__
        pack .ftop.input.tc.r2.b1 -side left -padx 2 -pady 2
        .ftop.input.tc.r2.b2 configure -text $btn6__
        pack .ftop.input.tc.r2.b2 -side left -padx 2 -pady 2
        pack .ftop.input.tc.r2 -side bottom -anchor se

       .ftop.input.tc.r1.b0 configure -text $btn0__
        pack .ftop.input.tc.r1.b0 -side left -padx 2 -pady 2
        .ftop.input.tc.r1.b1 configure -text $btn1__
        pack .ftop.input.tc.r1.b1 -side left -padx 2 -pady 2
        .ftop.input.tc.r1.b2 configure -text $btn2__
        pack .ftop.input.tc.r1.b2 -side left -padx 2 -pady 2
        pack .ftop.input.tc.r1 -side bottom -anchor se 

        pack .ftop.input.tc -side bottom -anchor se -padx 3 -pady 3

    }


    proc packCalWheeledStep2 {title__ line1__ line2__ \
            btn0__ btn1__ cancel__} {

        global huge_font big_font

        .ftop.input.cancel configure -text $cancel__
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        
        .ftop.display.l0 configure -text $title__ -font $huge_font
        .ftop.display.l1 configure -text $line1__ -font $big_font
        .ftop.display.l2 configure -text $line2__ -font $big_font
        pack .ftop.display.l0 -side top -pady 2
        pack .ftop.display.l1 -side top -pady 10
        pack .ftop.display.l2 -side top -pady 10

        .ftop.input.r1.b0 configure -text $btn0__
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        .ftop.input.r1.b1 configure -text $btn1__
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se
    }

}
