##############################################################################
#
# vc/src/tcl/databasediff.tcl
#
# Screen to show database diff.
#
# 20040802 QC - created
#
# Copyright (c) 2004 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Database Compare"
    label .ftop.subtitle0 -font $big_font -text "Reference Vehicle Type"
    label .ftop.subtitle1 -font $big_font -text "Current Vehicle Name"
    label .ftop.subtitle2 -font $big_font -text "Export Data File Name"
    label .ftop.subtitle -font $big_font -text \
       [format "      %-24s %-20s %-19s %-22s" "Parameter Name" \
         "Default Value" "Current Value" "Date Changed"]     
                                                                                
    frame .ftop.input
    scrollbar .ftop.input.sbar -orient vertical -width 50 \
                -command [list .ftop.input.txt yview] 
    text .ftop.input.txt -width 62 -height 10 -font $big_font \
                -tabs {0.5i 2.45i}\
                -yscrollcommand [list .ftop.input.sbar set]

    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel \
                 btnKhakiForSatVUU btnKhakiForSatVUD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To Previous Menu"
    SnazzyButton::create .ftop.input2.export \
                 btnBlueForSatVUU btnBlueForSatVUD 0.5 \
         "beepOnce; post $DISP_BTN1_SIG 1;" "Export Analysis to Compact Flash"
        
    pack .ftop.input2.cancel -side left -padx 1 -anchor se
    pack .ftop.input2.export -side right -padx 1 -anchor sw

    # Pack .ftop
    pack .ftop.title -side top -pady 5
    pack .ftop.subtitle0 -side top -padx 10 -anchor nw
    pack .ftop.subtitle1 -side top -padx 10 -anchor nw
    pack .ftop.subtitle2 -side top -padx 10 -anchor nw
    pack .ftop.subtitle -side top -pady 10 -anchor sw
    pack .ftop.input -side top -padx 10
    pack .ftop.input2 -side bottom -anchor sw -padx 5 -pady 5 -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { titleLbl subTitle0Lbl subTitle1Lbl exportBtn returnBtn subtitle } {
      .ftop.title configure -text $titleLbl
      .ftop.subtitle0 configure -text $subTitle0Lbl
      .ftop.subtitle1 configure -text $subTitle1Lbl
      SnazzyButton::setText .ftop.input2.cancel $returnBtn 0.5
      SnazzyButton::setText .ftop.input2.export $exportBtn 0.5
      .ftop.subtitle configure -text $subtitle
      # Pack the list box
      pack .ftop.input.txt -side left -fill both
      pack .ftop.input.sbar -side left -fill y

      pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actListboxInsert { paramName currentValue defaultValue gpsDate } {
        .ftop.input.txt insert end  \
       [format "%s\t\t%-8.4f\t%-8.4f\t%s\n" $paramName $currentValue \
                                            $defaultValue $gpsDate]
    }

    proc actListboxInsertCategory { categoryName } {
        .ftop.input.txt insert end  \
       [format "\n%s\n" $categoryName]
    }

    proc actListboxInsertFirstCategory { categoryName } {
        .ftop.input.txt insert end  \
       [format "%s\n" $categoryName]
    }

    proc actNoDiff { msg } {
        .ftop.input.txt insert end $msg
    }
    
    proc actDispExportFileName { exprtFileName } {
      .ftop.subtitle2 configure -text $exprtFileName
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
