##############################################################################
#
# vc/src/tcl/examineAtt.tcl
#
# Screen to display details about Attitude examination.
#
# 20030421 M_S - created
#
# Copyright (c) 2002-2003 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes -anchor sw

    # NOTE: using place for positioning imported frames (-in option)
    #       crashes Tcl interpreter. Therefore pack must be used.
    pack .configDisplay -in .ftop -side left \
            -anchor n -padx 10 -pady 10
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor n -padx 10 -pady 10
    raise .navDisplay

    # title and error indicator
    label .ftop.display.title -font $huge_font
    pack .ftop.display.title -side top -padx 10 -pady 0 \
        -fill x -expand yes -anchor n
    
    # Text
    label .ftop.display.attText -font $medium_font -justify left
    label .ftop.display.linebiasText1 -font $medium_font -justify left
    label .ftop.display.linebiasText2 -font $medium_font -justify left
    label .ftop.display.linebiasText3 -font $medium_font -justify left
    label .ftop.display.linebiasText4 -font $medium_font -justify left
    label .ftop.display.linebiasText5 -font $medium_font -justify left
    label .ftop.display.linebiasText6 -font $medium_font -justify left
    pack .ftop.display.attText -side top -padx 40 -pady 3 -anchor nw
    pack .ftop.display.linebiasText1 -side top -padx 40 -pady 0 -anchor w \
        -fill y -expand yes
   
    # buttons
    SnazzyButton::create .ftop.input.return btnKhakiU btnKhakiD 0.5 \
             "beepOnce; post $DISP_BTN9_SIG 9;" "Return To Previous Menu"
    pack .ftop.input.return -side left -padx 5 -pady 5 -anchor sw
    SnazzyButton::create .ftop.input.survey btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN1_SIG 1;" "Survey"
    SnazzyButton::create .ftop.input.reset btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN2_SIG 2;" "Reset"
    SnazzyButton::create .ftop.input.resetLb btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN3_SIG 3;" "ResetLb"

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    
    proc actEntry { titleLbl returnBtn surveyBtn resetBtn resetLbBtn\
                    attText linebiasText } {
   
        .ftop.display.title configure -text $titleLbl
        .ftop.input.return configure -text $returnBtn
        .ftop.input.survey configure -text $surveyBtn
        .ftop.input.reset configure -text $resetBtn
        .ftop.input.resetLb configure -text $resetLbBtn
        .ftop.display.attText configure -text $attText
        .ftop.display.linebiasText1 configure -text $linebiasText

        if {$surveyBtn != "!"} {
          pack .ftop.input.survey -side right -padx 5 -pady 5 -anchor se
        }
        pack .ftop.input.reset -side right -padx 5 -pady 5 -anchor se
        pack .ftop.input.resetLb -side right -padx 5 -pady 5 -anchor se
        pack forget .ftop.display.linebiasText2 .ftop.display.linebiasText3 \
            .ftop.display.linebiasText4  .ftop.display.linebiasText5 \
            .ftop.display.linebiasText6
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # other action procedures (called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actDisplayAtt { attText } {
        .ftop.display.attText configure -text $attText
    }
    
    proc actDisplayLineBiasWithoutHeading { linebias1 linebias2 filtertime } {
        .ftop.display.linebiasText3 configure -text ""
        .ftop.display.linebiasText2 configure -text "Filter Value:      $linebias1      $linebias2     $filtertime"
    }

    proc actDisplayLineBias { a5Flag linebiasText1 linebiasText2 lbcolor2 \
                              linebiasText3 \
                              linebiasText4 lbcolor4 \
                              linebiasText5 lbcolor5 \
                              linebiasText6 lbcolor6 } {
        .ftop.display.linebiasText1 configure -text $linebiasText1
        .ftop.display.linebiasText2 configure -text $linebiasText2 \
            -background $lbcolor2
        .ftop.display.linebiasText3 configure -text $linebiasText3
        .ftop.display.linebiasText4 configure -text $linebiasText4 \
            -background $lbcolor4
        .ftop.display.linebiasText5 configure -text $linebiasText5 \
            -background $lbcolor5
        .ftop.display.linebiasText6 configure -text $linebiasText6 \
            -background $lbcolor6
        pack .ftop.display.linebiasText2 -side top -padx 70 -pady 0 -anchor w
        pack .ftop.display.linebiasText3 -side top -padx 70 -pady 0 -anchor w
        if {$a5Flag == 0} {
          pack .ftop.display.linebiasText4 -side top -padx 70 -pady 0 -anchor w
          pack .ftop.display.linebiasText5 -side top -padx 70 -pady 0 -anchor w
          pack .ftop.display.linebiasText6 -side top -padx 70 -pady 0 -anchor w
        }
    }
}
