##############################################################################
#
# vc/src/tcl/examineImplementDisplay.tcl
#
# Screen to display details about Steering examination.
#
# 20050906 RM - created
#
# Copyright (c) 2005 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames, and reuses the .logo,
    # .configDisplay, and .navDisplay components)
    frame .ftop.title
    frame .ftop.input
    pack .ftop.input -side bottom -fill x -padx 5 -pady 3
    pack .ftop.title -side bottom -fill x
    pack .configDisplay -in .ftop -side left \
            -anchor nw -fill y -expand yes -padx 10 -pady 7
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor ne -padx 10 -pady 7
    raise .navDisplay

    # Title
    label .ftop.title.prompt -text "Space for title"
    pack .ftop.title.prompt -side top -anchor s
    
    # Row 1
    frame .ftop.input.r1
    frame .ftop.input.r1.top
    frame .ftop.input.r1.bottom -relief sunken -borderwidth 1
    frame .ftop.input.r1.bottom.left
    frame .ftop.input.r1.bottom.middle
    frame .ftop.input.r1.bottom.right
    
    label .ftop.input.r1.bottom.middle.l0 -text "Error Signal:" \
          -font $big_font -anchor e
    label .ftop.input.r1.bottom.middle.e0 -text "0" -font $big_font \
          -width 8 -relief sunken -borderwidth 2
    label .ftop.input.r1.bottom.middle.e1 -text "0.000000" -font $big_font \
          -width 8 -relief sunken -borderwidth 2
    SnazzyButton::create .ftop.input.r1.bottom.left.btn0 \
                 btnKhakiIMPLSU btnKhakiIMPLSD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;" "-100"
    SnazzyButton::create .ftop.input.r1.bottom.left.btn1 \
                 btnKhakiIMPLSU btnKhakiIMPLSD 0.5 \
                 "beepOnce; post $DISP_BTN1_SIG 1;" "-10"
    SnazzyButton::create .ftop.input.r1.bottom.left.btn2 \
                 btnKhakiIMPLSU btnKhakiIMPLSD 0.5 \
                 "beepOnce; post $DISP_BTN2_SIG 2;" "-1"
    SnazzyButton::create .ftop.input.r1.bottom.right.btn3 \
                 btnKhakiIMPLSU btnKhakiIMPLSD 0.5 \
                 "beepOnce; post $DISP_BTN3_SIG 3;" "+1"
    SnazzyButton::create .ftop.input.r1.bottom.right.btn4 \
                 btnKhakiIMPLSU btnKhakiIMPLSD 0.5 \
                 "beepOnce; post $DISP_BTN4_SIG 4;" "+10"
    SnazzyButton::create .ftop.input.r1.bottom.right.btn5 \
                 btnKhakiIMPLSU btnKhakiIMPLSD 0.5 \
                 "beepOnce; post $DISP_BTN5_SIG 5;" "+100"
    SnazzyButton::create .ftop.input.r1.top.btn8 \
                 btnSmallStopU btnSmallStopD 0.5 \
                 "beepOnce; post $DISP_BTN8_SIG 8;" "    "
        
    # Row 2
    frame .ftop.input.r2
    frame .ftop.input.r2.left
    frame .ftop.input.r2.middle
    frame .ftop.input.r2.middle.top
    frame .ftop.input.r2.middle.bottom
    frame .ftop.input.r2.right
    
    # Left
    SnazzyButton::create .ftop.input.r2.left.cancel btnKhakiU btnKhakiD 0.5 \
           "beepOnce; post $DISP_BTN9_SIG 9;" "Return\nTo\nPrevious\nMenu"
           
    # Middle
    label .ftop.input.r2.middle.top.l0 -text "Lift Switch:" \
          -font $big_font -anchor w
    label .ftop.input.r2.middle.top.e0 -text "UP" -font $big_font \
                  -width 8 -relief sunken -borderwidth 2
    label .ftop.input.r2.middle.bottom.l1 -text "Controller Power:" \
          -font $big_font -anchor e
    label .ftop.input.r2.middle.bottom.e1 -text "OFF" -font $big_font \
          -width 8 -relief sunken -borderwidth 2
          
    # Right
    SnazzyButton::create .ftop.input.r2.right.min btnKhakiU btnKhakiD 0.5 \
           "beepOnce; post $DISP_BTN6_SIG 6;" "Set Min\nError\nSignal"
    SnazzyButton::create .ftop.input.r2.right.max btnKhakiU btnKhakiD 0.5 \
           "beepOnce; post $DISP_BTN7_SIG 7;" "Set Max\nError\nSignal"
    
    pack .ftop.input.r2.left.cancel -side left -padx 5 -pady 5
    
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
        
        eval $packProc__
        pack .ftop -fill both -expand yes

    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    
    proc actDisplayOrthmanImpl { liftSwitch controllerPower \
                                errorSignalRawCount errorSignalVoltage } {
                                
        
        .ftop.input.r1.bottom.middle.e0 configure \
          -text $errorSignalRawCount
        .ftop.input.r1.bottom.middle.e1 configure \
          -text $errorSignalVoltage
        .ftop.input.r2.middle.top.e0 configure -text $liftSwitch
        .ftop.input.r2.middle.top.e1 configure -text $controllerPower
           
    }

    proc actDisplayImplErrSig { errorSignalRawCount errorSignalVoltage } {
      .ftop.input.r1.bottom.middle.e0 configure -text $errorSignalRawCount 
      .ftop.input.r1.bottom.middle.e1 configure -text $errorSignalVoltage  
    }

    proc actDisplayDvaImplErrSig { errorSignalRawCount } {
      .ftop.input.r1.bottom.middle.e0 configure -text $errorSignalRawCount 
    }

    proc actDisplayCoulterAngle { coulterAngle } {
      .ftop.input.r2.middle.bottom.e1 configure -text $coulterAngle	
    }

    proc actControllerPwrOn {} {
      .ftop.input.r2.middle.bottom.e1 configure -text "ON"
    }

    proc actControllerPwrOff {} {
      .ftop.input.r2.middle.bottom.e1 configure -text "OFF"
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures

    proc packOrthmanImpl { title errorSignal controllerPower liftSwitch \
                           returnBtn maxErrSigBtn minErrSigBtn } {

        .ftop.title.prompt configure -text $title

        # Row 1
        .ftop.input.r1.bottom.middle.l0 configure -text $errorSignal
             
        pack .ftop.input.r1.bottom.left.btn0 -side left
        pack .ftop.input.r1.bottom.left.btn1 -side left
        pack .ftop.input.r1.bottom.left.btn2 -side left
        
        pack .ftop.input.r1.bottom.middle.l0
        pack .ftop.input.r1.bottom.middle.e0
        pack .ftop.input.r1.bottom.middle.e1
        
        pack .ftop.input.r1.bottom.right.btn3 -side left
        pack .ftop.input.r1.bottom.right.btn4 -side left
        pack .ftop.input.r1.bottom.right.btn5 -side left
        pack .ftop.input.r1.top.btn8 -side left -pady 2


        # Row 2
        .ftop.input.r2.left.cancel configure -text $returnBtn
        .ftop.input.r2.middle.top.l0 configure -text $liftSwitch
        .ftop.input.r2.middle.bottom.l1 configure -text $controllerPower
        .ftop.input.r2.right.min configure -text $minErrSigBtn
        .ftop.input.r2.right.max configure -text $maxErrSigBtn
        pack .ftop.input.r2.middle.top.l0 -side left
        pack .ftop.input.r2.middle.top.e0 -side right -anchor e
        pack .ftop.input.r2.middle.bottom.l1 -side left
        pack .ftop.input.r2.middle.bottom.e1 -side left
        pack .ftop.input.r2.right.min -side left
        pack .ftop.input.r2.right.max -side left -padx 5
        pack .ftop.input.r2.left -side left
        pack .ftop.input.r2.middle.top -side top -pady 5 -anchor w -fill x
        pack .ftop.input.r2.middle.bottom -side bottom
        pack .ftop.input.r2.middle -side left -padx 8
        pack .ftop.input.r2.right -side right


        # Pack rows
        
        pack .ftop.input.r1.bottom -side bottom -padx 20 -fill x
        pack .ftop.input.r1.top -side top
        pack .ftop.input.r1.bottom.left -side left
        pack .ftop.input.r1.bottom.middle -side left -padx 30
        pack .ftop.input.r1.bottom.right -side right -fill x -anchor w
        pack .ftop.input.r2 -side bottom -padx 5 -anchor sw -fill x
        pack .ftop.input.r1 -side bottom -pady 1 -anchor sw -fill x
    }

    proc packImplBias { title errorSignal returnBtn setBiasBtn } {

        .ftop.title.prompt configure -text $title

        # Row 1
        .ftop.input.r1.bottom.middle.l0 configure -text $errorSignal
             
        pack .ftop.input.r1.bottom.left.btn0 -side left
        pack .ftop.input.r1.bottom.left.btn1 -side left
        pack .ftop.input.r1.bottom.left.btn2 -side left
        
        pack .ftop.input.r1.bottom.middle.l0
        pack .ftop.input.r1.bottom.middle.e0
        pack .ftop.input.r1.bottom.middle.e1
        
        pack .ftop.input.r1.bottom.right.btn3 -side left
        pack .ftop.input.r1.bottom.right.btn4 -side left
        pack .ftop.input.r1.bottom.right.btn5 -side left
        pack .ftop.input.r1.top.btn8 -side left -pady 2


        # Row 2
        .ftop.input.r2.left.cancel configure -text $returnBtn
        .ftop.input.r2.right.min configure -text $setBiasBtn
        pack .ftop.input.r2.right.min -side left -padx 5
        pack .ftop.input.r2.left -side left
        pack .ftop.input.r2.right -side right


        # Pack rows
        
        pack .ftop.input.r1.bottom -side bottom -padx 20 -fill x
        pack .ftop.input.r1.top -side top
        pack .ftop.input.r1.bottom.left -side left
        pack .ftop.input.r1.bottom.middle -side left -padx 30
        pack .ftop.input.r1.bottom.right -side right -fill x -anchor w
        pack .ftop.input.r2 -side bottom -padx 5 -anchor sw -fill x
        pack .ftop.input.r1 -side bottom -pady 1 -anchor sw -fill x
    }

    proc packDvaImpl { title errorSignal coulterAngle liftSwitch \
                           returnBtn } {

        .ftop.title.prompt configure -text $title

        # Row 1
        .ftop.input.r1.bottom.middle.l0 configure -text $errorSignal
             
        pack .ftop.input.r1.bottom.left.btn0 -side left
        pack .ftop.input.r1.bottom.left.btn1 -side left
        pack .ftop.input.r1.bottom.left.btn2 -side left
        
        pack .ftop.input.r1.bottom.middle.l0
        pack .ftop.input.r1.bottom.middle.e0
        
        pack .ftop.input.r1.bottom.right.btn3 -side left
        pack .ftop.input.r1.bottom.right.btn4 -side left
        pack .ftop.input.r1.bottom.right.btn5 -side left
        pack .ftop.input.r1.top.btn8 -side left -pady 2


        # Row 2
        .ftop.input.r2.left.cancel configure -text $returnBtn
        .ftop.input.r2.middle.top.l0 configure -text $liftSwitch
        .ftop.input.r2.middle.bottom.l1 configure -text $coulterAngle
        pack .ftop.input.r2.middle.top.l0 -side left
        pack .ftop.input.r2.middle.top.e0 -side right -anchor e
        pack .ftop.input.r2.middle.bottom.l1 -side left
        pack .ftop.input.r2.middle.bottom.e1 -side left
        pack .ftop.input.r2.left -side left
        pack .ftop.input.r2.middle.top -side top -pady 5 -anchor w -fill x
        pack .ftop.input.r2.middle.bottom -side bottom
        pack .ftop.input.r2.middle -side left -padx 8
        pack .ftop.input.r2.right -side right


        # Pack rows
        
        pack .ftop.input.r1.bottom -side bottom -padx 20 -fill x
        pack .ftop.input.r1.top -side top
        pack .ftop.input.r1.bottom.left -side left
        pack .ftop.input.r1.bottom.middle -side left -padx 30
        pack .ftop.input.r1.bottom.right -side right -fill x -anchor w
        pack .ftop.input.r2 -side bottom -padx 5 -anchor sw -fill x
        pack .ftop.input.r1 -side bottom -pady 1 -anchor sw -fill x
    }

}
