##############################################################################
#
# vc/src/tcl/examineSteeringDisplayKillOn.tcl
#
# Screen to display Steering Disengage Switch Enabled.  Therefore, Steer
# Measurements are not available
#
# 20050403 RCM - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames, and reuses the .logo,
    # .configDisplay, and .navDisplay components)
    frame .ftop.title
    frame .ftop.input
    pack .ftop.input -side bottom -fill both -expand yes \
            -padx 5 -pady 3
    pack .ftop.title -side bottom -fill both -expand yes
    pack .configDisplay -in .ftop -side left \
            -anchor nw -fill y -expand yes -padx 10 -pady 10
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor ne -padx 10 -pady 10
    raise .navDisplay

    # Title
    label .ftop.title.prompt -text "Space for title"
    
    # Row 1
    frame .ftop.input.r1
    frame .ftop.input.r1.top -height 10
    frame .ftop.input.r1.bottom -height 10
    label .ftop.input.r1.bottom.msgtxt -text "Kill Switch Pushed In Text" \
          -font $huge_font -anchor w
    label .ftop.input.r1.top.potsLbl -text "Pots:" \
          -font $big_font -anchor e
    label .ftop.input.r1.top.p1 -text "32521" -font $big_font \
          -width 8 -relief sunken -borderwidth 2
    label .ftop.input.r1.top.p2 -text "32536" -font $big_font \
          -width 8 -relief sunken -borderwidth 2
    label .ftop.input.r1.top.p3 -text "32313" -font $big_font \
          -width 8 -relief sunken -borderwidth 2
         
    # Row 2
    frame .ftop.input.r2
    SnazzyButton::create .ftop.input.r2.cancel btnKhakiU btnKhakiD 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Return To\nService Menu"
    
        
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
      eval $packProc__
      pack .ftop -fill both -expand yes    
    }

    proc actDisplayDeereTrackKilled { pot1 pot2 pot3 } {
      .ftop.input.r1.top.p1 configure -text $pot1
      .ftop.input.r1.top.p2 configure -text $pot2
      .ftop.input.r1.top.p3 configure -text $pot3
    }
        
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
    
    proc packDeereTrack { title potsLbl msgtxt returnBtn } {
      pack .ftop.title.prompt -side top
      .ftop.title.prompt configure -text $title
      pack .ftop.input.r1.top.potsLbl -side left -anchor w
      .ftop.input.r1.top.potsLbl configure -text $potsLbl
      pack .ftop.input.r1.top.p1 -side left -padx 5 -anchor e 
      pack .ftop.input.r1.top.p2 -side left -padx 5 -anchor e
      pack .ftop.input.r1.top.p3 -side left -padx 5 -anchor e
      pack .ftop.input.r1.bottom.msgtxt -anchor s -padx 60 -pady 10 -anchor w
      .ftop.input.r1.bottom.msgtxt configure -text $msgtxt
      pack .ftop.input.r2.cancel
      pack .ftop.input.r1.top -pady 10
      pack .ftop.input.r1.bottom
      pack .ftop.input.r1
      pack .ftop.input.r2 -side bottom -anchor w
      .ftop.input.r2.cancel configure -text $returnBtn
    }
    
    proc packGeneric { title msgtxt returnBtn } {
      pack .ftop.title.prompt -side top
      .ftop.title.prompt configure -text $title
      pack .ftop.input.r1.bottom.msgtxt -side top -padx 60 -pady 10 -anchor w
      .ftop.input.r1.bottom.msgtxt configure -text $msgtxt
      pack .ftop.input.r2.cancel
      .ftop.input.r2.cancel configure -text $returnBtn
      pack .ftop.input.r1.bottom
      pack .ftop.input.r1
      pack .ftop.input.r2 -side bottom -anchor w
    }        
  }