##############################################################################
#
# vc/src/tcl/impsteercfg.tcl
#
# Screen to show SATEL frequencies
#
# 20051104 SSJ - created
#
# Copyright (c) 2005 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text ""

    
    frame .ftop.display
    frame .ftop.display.steps

    # Display Frame - displays up to 2 lines of text at a time
    label .ftop.display.l0
    label .ftop.display.l1
    label .ftop.display.steps.l1 -text "line 1" -justify left
    label .ftop.display.steps.l2 -text "line 2" -justify left
    label .ftop.display.steps.l3 -text "line 3" -justify left
    label .ftop.display.steps.l4 -text "line 4" -justify left

    frame .ftop.input
    
    #frequecy list box
    frame .ftop.input.listdevframe
    listbox .ftop.input.listdevframe.lbox -background white -font $big_font\
            -width 35 -height 3 

    # Create frame for buttons
    frame .ftop.input.b
    SnazzyButton::create .ftop.input.b.cancel \
                 btnBlueU btnBlueD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To\nPrevious\nMenu"

    # get device list frame
    SnazzyButton::create .ftop.input.b.devlist \
             btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN0_SIG 0;" "Get\nDevice\nList"
    SnazzyButton::create .ftop.input.b.examineSteer \
             btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN1_SIG 1;" "Examine\nSteering"
    SnazzyButton::create .ftop.input.b.examineISteer \
             btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN2_SIG 2;" "Examine\nImplement\nSteering"
    SnazzyButton::create .ftop.input.b.reconfig \
             btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN3_SIG 3;" "Reconfig to\nDB Vehicle\nType"
    SnazzyButton::create .ftop.input.b.reconfigIS \
             btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN4_SIG 4;" "Reconfig to\nImp Steer\nType"

    # Pack .ftop
    pack .ftop.title -side top -pady 10
    
    pack .ftop.input.listdevframe -side top -anchor n
    pack .ftop.input.b -side bottom -fill both -anchor s
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

               
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { cancelBtn steerLbl devOKLbl devlistBtn } {
        global big_font

        .ftop.title configure -text $steerLbl -font $big_font
        #pack .ftop.display.l0 -side top
        
        SnazzyButton::setText .ftop.input.b.cancel $cancelBtn 0.5
        pack .ftop.input.b.cancel -side left -anchor w -padx 5
        
        if {$devOKLbl != "!"} {
          .ftop.display.l1 configure -text $devOKLbl -font $big_font
	      pack .ftop.display.l1 -side top
        }
        
        if {$devlistBtn != "!"} {
          SnazzyButton::setText .ftop.input.b.devlist $devlistBtn 0.5
          pack .ftop.input.b.devlist -side right -anchor e
        }
 
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actListDevices {configLbl} {
        global big_font

        pack forget .ftop.display.l1
        pack forget .ftop.input.b.devlist

        .ftop.display.l0 configure -text $configLbl -font $big_font

        pack .ftop.input.listdevframe.lbox -side right
   
    }

    proc actEnableDevSelection {seldevLbl exsteerBtn exIsteerBtn rcBtn \
                                isBtn} {
        global huge_font

        .ftop.display.l0 configure -text $seldevLbl -font $huge_font

        if {$exsteerBtn != "!"} {
          SnazzyButton::setText .ftop.input.b.examineSteer $exsteerBtn 0.5
          pack .ftop.input.b.examineSteer -side right -anchor e
        }

        if {$exIsteerBtn != "!" } {
          SnazzyButton::setText .ftop.input.b.examineISteer $exIsteerBtn 0.5
          pack .ftop.input.b.examineISteer -side right -anchor ne
        }
        
        if {$isBtn != "!"} {
          SnazzyButton::setText .ftop.input.b.reconfigIS $isBtn 0.5
          pack .ftop.input.b.reconfigIS -side right -anchor ne
        }
        
        if {$rcBtn != "!"} {
          SnazzyButton::setText .ftop.input.b.reconfig $rcBtn 0.5
          pack .ftop.input.b.reconfig -side right -anchor ne
        }
    }
    
    proc actEnableUsrSAMConfig {samConfigTitle hint1 hint2 hint3 hint4 \
                                rcBtn isBtn} {
        global huge_font big_font small_font medium_font

        pack .ftop.display.steps -side top
        
        .ftop.title configure -text $samConfigTitle -font $huge_font
        
        .ftop.display.steps.l1 configure -text $hint1 -font $medium_font
        pack .ftop.display.steps.l1 -side top -anchor nw
        
        .ftop.display.steps.l2 configure -text $hint2 -font $medium_font
        pack .ftop.display.steps.l2 -side top -anchor nw -pady 10 -padx 20 
        
        .ftop.display.steps.l3 configure -text $hint3 -font $medium_font
        pack .ftop.display.steps.l3 -side top -anchor nw -pady 5 -padx 20 
        
        .ftop.display.steps.l4 configure -text $hint4 -font $medium_font
        pack .ftop.display.steps.l4 -side top -anchor nw -pady 5 -padx 20  
        
        SnazzyButton::setText .ftop.input.b.reconfigIS $isBtn 0.5
        pack .ftop.input.b.reconfigIS -side right -anchor ne -padx 5
        
        SnazzyButton::setText .ftop.input.b.reconfig $rcBtn 0.5
        pack .ftop.input.b.reconfig -side right -anchor ne

    }

    proc actDisableButtons {} {

        .ftop.input.b.examineSteer configure -state disabled
        .ftop.input.b.examineISteer configure -state disabled
        .ftop.input.b.reconfig configure -state disabled
        .ftop.input.b.reconfigIS configure -state disabled
        .ftop.input.b.cancel configure -state disabled
    }

    proc actListboxInsert { item } {
        .ftop.input.listdevframe.lbox insert end $item
        .ftop.input.listdevframe.lbox selection set 0
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.input.listdevframe.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.input.listdevframe.lbox selection set $index
        .ftop.input.listdevframe.lbox see $index
    }

    proc actListboxGetCurselection {} {
        if { [.ftop.input.listdevframe.lbox index end] != 0} {
            set index [lindex [.ftop.input.listdevframe.lbox curselection] 0]
            return [.ftop.input.listdevframe.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }

    proc actListboxGetCurindex {} {
      if { [.ftop.input.listdevframe.lbox index end] != 0} {
          return [lindex [.ftop.input.listdevframe.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }
}
