##############################################################################
#
# vc/src/tcl/leverArmDisplay.tcl
#
# Screen to adjust forward, right and down lever arm.
#
# 20021104 QC - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Space for title"

    # Input frame
    frame .ftop.input

    # Row 0
    frame .ftop.input.r0
    label .ftop.input.r0.l -text "Space for subtitle" -font $huge_font \
                -width 20 -anchor e
    pack .ftop.input.r0.l -side left -pady 5

    # Row 1
    frame .ftop.input.r1
    label .ftop.input.r1.l -text "Forward:" -font $big_font \
                -width 15 -anchor e
    label .ftop.input.r1.e -text "xx meters" -font $big_font \
                -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r1.l -side left -pady 5
    pack .ftop.input.r1.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r1.b btnBlueMU btnBlueMD 0.5 \
                "beepOnce; post $DISP_BTN2_SIG 2;" "Adjust"
#    button .ftop.input.r1.b -text "Adjust" -justify right \
#            -height 2 -width 8 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN2_SIG 2; } 
    pack .ftop.input.r1.b -side right
            
       
    # Row 2
    frame .ftop.input.r2
    label .ftop.input.r2.l -text "Right:" -font $big_font -width 15 -anchor e
    label .ftop.input.r2.e -text "xx meters" -font $big_font \
                  -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r2.l -side left -pady 5 -anchor w
    pack .ftop.input.r2.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r2.b btnBlueMU btnBlueMD 0.5 \
                  "beepOnce; post $DISP_BTN3_SIG 3;" "Adjust"
#    button .ftop.input.r2.b -text "Adjust" -justify right \
#            -height 2 -width 8 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN3_SIG 3; }
    pack .ftop.input.r2.b -side right        
    
    # Row 3
    frame .ftop.input.r3
    label .ftop.input.r3.l -text "Down:" -font $big_font -width 15 -anchor e
    label .ftop.input.r3.e -text "xx meters" -font $big_font \
                  -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r3.l -side left -pady 5 -anchor w
    pack .ftop.input.r3.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r3.b btnBlueMU btnBlueMD 0.5 \
                  "beepOnce; post $DISP_BTN4_SIG 4;" "Change"
#    button .ftop.input.r3.b -text "Change" -justify right \
#            -height 2 -width 8 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN4_SIG 4; }
    pack .ftop.input.r3.b -side right        

    # Pack rows
    pack .ftop.input.r0 -side top -anchor w -fill x
    pack .ftop.input.r1 -side top -anchor w -fill x
    pack .ftop.input.r2 -side top -anchor w -fill x
    pack .ftop.input.r3 -side top -anchor w -fill x
    
    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;" "Return To Previous Menu"
    SnazzyButton::create .ftop.input2.accept btnBlueU btnBlueD 0.5 \
                 "beepOnce; post $DISP_BTN1_SIG 1;" "Accept/Confirm"            
#    button .ftop.input2.cancel -text "Return To Previous Menu" \
#            -width 10 -height 6 \
#            -background $color5 -activebackground $color5 \
#            -command {beepOnce; post $DISP_BTN0_SIG 0; }
#    button .ftop.input2.accept -text "Accept/Confirm" \
#            -width 10 -height 6 \
#            -background $color3 -activebackground $color3 \
#            -command {beepOnce; post $DISP_BTN1_SIG 1; }
        
    pack .ftop.input2.cancel -side left -padx 10 -pady 10
    pack .ftop.input2.accept -side right -padx 10 -pady 10

    # Pack .ftop
    pack .ftop.title -side top -pady 10 -fill both -expand yes
    pack .ftop.input -side top -pady 10 -pady 5
    pack .ftop.input2 -side bottom -anchor se -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {titleLbl subtitleLbl forwardLbl rightLbl downLbl \
                   adjustBtn returnBtn acceptBtn} {
        .ftop.title configure -text $titleLbl
        .ftop.input.r0.l configure -text $subtitleLbl
        .ftop.input.r1.l configure -text $forwardLbl
        .ftop.input.r2.l configure -text $rightLbl
        .ftop.input.r3.l configure -text $downLbl
        SnazzyButton::setText .ftop.input.r1.b $adjustBtn 0.5
        SnazzyButton::setText .ftop.input.r2.b $adjustBtn 0.5
        SnazzyButton::setText .ftop.input.r3.b $adjustBtn 0.5
        SnazzyButton::setText .ftop.input2.cancel $returnBtn 0.5
        SnazzyButton::setText .ftop.input2.accept $acceptBtn 0.5
#        .ftop.input.r1.b configure -text $adjustBtn
#        .ftop.input.r2.b configure -text $adjustBtn
#        .ftop.input.r3.b configure -text $adjustBtn
#        .ftop.input2.cancel configure -text $returnBtn
#        .ftop.input2.accept configure -text $acceptBtn
        
        pack .ftop -fill both -expand yes
    }


    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actDisplayLeverArm {forward right down} {
        .ftop.input.r1.e configure -text $forward
        .ftop.input.r2.e configure -text $right
        .ftop.input.r3.e configure -text $down
    }

    proc actDisplayLeverArmX {forward} {
        .ftop.input.r1.e configure -text $forward
    }

    proc actDisplayLeverArmY {right} {
        .ftop.input.r2.e configure -text $right
    }
    
    proc actDisplayLeverArmZ {down} {
        .ftop.input.r3.e configure -text $down
    }
    
    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
