##############################################################################
#
# vc/src/tcl/movingMapConfig.tcl
#
# Screen to display moving map configuration options.  These configuration 
# options are divided into two aspects of the moving map screen, coverage and
# guidence.  The options provided for the coverage maps are display and
# record, while the options for guidence are only record.
#
# 20060119 RCM - created
#
# Copyright (c) 2006 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    
    # Main title text frame and label
    #-------------------------------------------------------------------------
    frame .ftop.title
    label .ftop.title.text -text "Space for title" -font $huge_font
    pack .ftop.title.text -side top -fill x -expand yes
    pack .ftop.title -side top -fill x -expand yes -anchor n -pady 20

        
    # Coverage map configuration options
    #-------------------------------------------------------------------------
    #...title, display and record frames
    frame .ftop.coverageOpt -bd 1 -relief solid
    frame .ftop.coverageOpt.title -bd 1 -relief solid
    frame .ftop.coverageOpt.main -bd 1 -relief solid
    frame .ftop.coverageOpt.main.display 
    frame .ftop.coverageOpt.main.record
    
    #...title, display and record labels
    label .ftop.coverageOpt.title.text -text "Space for Title" \
                                       -font $big_font
    label .ftop.coverageOpt.main.display.text -text "Space for Title" \
                                              -font $medium_font -width 19 
    label .ftop.coverageOpt.main.record.text -text "Space for Title" \
                                        -font $medium_font -width 15
                                        
    #...display options radio buttons 
    radiobutton .ftop.coverageOpt.main.display.b0 -text "Opt 1" -height 2 \
     -anchor w -variable cDispOption -value 1 -relief solid -bd 1 \
     -bg $colorBlueBtn -image imgCoverageDispPoly -height 30 \
     -activebackground $colorBlueBtn -compound left   
    radiobutton .ftop.coverageOpt.main.display.b1 -text "Opt 2" -height 2 \
     -anchor w -variable cDispOption -value 2 -relief solid -bd 1 \
     -bg $colorBlueBtn -image imgCoverageDispWire -height 30 \
     -activebackground $colorBlueBtn -compound left 
    radiobutton .ftop.coverageOpt.main.display.b2 -text "Opt 3" -height 2 \
     -anchor w -variable cDispOption -value 3 -relief solid -bd 1 \
     -bg $colorBlueBtn -image imgCoverageDispBoom -height 30 \
     -activebackground $colorBlueBtn -compound left 
    
    #...record options radio buttons
    radiobutton .ftop.coverageOpt.main.record.b0 -text "Opt 1" -height 2 \
     -anchor w -variable cRecOption -value 1 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
    radiobutton .ftop.coverageOpt.main.record.b1 -text "Opt 2" -height 2 \
     -anchor w -variable cRecOption -value 2 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
    radiobutton .ftop.coverageOpt.main.record.b2 -text "Opt 3" -height 2 \
     -anchor w -variable cRecOption -value 3 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
    radiobutton .ftop.coverageOpt.main.record.b3 -text "Opt 4" -height 2 \
     -anchor w -variable cRecOption -value 4 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn     
    
     
    # Guidence map configuration options
    #-------------------------------------------------------------------------
    #...title and record frames
    frame .ftop.guidenceOpt -bd 1 -relief solid
    frame .ftop.guidenceOpt.title -bd 1 -relief solid
    frame .ftop.guidenceOpt.record -bd 1 -relief solid
    frame .ftop.space
    label .ftop.space.space -width 1
    
    #...title and record labels
    label .ftop.guidenceOpt.title.text -font $big_font
    label .ftop.guidenceOpt.record.text -font $medium_font
    
    #...record options radio buttons
    radiobutton .ftop.guidenceOpt.record.b0 -text "Opt 1" -height 2 \
      -anchor w -variable gRecOption -value 1 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
    radiobutton .ftop.guidenceOpt.record.b1 -text "Opt 2" -height 2 \
      -anchor w -variable gRecOption -value 2 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
    radiobutton .ftop.guidenceOpt.record.b2 -text "Opt 3" -height 2 \
      -anchor w -variable gRecOption -value 3 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
    radiobutton .ftop.guidenceOpt.record.b3 -text "Opt 4" -height 2 \
      -anchor w -variable gRecOption -value 4 -relief solid -bd 1 \
     -bg $colorBlueBtn -activebackground $colorBlueBtn 
            
    # Accept and Cancel buttons
    #-------------------------------------------------------------------------
    frame .ftop.buttons
    SnazzyButton::create .ftop.buttons.accept btnBlueU btnBlueD 0.5 \
      "beepOnce; post $DISP_BTN0_SIG 0;" "Accept"
    label .ftop.buttons.space -width 1
    
    frame .ftop.buttons.pointSpacing -bd 1 -relief solid
    frame .ftop.buttons.pointSpacing.top -bd 1 -relief solid
    label .ftop.buttons.pointSpacing.top.captionLbl -text "Point Spacing:" \
      -font $big_font 
    label .ftop.buttons.pointSpacing.top.unitLbl -text "Units:" \
      -font $big_font
    label .ftop.buttons.pointSpacing.top.spacingDisp -text "0.0" \
      -relief sunken -width 8 -font $big_font
                                             
    SnazzyButton::create .ftop.buttons.pointSpacing.top.edit \
      btnBlueMU btnBlueMD 0.5 "beepOnce; post $DISP_BTN1_SIG 1;" "Edit"
    
    pack .ftop.buttons.space -side right -anchor se
    pack .ftop.buttons.accept -side right -anchor se
    pack .ftop.buttons.pointSpacing.top.captionLbl -side left -padx 23
    pack .ftop.buttons.pointSpacing.top.spacingDisp -side left -padx 10
    pack .ftop.buttons.pointSpacing.top.unitLbl -side left -padx 10
    pack .ftop.buttons.pointSpacing.top.edit -side left -padx 10
    pack .ftop.buttons.pointSpacing.top -side top -anchor nw \
      -fill x -expand yes 
    #pack .ftop.buttons.pointSpacing -side left -anchor nw -padx 20 -pady 10       
    pack .ftop.buttons -side bottom -anchor s -pady 7 -fill x -expand yes
            
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { title__ editBtn__  pointSpacingTxtLbl__ \
                    pointSpacingUnitsLbl__ acceptBtn__ } {
      
      .ftop.title.text configure -text $title__ 
      .ftop.buttons.accept configure -text $acceptBtn__ 
      .ftop.buttons.pointSpacing.top.edit configure -text $editBtn__
      .ftop.buttons.pointSpacing.top.unitLbl configure -text "Meters"
      .ftop.buttons.pointSpacing.top.captionLbl configure \
        -text $pointSpacingTxtLbl__
        
      pack .ftop -fill both -expand yes    
    }

    proc actDispCoverageOptionsMenu { title__ \
                                      dispOptTitle__ \
                                      recOptTitle__ \
                                      b0Text__ b0Id__ b0State__ \
                                      b1Text__ b1Id__ b1State__ \
                                      b2Text__ b2Id__ b2State__ \
                                      b3Text__ b3Id__ b3State__ \
                                      b4Text__ b4Id__ b4State__ \
                                      b5Text__ b5Id__ b5State__ \
                                      b6Text__ b6Id__ b6State__ } {
      
      .ftop.coverageOpt.title.text configure -text $title__
      .ftop.coverageOpt.main.display.text configure -text $dispOptTitle__ 
      .ftop.coverageOpt.main.record.text configure -text $recOptTitle__
            
      # Display Options
      .ftop.coverageOpt.main.display.b0 configure -text $b0Text__ \
         -command "beepOnce; post \$DISP_BTN5_SIG $b0Id__"  
      if {$b0State__ == 1} {
        .ftop.coverageOpt.main.display.b0 select
      } else {
        .ftop.coverageOpt.main.display.b0 deselect
      }
      
      .ftop.coverageOpt.main.display.b1 configure -text $b1Text__ \
        -command "beepOnce; post \$DISP_BTN5_SIG $b1Id__"      
      if {$b1State__ == 1} {
        .ftop.coverageOpt.main.display.b1 select
      } else {
        .ftop.coverageOpt.main.display.b1 deselect
      }
      
      .ftop.coverageOpt.main.display.b2 configure -text $b2Text__ \
        -command "beepOnce; post \$DISP_BTN5_SIG $b2Id__"          
      if {$b2State__ == 1} {
        .ftop.coverageOpt.main.display.b2 select
      } else {
        .ftop.coverageOpt.main.display.b2 deselect
      }
      
      # Record Options
      .ftop.coverageOpt.main.record.b0 configure -text $b3Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b3Id__"
      if {$b3State__ == 1} {
        .ftop.coverageOpt.main.record.b0 select
      } else {
        .ftop.coverageOpt.main.record.b0 deselect
      }
      
      .ftop.coverageOpt.main.record.b1 configure -text $b4Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b4Id__"
      if {$b4State__ == 1} {
        .ftop.coverageOpt.main.record.b1 select
      } else {
        .ftop.coverageOpt.main.record.b1 deselect
      }
                
      .ftop.coverageOpt.main.record.b2 configure -text $b5Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b5Id__"
      if {$b5State__ == 1} {
        .ftop.coverageOpt.main.record.b2 select
      } else {
        .ftop.coverageOpt.main.record.b2 deselect
      }
            
      .ftop.coverageOpt.main.record.b3 configure -text $b6Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b6Id__"
      if {$b6State__ == 1} {
        .ftop.coverageOpt.main.record.b3 select
      } else {
        .ftop.coverageOpt.main.record.b3 deselect
      }
                  
      pack .ftop.coverageOpt.main.display.text -side top -expand yes -pady 5
      pack .ftop.coverageOpt.main.display.b0 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.display.b1 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.display.b2 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.display -side left -anchor nw -expand yes
      pack .ftop.coverageOpt.main.record.text -side top -expand yes -pady 5
      pack .ftop.coverageOpt.main.record.b0 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.record.b1 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.record.b2 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.record.b3 -side top -fill x -padx 5 -pady 5
      pack .ftop.coverageOpt.main.record -side right -anchor ne
      pack .ftop.coverageOpt.main -side bottom -expand yes -fill x
      pack .ftop.coverageOpt.title.text -side top
      pack .ftop.coverageOpt.title -side top -fill x -expand yes   
      pack .ftop.coverageOpt -side left -padx 20
    }
    
    proc actDispGuidanceOptionsMenu { title__ \
                                      recOptTitle__ \
                                      b0Text__ b0Id__ b0State__ \
                                      b1Text__ b1Id__ b1State__ \
                                      b2Text__ b2Id__ b2State__ \
                                      b3Text__ b3Id__ b3State__} {
      
      .ftop.guidenceOpt.title.text configure -text $title__        
      .ftop.guidenceOpt.record.text configure -text $recOptTitle__
      
      .ftop.guidenceOpt.record.b0 configure -text $b0Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b0Id__"  
      if {$b0State__ == 1} {
        .ftop.guidenceOpt.record.b0 select
      } else {
        .ftop.guidenceOpt.record.b0 deselect
      }
            
      .ftop.guidenceOpt.record.b1 configure -text $b1Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b1Id__"
      if {$b1State__ == 1} {
        .ftop.guidenceOpt.record.b1 select
      } else {
        .ftop.guidenceOpt.record.b1 deselect
      }
                
      .ftop.guidenceOpt.record.b2 configure -text $b2Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b2Id__"
      if {$b2State__ == 1} {
        .ftop.guidenceOpt.record.b2 select
      } else {
        .ftop.guidenceOpt.record.b2 deselect
      }
            
      .ftop.guidenceOpt.record.b3 configure -text $b3Text__ \
        -command "beepOnce; post \$DISP_BTN6_SIG $b3Id__"
      if {$b3State__ == 1} {
        .ftop.guidenceOpt.record.b3 select
      } else {
        .ftop.guidenceOpt.record.b3 deselect
      }
                
      pack .ftop.guidenceOpt.title.text -side top -fill x -expand yes \
                                        -anchor nw
      pack .ftop.guidenceOpt.record.text -side top -fill x -expand yes \
                                         -anchor nw -pady 5
      pack .ftop.guidenceOpt.title -side top -anchor nw -fill x -expand yes
      pack .ftop.guidenceOpt.record -side top -anchor nw -fill x -expand yes      
      pack .ftop.guidenceOpt.record.b0 -side bottom -fill x -padx 5 -pady 5
      pack .ftop.guidenceOpt.record.b1 -side bottom -fill x -padx 5 -pady 5
      pack .ftop.guidenceOpt.record.b2 -side bottom -fill x -padx 5 -pady 5
      pack .ftop.guidenceOpt.record.b3 -side bottom -fill x -padx 5 -pady 5     
      pack .ftop.space.space -side top
      pack .ftop.space -side right
      pack .ftop.guidenceOpt -side left -expand yes -fill x
    }
    
    proc actDisplayCoverageOptionLeft { } {
      pack .ftop.coverageOpt -side left -padx 20
    }
    
    proc actDisplayCoverageOptionCenter { } {
      pack .ftop.coverageOpt -side top
    }
    
    proc actDisplayCoverageRecordSpacing { recordSpacing__ } {
      .ftop.buttons.pointSpacing.top.spacingDisp configure \
        -text $recordSpacing__  
    }
           
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
           
  }