##############################################################################
#
# vc/src/tcl/menu.tcl
#
# A configurable, reusable 8 button menu screen. Includes listbox with 
# scrollbar if desired.
#
# 20020701 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames
    # .configDisplay, and .navDisplay components)
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame

    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes
    pack .configDisplay -in .ftop -side left \
            -anchor nw -fill y -expand yes -padx 10 -pady 10
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor ne -padx 10 -pady 10
    raise .navDisplay

    # Secret Button
    button .ftop.display.s -height 5 -width 5 \
            -command {beepOnce; post $DISP_BTN2_SIG 2 } \
            -borderwidth 0 -state normal \
            -background $color6 -highlightbackground $color6 \
            -activebackground $color6
    
    # Wait Message
    label .ftop.waitText
    
    # Exit button
    SnazzyButton::create .ftop.input.exit btnExitKhakiU btnExitKhakiD 0.2 \
            "beepOnce; guiExit" "Exit"
    
    SnazzyButton::create .ftop.input.cancel btnKhakiU btnKhakiD 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Cancel"

    # Display Frame - displays up to 6 lines of text
    label .ftop.display.l0 -text "line 0"
    label .ftop.display.l1 -text "line 1" -font $big_font
    label .ftop.display.l2 -text "line 2" -font $big_font
    label .ftop.display.l3 -text "line 3" -font $big_font
    label .ftop.display.l4 -text "line 4" -font $big_font
    label .ftop.display.l5 -text "line 5" -font $big_font

    # Display Row 1 frame
    frame .ftop.display.r1
    label .ftop.display.r1.l0 -text "North" -font $big_font \
            -width 7
    label .ftop.display.r1.e0 -text "north feet" -font $big_font \
            -width 18 -relief sunken -borderwidth 2 -anchor w
    label .ftop.display.r1.l1 -text "East" -font $big_font \
            -width 7 
    label .ftop.display.r1.e1 -text "east feet" -font $big_font \
            -width 18 -relief sunken -borderwidth 2 -anchor w

    # Display Row 2 frame
    frame .ftop.display.r2
    label .ftop.display.r2.l0 -text "Number of corners" \
            -font $big_font -width 32
    label .ftop.display.r2.e0 -text "nPoints_" -font $big_font \
            -width 6 -relief sunken -borderwidth 2 -anchor w

    # Display Row 3 frame
    frame .ftop.display.r3
    label .ftop.display.r3.l0 -text "Number of rows:" \
            -font $big_font -width 32
    label .ftop.display.r3.e0 -text "0" -font $big_font \
            -width 24 -relief sunken -borderwidth 2 -anchor w

    # Display Row 4 frame
    frame .ftop.display.r4
    label .ftop.display.r4.l0 -text "Number of rows:" \
            -font $big_font -width 32
    label .ftop.display.r4.e0 -text "0" -font $big_font \
            -width 24 -relief sunken -borderwidth 2 -anchor w
    
    
    # Input frame 
    #   - up to 2 rows of up to 4 buttons each
    #   - or a scrolling listbox, with up to two rows of 2 rows 2 buttons each
    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.b0 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 0" "Button 0"
    SnazzyButton::create .ftop.input.r1.b1 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN1_SIG 1" "Button 1"
    SnazzyButton::create .ftop.input.r1.b2 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 2" "Button 2"
    SnazzyButton::create .ftop.input.r1.b3 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN3_SIG 3" "Button 3"
    SnazzyButton::create .ftop.input.r1.b8 btnYellowU btnYellowD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 8" "Button 8"

    SnazzyButton::create .ftop.input.r1.b8b btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 8" "Button 8"
            
    # row 1 wizard buttons
    SnazzyButton::create .ftop.input.r1.bwg0 btnGrayU btnGrayD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 0" "Button 0"
    SnazzyButton::create .ftop.input.r1.bwb0 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 0" "Button 0"

    SnazzyButton::create .ftop.input.r1.bwc0 btnBlueUChecked btnBlueDChecked 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 0" "Button 0"

    # row 1 warning buttons
    SnazzyButton::create .ftop.input.r1.bA btnAcceptU btnAcceptD 0.2 \
                         "beepOnce; post $DISP_BTN0_SIG 0"
    SnazzyButton::create .ftop.input.r1.bR btnRejectU btnRejectD 0.25 \
                         "beepOnce; post $DISP_BTN1_SIG 1"

    SnazzyButton::create .ftop.input.r1.bwg1 btnGrayU btnGrayD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 1" "Button 1"
    SnazzyButton::create .ftop.input.r1.bwb1 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN1_SIG 1" "Button 1"
    SnazzyButton::create .ftop.input.r1.bwc1 btnBlueUChecked btnBlueDChecked 0.5 \
            "beepOnce; post $DISP_BTN1_SIG 1" "Button 1"
    SnazzyButton::create .ftop.input.r1.bwg2 btnGrayU btnGrayD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 2" "Button 2"
    SnazzyButton::create .ftop.input.r1.bwb2 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 2" "Button 2"
    SnazzyButton::create .ftop.input.r1.bwc2 btnBlueUChecked btnBlueDChecked 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 2" "Button 2"
    SnazzyButton::create .ftop.input.r1.bwg3 btnGrayU btnGrayD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 3" "Button 3"
    SnazzyButton::create .ftop.input.r1.bwb3 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN3_SIG 3" "Button 3"
    SnazzyButton::create .ftop.input.r1.bwc3 btnBlueUChecked btnBlueDChecked 0.5 \
            "beepOnce; post $DISP_BTN3_SIG 3" "Button 3"

    frame .ftop.input.r2
    SnazzyButton::create .ftop.input.r2.b4 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN4_SIG 4" "Button 4"
    SnazzyButton::create .ftop.input.r2.b5 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN5_SIG 5" "Button 5"
    SnazzyButton::create .ftop.input.r2.b6 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN6_SIG 6" "Button 6"
    SnazzyButton::create .ftop.input.r2.b7 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN7_SIG 7" "Button 7"
    SnazzyButton::create .ftop.input.r2.b8 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 8" "Button 8"

    # row 2 wizard button
    SnazzyButton::create .ftop.input.r2.bwg6 btnGrayU btnGrayD 0.5 \
            "beepOnce; post $DISP_BTN8_SIG 6" "Button 6"
    SnazzyButton::create .ftop.input.r2.bwb6 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN6_SIG 6" "Button 6"
    SnazzyButton::create .ftop.input.r2.bwc6 btnBlueUChecked btnBlueDChecked 0.5 \
            "beepOnce; post $DISP_BTN6_SIG 6" "Button 6"

    # Heading select frame
    # {MLE-030220: Is this an abuse of menu.tcl? Do we need a separate .tcl 
    # file?}
    frame .ftop.input.headingselect
    frame .ftop.input.headingselect.col1
    frame .ftop.input.headingselect.col2
    SnazzyButton::create .ftop.input.headingselect.col1.b0 btnBlueM3U \
            btnBlueM3D 0.5 "beepOnce; post $DISP_BTN0_SIG 0" "Button 0"
    SnazzyButton::create .ftop.input.headingselect.col1.b1 btnBlueM3U \
            btnBlueM3D 0.5 "beepOnce; post $DISP_BTN1_SIG 1" "Button 1"
    SnazzyButton::create .ftop.input.headingselect.col1.b2 btnBlueM3U \
            btnBlueM3D 0.5 "beepOnce; post $DISP_BTN2_SIG 2" "Button 2"
    SnazzyButton::create .ftop.input.headingselect.col1.b3 btnBlueM3U \
            btnBlueM3D 0.5 "beepOnce; post $DISP_BTN3_SIG 3" "Button 3"
    SnazzyButton::create .ftop.input.headingselect.col2.b4 btnBlueM3U \
            btnBlueM3D 0.5 "beepOnce; post $DISP_BTN4_SIG 4" "Button 4"
    SnazzyButton::create .ftop.input.headingselect.col2.b5 btnBlueM3U \
            btnBlueM3D 0.5 "beepOnce; post $DISP_BTN5_SIG 5" "Button 5"

    canvas .ftop.input.c -width 200 -height 200 \
            -relief sunken -borderwidth 1 
    global compassCenterX compassCenterY
    global compassCircleRad compassTextRad compassTickRad compassText
    global compassNorthTick compassNorthText
    global compassEastTick compassEastText
    global compassSouthTick compassSouthText
    global compassWestTick compassWestText
    global yawDeg
    
    #---------------------------------------------
    # Canvas for compass heading display
    # 
    set compassCenterX     82 
    set compassCenterY    110 
    set compassCircleRad   70
    set compassTextRad     80
    set compassTickRad      3

    .ftop.input.c create oval \
            [expr $compassCenterX-$compassCircleRad]\
            [expr $compassCenterY-$compassCircleRad]\
            [expr $compassCenterX+$compassCircleRad]\
            [expr $compassCenterY+$compassCircleRad]
    .ftop.input.c create rectangle \
            [expr $compassCenterX-10] [expr $compassCenterY-20] \
            [expr $compassCenterX+10] [expr $compassCenterY+20] \
            -fill $colorGood -outline black
    .ftop.input.c create rectangle \
            [expr $compassCenterX-15] [expr $compassCenterY-20] \
            [expr $compassCenterX-12] [expr $compassCenterY-12] \
            -fill black -outline black
    .ftop.input.c create rectangle \
            [expr $compassCenterX+12] [expr $compassCenterY-20] \
            [expr $compassCenterX+15] [expr $compassCenterY-12] \
            -fill black -outline black
    .ftop.input.c create rectangle \
            [expr $compassCenterX-18] [expr $compassCenterY+10] \
            [expr $compassCenterX-12] [expr $compassCenterY+20] \
            -fill black -outline black
    .ftop.input.c create rectangle \
            [expr $compassCenterX+12] [expr $compassCenterY+10] \
            [expr $compassCenterX+18] [expr $compassCenterY+20] \
            -fill black -outline black

    set compassText [.ftop.input.c create text 82 15 -justify center ]
    set compassNorthTick [.ftop.input.c create oval 0 0 0 0 -fill black]
    set compassNorthText  [.ftop.input.c create text 0 0 -text N]
    set compassEastTick [.ftop.input.c create oval 0 0 0 0 -fill black]
    set compassEastText  [.ftop.input.c create text 0 0 -text E]
    set compassSouthTick [.ftop.input.c create oval 0 0 0 0 -fill black]
    set compassSouthText [.ftop.input.c create text 0 0 -text S]
    set compassWestTick [.ftop.input.c create oval 0 0 0 0 -fill black]
    set compassWestText  [.ftop.input.c create text 0 0 -text W]

    # {MLE-020701: Are these -commands too intelligent?}
    scrollbar .ftop.input.sbar -command { .ftop.input.lbox yview }
    listbox .ftop.input.lbox -yscrollcommand {.ftop.input.sbar set} \
            -width 16 -height 8

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
        
        eval $packProc__
        pack .ftop -fill both -expand yes
        #testPackAll8
        #testPackListBox
        #testPackYesNo
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }


    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actConfigAndPackButton { num__ configArgs__ packArgs__ } {
        
        eval {.ftop.input.r1.b$num__ configure} $configArgs__
        eval {pack .ftop.input.r1.b$num__} $packArgs__

    }

    set wasReady 1            ;# we initially pack the "Begin Autofarm" button
    ;# {MLE-030704: Too clever! Tcl should not have memory!}
    proc actConfigBeginBtn {isReady} {
        global Screen::wasReady
        if {$Screen::wasReady == 0 && $isReady == 1} {
            pack forget .ftop.input.r1.b8
            pack .ftop.input.r1.b0 -before .ftop.input.r1.b1 \
                    -side right -padx 5 -pady 5
            set Screen::wasReady 1
        } 
        if {$Screen::wasReady == 1 && $isReady == 0} {
            pack forget .ftop.input.r1.b0
            pack .ftop.input.r1.b8 -before .ftop.input.r1.b1 \
                    -side right -padx 5 -pady 5
            set Screen::wasReady 0
        }
    }

    proc actConfigAndPackDisplayLine { num__ configArgs__ packArgs__ } {
        
        global medium_font big_font huge_font
        eval {.ftop.display.l$num__ configure} $configArgs__
        eval {pack .ftop.display.l$num__} $packArgs__

    }


    proc actListboxInsert { item__ } {
        .ftop.input.lbox insert end $item__
    }
    

    proc actListboxSelectionSet { item__ } {
        .ftop.input.lbox selection set $item__
    }

    proc actListboxGetCurselection {} {
        if { [.ftop.input.lbox index end] != 0} {
            set index [lindex [.ftop.input.lbox curselection] 0]
            return [.ftop.input.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }


    proc actListboxGetCurindex {} {
        if { [.ftop.input.lbox index end] != 0} {
            return [lindex [.ftop.input.lbox curselection] 0]
        } else {
            return -1             ;# -1 tells the C side the listbox was empty
        }
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.input.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.input.lbox selection set $index
        .ftop.input.lbox see $index
    }
    

    proc actListboxDeleteAll { } {
        .ftop.input.lbox delete 0 end
    }
    
    proc actDisableReturnBtn {} {
        .ftop.input.cancel configure -state disabled
    }
    
    proc actDisplayPosition {north east} {
        .ftop.display.r1.e0 configure -text $north
        .ftop.display.r1.e1 configure -text $east
    }

    proc actDisplayNumOfPoints {name__ points__ area__} {
        .ftop.display.r2.e0 configure -text $points__
    }

    proc actDisplayFanSpacing {wideEnd narrowEnd nRows} {
        global big_font
        .ftop.display.l1 configure -text $wideEnd -font $big_font
        .ftop.display.l2 configure -text $narrowEnd -font $big_font
        .ftop.display.l3 configure -text $nRows -font $big_font
    }

    proc actDisplayCurveSpacing {implWidth propDist minWidth maxWidth} {
        global big_font
        .ftop.display.l1 configure -text $implWidth -font $big_font
        .ftop.display.l2 configure -text $propDist -font $big_font
        .ftop.display.l3 configure -text $minWidth -font $big_font
        .ftop.display.l4 configure -text $maxWidth -font $big_font
    }

    proc actHeading {headingBtn yaw yawDeg yawHighResDegrees} {

        global huge_font big_font colorGood color3 color0 \
                compassCenterX compassCenterY compassCircleRad \
                compassTextRad compassTickRad \
                compassText \
                compassNorthTick compassNorthText \
                compassEastTick compassEastText \
                compassSouthTick compassSouthText \
                compassWestTick compassWestText
        
        set cosYaw [expr cos($yaw)]
        set sinYaw [expr sin($yaw)]
        
        .ftop.input.c itemconfigure $Screen::compassText -text $yawDeg
        SnazzyButton::setText .ftop.input.headingselect.col2.b4 \
                "$headingBtn$yawDeg" 0.5

        set x [expr $Screen::compassCenterX-$Screen::compassCircleRad*$sinYaw]
        set y [expr $Screen::compassCenterY-$Screen::compassCircleRad*$cosYaw]
        .ftop.input.c coords $Screen::compassNorthTick \
                [expr $x-$Screen::compassTickRad] [expr $y-$Screen::compassTickRad]\
                [expr $x+$Screen::compassTickRad] [expr $y+$Screen::compassTickRad]
        set x [expr $Screen::compassCenterX-$Screen::compassTextRad*$sinYaw]
        set y [expr $Screen::compassCenterY-$Screen::compassTextRad*$cosYaw]
        .ftop.input.c coords $Screen::compassNorthText $x $y
        
        set x [expr $Screen::compassCenterX+$Screen::compassCircleRad*$cosYaw]
        set y [expr $Screen::compassCenterY-$Screen::compassCircleRad*$sinYaw]
        .ftop.input.c coords $Screen::compassEastTick \
                [expr $x-$Screen::compassTickRad] [expr $y-$Screen::compassTickRad]\
                [expr $x+$Screen::compassTickRad] [expr $y+$Screen::compassTickRad]
        set x [expr $Screen::compassCenterX+$Screen::compassTextRad*$cosYaw]
        set y [expr $Screen::compassCenterY-$Screen::compassTextRad*$sinYaw]
        .ftop.input.c coords $Screen::compassEastText $x $y
        
        set x [expr $Screen::compassCenterX+$Screen::compassCircleRad*$sinYaw]
        set y [expr $Screen::compassCenterY+$Screen::compassCircleRad*$cosYaw]
        .ftop.input.c coords $Screen::compassSouthTick \
                [expr $x-$Screen::compassTickRad] [expr $y-$Screen::compassTickRad]\
                [expr $x+$Screen::compassTickRad] [expr $y+$Screen::compassTickRad]
        set x [expr $Screen::compassCenterX+$Screen::compassTextRad*$sinYaw]
        set y [expr $Screen::compassCenterY+$Screen::compassTextRad*$cosYaw]
        .ftop.input.c coords $Screen::compassSouthText $x $y
        
        set x [expr $Screen::compassCenterX-$Screen::compassCircleRad*$cosYaw]
        set y [expr $Screen::compassCenterY+$Screen::compassCircleRad*$sinYaw]
        .ftop.input.c coords $Screen::compassWestTick \
                [expr $x-$Screen::compassTickRad] [expr $y-$Screen::compassTickRad]\
                [expr $x+$Screen::compassTickRad] [expr $y+$Screen::compassTickRad]
        set x [expr $Screen::compassCenterX-$Screen::compassTextRad*$cosYaw]
        set y [expr $Screen::compassCenterY+$Screen::compassTextRad*$sinYaw]
        .ftop.input.c coords $Screen::compassWestText $x $y
        
    }

    proc actConfigSensorButtons {posImgU posImgD attImgU attImgD \
                                 steerImgU steerImgD \
                                 isteerAttImgU isteerAttImgD \
                                 isteerSteerImgU isteerSteerImgD} {

        SnazzyButton::setImage .ftop.input.r1.b0 \
                $steerImgU $steerImgD 0.5
        SnazzyButton::setImage .ftop.input.r1.b1 \
                $attImgU $attImgD 0.5
        SnazzyButton::setImage .ftop.input.r1.b2 \
                $posImgU $posImgD 0.5
        if {$isteerAttImgU != "!"} {
          SnazzyButton::setImage .ftop.input.r2.b6 \
                  $isteerAttImgU $isteerAttImgD 0.5
        }
        if {$isteerSteerImgU != "!"} {
          SnazzyButton::setImage .ftop.input.r2.b4 \
                  $isteerSteerImgU $isteerSteerImgD 0.5
        }
    }        
    
    proc actToggleDataSaving {} {
    }

    proc actConfigureStartLogging { startBtn clearBtn viewmapBtn } {

        pack forget .ftop.input.r2.b5
        pack forget .ftop.input.r2
        pack forget .ftop.input.r1
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        # Disable View map button for now.  This feature is becoming obsolete
        # due to the introduction of coverage maps in the earth release
        #pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        SnazzyButton::setText .ftop.input.r1.b0 $clearBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $viewmapBtn 0.5        
        SnazzyButton::setText .ftop.input.r2.b4 $startBtn 0.5

    }
    
    proc actConfigureStopLogging { stopBtn } {

        pack forget .ftop.input.r2.b4
        pack forget .ftop.input.r1.b0
        pack forget .ftop.input.r1.b1
        pack forget .ftop.input.r1
        pack forget .ftop.input.r2
        
        pack .ftop.input.r2.b5 -side bottom -anchor se -padx 5 -pady 5
        pack .ftop.input.r2 -side bottom -anchor se
        
        SnazzyButton::setImage .ftop.input.r2.b5 \
                btnRedU btnRedD 0.5        
        SnazzyButton::setText .ftop.input.r2.b5 $stopBtn 0.5

    }
    
    proc actShowMeasuredDistance { dist maxDist slope slopedir } {
        .ftop.display.r1.e0 configure -text $dist
        .ftop.display.r2.e0 configure -text $maxDist
        .ftop.display.r3.e0 configure -text $slope
        .ftop.display.r4.e0 configure -text $slopedir
    }
    
    proc actPackMenuButton0 {text__} {
        SnazzyButton::setText .ftop.input.r1.b0 $text__ 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton1 {text__} {
        SnazzyButton::setText .ftop.input.r1.b1 $text__ 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton2 {text__} {
        SnazzyButton::setText .ftop.input.r1.b2 $text__ 0.5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton3 {text__} {
        SnazzyButton::setText .ftop.input.r1.b3 $text__ 0.5
        pack .ftop.input.r1.b3 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton4 {text__} {
        SnazzyButton::setText .ftop.input.r2.b4 $text__ 0.5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton5 {text__} {
        SnazzyButton::setText .ftop.input.r2.b5 $text__ 0.5
        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton6 {text__} {
        SnazzyButton::setText .ftop.input.r2.b6 $text__ 0.5
        pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
    }

    proc actPackMenuButton7 {text__} {
        SnazzyButton::setText .ftop.input.r2.b7 $text__ 0.5
        pack .ftop.input.r2.b7 -side right -padx 5 -pady 5
    }
    
    proc actDisableFieldButtons {} {
      .ftop.input.r1.b0 configure -state disabled
      .ftop.input.r1.b1 configure -state disabled
      .ftop.input.r2.b4 configure -state disabled
      .ftop.input.r2.b5 configure -state disabled
      .ftop.input.cancel configure -state disabled  
    }
    
    proc actEnableFieldButtons {} {
      .ftop.input.r1.b0 configure -state active
      .ftop.input.r1.b1 configure -state active
      .ftop.input.r2.b4 configure -state active
      .ftop.input.r2.b5 configure -state active
      .ftop.input.cancel configure -state active  
    }
    
    proc actDisableJobButtons {} {
      .ftop.input.r1.b0 configure -state disabled
      .ftop.input.r1.b1 configure -state disabled
      .ftop.input.r2.b4 configure -state disabled
      .ftop.input.r2.b5 configure -state disabled
      .ftop.input.cancel configure -state disabled  
    }
    
    proc actEnableJobButtons {} {
      .ftop.input.r1.b0 configure -state active
      .ftop.input.r1.b1 configure -state active
      .ftop.input.r2.b4 configure -state active
      .ftop.input.r2.b5 configure -state active
      .ftop.input.cancel configure -state active  
    }
    
    proc actShowWaitText { text__ } {
      .ftop.waitText configure -text $text__
      place .ftop.waitText -relx 0.53 -x -20 -rely 0.85 -y -20 -anchor se
    }
    
    proc actHideWaitText {} {
      place forget .ftop.waitText
    }

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
    proc testPackAll8 {} {

        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r2 -side bottom -fill both -expand yes
        pack .ftop.input.r1 -side bottom -fill both -expand yes

        pack .ftop.input.r1.b3 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        pack .ftop.input.r2.b7 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

        pack .ftop.display.l0 -side top -pady 5

    }


    proc testPackListBox {} {

        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.display.l0 -side top -pady 5

        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        pack .ftop.input.r2 -side bottom -fill both -expand yes
        pack .ftop.input.r1 -side bottom -fill both -expand yes

        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

    }


    proc testPackYesNo {} {

        pack  -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        pack .ftop.display.l0 -side top -pady 5
        pack .ftop.display.l1 -side top -pady 5
        pack .ftop.display.l2 -side top -pady 5

    }


    proc packConfirmShutdown {title noBtn yesBtn secretBtn} {

        global huge_font color0 color5 color6

        # configure and pack buttons and text
        .ftop.display.l0 configure -text $title \
                -font $huge_font
        SnazzyButton::setImage .ftop.input.r1.b1 \
                btnKhakiU btnKhakiD 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $noBtn 0.5                
        SnazzyButton::setImage .ftop.input.r1.b0 \
                btnRedU btnRedD 0.5
        SnazzyButton::setText .ftop.input.r1.b0 $yesBtn 0.5

        pack forget .navDisplay

        if {$secretBtn == 1} {
           pack .ftop.display.s -side bottom -anchor se
        }
        pack .navDisplay -in .ftop -side right -anchor ne -pady 10
        raise .navDisplay

        pack .ftop.input.r1 -side bottom -fill x -anchor se
        pack .ftop.input.r1.b1 -side left -padx 5 -pady 5 -anchor sw
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5 -anchor se
        pack .ftop.display.l0 -side top -pady 5

    }

    proc packConfirmReset {title noBtn yesBtn} {

        global huge_font color0 color5

        # configure and pack buttons and text
        .ftop.display.l0 configure -text $title \
                -font $huge_font
        SnazzyButton::setImage .ftop.input.r1.b1 \
                btnKhakiU btnKhakiD 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $noBtn 0.5                
        SnazzyButton::setImage .ftop.input.r1.b0 \
                btnRedU btnRedD 0.5
        SnazzyButton::setText .ftop.input.r1.b0 $yesBtn 0.5
        
        pack .ftop.input.r1 -side bottom -fill x -anchor se
        pack .ftop.input.r1.b1 -side left -padx 5 -pady 5 -anchor sw
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5 -anchor se

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packConfirmRMCodeUpload {title noBtn yesBtn} {

        global huge_font color0 color5

        # configure and pack buttons and text
        .ftop.display.l0 configure -text $title \
                -font $huge_font
        .ftop.display.l1 configure -text " " \
                -font $huge_font
        .ftop.display.l2 configure -text " " \
                -font $huge_font
        SnazzyButton::setImage .ftop.input.r1.b1 \
                btnKhakiU btnKhakiD 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $noBtn 0.5                
        SnazzyButton::setImage .ftop.input.r1.b0 \
                btnRedU btnRedD 0.5
        SnazzyButton::setText .ftop.input.r1.b0 $yesBtn 0.5
        
        pack .ftop.input.r1 -side bottom -fill x -anchor se
        pack .ftop.input.r1.b1 -side left -padx 5 -pady 5 -anchor sw
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5 -anchor se

        pack .ftop.display.l0 -side top -pady 5
        pack .ftop.display.l1 -side top
        pack .ftop.display.l2 -side top

    }

    proc actConfigNoBundleId { title txtLbl } {
        global huge_font
        .ftop.display.l0 configure -text $title \
                -font $huge_font
        .ftop.display.l1 configure -text $txtLbl \
                -font $huge_font
        pack forget .ftop.input.r1.b0
        SnazzyButton::setText .ftop.input.r1.b1 "Ok" 0.5        
    }
    
    proc actConfigHaveBundleId { title txtLbl1 txtLbl2} {
        global huge_font
        .ftop.display.l0 configure -text $title \
                -font $huge_font
        .ftop.display.l1 configure -text $txtLbl1 \
                -font $huge_font
        .ftop.display.l2 configure -text $txtLbl2 \
                -font $huge_font
    }

    proc actResetSuccessfully {title okBtn} {

        global huge_font
        .ftop.display.l0 configure -text $title -font $huge_font
        SnazzyButton::setImage .ftop.input.r1.b1 btnBlueU btnBlueD 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $okBtn 0.5                
        pack .ftop.input.r1.b1 -side bottom -pady 5
    }

    proc actResetting {title} {

        global huge_font
        .ftop.display.l0 configure -text $title -font $huge_font
        pack forget .ftop.input.r1.b0
        pack forget .ftop.input.r1.b1

    }

    proc packSelectOperation {selectOperation exitBtn \
            operation1 operation2 operation3 operation4 operation5 \
            operation6 operation7 } {

        global huge_font color3

        # configure and pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        if {$operation1 != "!"} {
          SnazzyButton::setText .ftop.input.r1.b0 $operation1 0.5
          pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        }
        
        if {$operation3 != "!"} {
          SnazzyButton::setText .ftop.input.r1.b2 $operation3 0.5
          pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        }
        
        if {$operation2 != "!"} {
          SnazzyButton::setText .ftop.input.r1.b1 $operation2 0.5
          pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        }

        if {$operation4 != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $operation4 0.5
          pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        }

        if {$operation5 != "!"} {
          SnazzyButton::setText .ftop.input.r2.b5 $operation5 0.5
          pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        }
        
        if {$operation6 != "!"} {
          SnazzyButton::setText .ftop.input.r2.b6 $operation6 0.5
          pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
        }
        
        if {$operation7 != "!"} {
          SnazzyButton::setText .ftop.input.r2.b7 $operation7 0.5
          pack .ftop.input.r2.b7 -side right -padx 5 -pady 5
        }
        
        .ftop.display.l0 configure -text $selectOperation -font $huge_font

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se
        pack .ftop.display.l0 -side top -pady 5

    }

    proc packSelectUserLevel {selectUserLevel exitBtn driverBtn \
            supervisorBtn} {

        global huge_font color3

        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text

        SnazzyButton::setText .ftop.input.r1.b0 $driverBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $supervisorBtn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $selectUserLevel -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packChangeRadioConfig {changeRadioConfig returnBtn changeBsTypeBtn \
            changeRadioChannelBtn} {

        global huge_font color3

        # pack the exit button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text

        SnazzyButton::setText .ftop.input.r1.b1 $changeRadioChannelBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        if {$changeBsTypeBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b0 $changeBsTypeBtn 0.5
          pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        }
        
        pack .ftop.input.r1 -side bottom -anchor se

        .ftop.display.l0 configure -text $changeRadioConfig -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packSystemInternals {systemInternalsLbl returnBtn resetRMSAMBtn \
         modifyDatabaseBtn databaseCompareBtn rmCodeUploadBtn samDiagMenuBtn \
         rmDiagMenuBtn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $modifyDatabaseBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $databaseCompareBtn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        if {$samDiagMenuBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b2 $samDiagMenuBtn 0.5
          pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        }
        if {$rmDiagMenuBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b3 $rmDiagMenuBtn 0.5
          pack .ftop.input.r1.b3 -side right -padx 5 -pady 5
        }
        if {$rmCodeUploadBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $rmCodeUploadBtn 0.5
          pack .ftop.input.r2 -side bottom -anchor se
          pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        }
        if {$resetRMSAMBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b5 $resetRMSAMBtn 0.5
          pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        }

        .ftop.display.l0 configure -text $systemInternalsLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packCalibDeereTrack {calibDeereTrackLbl returnBtn \
            step1Btn step2Btn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $step2Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $step1Btn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $calibDeereTrackLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packCalibWheeled {calibWheeledLbl returnBtn \
            step1Btn step2Btn step3Btn step4Btn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $step4Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $step3Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $step2Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b3 $step1Btn 0.5                
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b3 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $calibWheeledLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packCalibGantry {calibGantryLbl returnBtn \
            step1Btn step2Btn step3Btn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        SnazzyButton::setText .ftop.input.r1.b1 $step3Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $step2Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b3 $step1Btn 0.5                
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b3 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $calibGantryLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packCalibMT {calibMTLbl returnBtn steeringCalibBtn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $steeringCalibBtn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $calibMTLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packCalibCattrack {calibCattrackLbl returnBtn \
            step1Btn step2Btn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $step2Btn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $step1Btn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $calibCattrackLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }
    
    proc packCalibCamecoHarv {calibCamecoHarvLbl returnBtn steeringCalibBtn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $steeringCalibBtn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $calibCamecoHarvLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packSelectAutoManualBase { titleLbl 
    exitBtn autoBtn manualBtn skipBtn } {

        global huge_font big_font color3

        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw
        if {$skipBtn != "!"} {
            SnazzyButton::setText .ftop.input.cancel $skipBtn 0.5        
            pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        }
        # configure and pack buttons and text

        SnazzyButton::setText .ftop.input.r1.b0 $autoBtn 0.5        

        SnazzyButton::setText .ftop.input.r1.b1 $manualBtn 0.5
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $titleLbl -font $huge_font
        pack .ftop.display.l0 -side top -pady 20
    }


    proc packManualBaseSelect {exitBtn selLbl selBtn addBtn delBtn editBtn} {

        global huge_font big_font color3
        
        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2        
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # Pack the text
        .ftop.display.l0 configure -text $selLbl \
                -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        # Pack the list box
        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        # configure and pack buttons
        SnazzyButton::setText .ftop.input.r1.b0 $selBtn 0.5        
        SnazzyButton::setText .ftop.input.r1.b1 $addBtn 0.5
        SnazzyButton::setText .ftop.input.r2.b4 $delBtn 0.5
        SnazzyButton::setText .ftop.input.r2.b5 $editBtn 0.5

        pack .ftop.input.r2 -side bottom -fill x -anchor s
        pack .ftop.input.r1 -side bottom -fill both -expand yes -anchor s

        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5 -anchor s
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5 -anchor s
        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

    }
    
    
    proc packWaitForBase {ligGreen conChannel btypeBtn exitBtn reproBtn \
                          skipBtn} {

        global huge_font big_font color3 colorMedium

        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2        
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # Configure and pack the text
        .ftop.display.l0 configure -text $ligGreen -font $huge_font
        pack .ftop.display.l0 -side top -pady 10

        .ftop.display.l1 configure -text $conChannel -font $big_font
        pack .ftop.display.l1 -side top -pady 5

        # configure and pack buttons
        if {$skipBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b0 $skipBtn 0.5        
            pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        }
        
        if {$reproBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b1 $reproBtn 0.5        
            pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        }

        if {$btypeBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b2 $btypeBtn 0.5        
            pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        }

        pack .ftop.input.r1 -side bottom -anchor se

    }

    
    proc packA5WaitForBase {ligGreen bsType modType modFreq btypeBtn exitBtn \
                            reproBtn skipBtn} {
        global huge_font big_font color3 colorMedium

        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2        
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # Configure and pack the text
        .ftop.display.l0 configure -text $ligGreen -font $huge_font
        pack .ftop.display.l0 -side top -pady 10

        .ftop.display.l1 configure -text $bsType -font $big_font
        pack .ftop.display.l1 -side top -pady 5

        .ftop.display.l2 configure -text $modType -font $big_font
        pack .ftop.display.l2 -side top -pady 5

        .ftop.display.l3 configure -text $modFreq -font $big_font
        pack .ftop.display.l3 -side top -pady 5

        # configure and pack buttons
        if {$skipBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b0 $skipBtn 0.5        
            pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        }
        
        if {$reproBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b1 $reproBtn 0.5        
            pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        }

        if {$btypeBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b2 $btypeBtn 0.5        
            pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        }

        pack .ftop.input.r1 -side bottom -anchor se

    }
    
    
    proc packAutoBaseSelect {selBase selBaseBtn exitBtn} {

        global huge_font big_font color3

        # spacer
        frame .ftop.input.spacer -height 220 -width 0
        pack .ftop.input.spacer -side left

        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2        
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # Pack the text
        .ftop.display.l0 configure -text $selBase -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        # Pack the list box
        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        # configure and pack buttons
        
        SnazzyButton::setText .ftop.input.r1.b0 $selBaseBtn 0.5
        pack .ftop.input.r1 -side bottom -fill both -expand yes
        pack .ftop.input.r1.b0 -side left -anchor nw -padx 5 -pady 5

    }


    proc packWaitForGreens {waitGreenLbl exitBtn } {

        global colorMedium
        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2        
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw
        
        .ftop.display.l0 configure -text $waitGreenLbl
        pack .ftop.display.l0 -side top -pady 20

    }
    

    proc packLockLastKnown {exitBtn cancelInitBtn noMoveLbl} {

        global huge_font color3

        # pack the exit button
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2        
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        SnazzyButton::setText .ftop.input.r1.b0 $cancelInitBtn 0.5        
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        .ftop.display.l0 configure -text $noMoveLbl -font $huge_font

        pack .ftop.display.l0 -side top -pady 20

    }

    proc packMainMenu {exitBtn mainText begBtn initBtn toolsMenuBtn \
      settingsMenuBtn systemMenuBtn resumeBtn isReady} {

        global huge_font colorGood colorMedium color3 Screen::wasReady

        SnazzyButton::setImage .ftop.input.exit \
                btnExitRedU btnExitRedD 0.5
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
        .ftop.display.l0 configure -text $mainText -font $huge_font

        SnazzyButton::setText .ftop.input.r1.b0 $begBtn 0.5
        SnazzyButton::setImage .ftop.input.r1.b0 btnGreenU btnGreenD 0.5        
        SnazzyButton::setText .ftop.input.r1.b8 $initBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $toolsMenuBtn 0.5
	SnazzyButton::setText .ftop.input.r1.b1 $settingsMenuBtn 0.5                

        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw
        if {$isReady == 1} {
            pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        } else {
            pack .ftop.input.r1.b8 -side right -padx 5 -pady 5
        }
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        if { $systemMenuBtn != "!" } {
	    SnazzyButton::setText .ftop.input.r1.b3 $systemMenuBtn 0.5
	    pack .ftop.input.r1.b3 -side right -padx 5 -pady 5
	}
        pack .ftop.input.r1 -side bottom -anchor se
        
        if {$resumeBtn != "!"} {
           SnazzyButton::setText .ftop.input.r2.b6 $resumeBtn 0.5               
           pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
	}
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5

        set Screen::wasReady $isReady
    }

    
    proc packDataLogging {returnBtn dataloggingText} {
        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        .ftop.display.l0 configure -text $dataloggingText -font $huge_font

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        pack .ftop.input.r1 -side bottom -anchor se
        
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packInitSensors {mainLbl returnBtn \
            positionBtn headingBtn steeringBtn \
            isteerSteerBtn isteerAttBtn} {

        global huge_font

        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        .ftop.display.l0 configure -text $mainLbl -font $huge_font
        SnazzyButton::setText .ftop.input.r1.b0 $steeringBtn 0.5        
        SnazzyButton::setText .ftop.input.r1.b1 $headingBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $positionBtn 0.5
        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        if {$isteerSteerBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $isteerSteerBtn 0.5
          pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        }
        if {$isteerAttBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b6 $isteerAttBtn 0.5
          pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
        }
        pack .ftop.input.r2 -side bottom -anchor se
        
        pack .ftop.display.l0 -side top -pady 5

    }
    
    proc actToggleAccuracyMode {toggleBtn} {
        SnazzyButton::setText .ftop.input.r2.b7 $toggleBtn 0.5        
    }

    proc packChangeConfiguration { returnBtn chooseLbl changeTractorBtn \
			changeRadioBtn changeImplBtn configNmeaBtn\
			changeUserLevelBtn lowAccBtn moreBtn waasConfigBtn} {
        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $chooseLbl \
                -font $huge_font

        SnazzyButton::setImage .ftop.input.r1.b0 btnKhakiU btnKhakiD 0.5
        SnazzyButton::setText .ftop.input.r1.b0 $moreBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b1 $changeUserLevelBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b2 $changeImplBtn 0.5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
       
        if {$waasConfigBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b3 $waasConfigBtn 0.5
          pack .ftop.input.r1.b3 -side right -padx 5 -pady 2
        }
        
        SnazzyButton::setText .ftop.input.r2.b4 $configNmeaBtn 0.5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r2.b5 $changeRadioBtn 0.5
        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        
        SnazzyButton::setText .ftop.input.r2.b6 $changeTractorBtn 0.5         
        pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
        
        if {$lowAccBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b7 $lowAccBtn 0.5         
          pack .ftop.input.r2.b7 -side right -padx 5 -pady 5
        }

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packChangeConfigurationMore { returnBtn chooseLbl \
	changeLangBtn changeGridBtn changeTimeZoneBtn configUserPortBtn \
	setDefaultUnitsBtn changeSamBtn configOmniStarBtn} {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $chooseLbl \
                -font $huge_font

        SnazzyButton::setText .ftop.input.r1.b0 $changeLangBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b1 $changeGridBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        if {$changeTimeZoneBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b2 $changeTimeZoneBtn 0.5
          pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
	    }

        if {$configUserPortBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $configUserPortBtn 0.5
          pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        }

        if {$setDefaultUnitsBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b5 $setDefaultUnitsBtn 0.5
          pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        }
        
        if {$changeSamBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b6 $changeSamBtn 0.5         
          pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
        }
        
        if {$configOmniStarBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b7 $configOmniStarBtn 0.5         
          pack .ftop.input.r2.b7 -side right -padx 5 -pady 5
        }

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packDriverChangeConfiguration { returnBtn chooseLbl \
	changeLangBtn changeUserLevelBtn changeGridBtn  \
	changeRadioBtn changeImplBtn waasConfigBtn} {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $chooseLbl \
                -font $huge_font

        SnazzyButton::setText .ftop.input.r1.b0 $changeLangBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b1 $changeUserLevelBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b2 $changeGridBtn 0.5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5

        if {$waasConfigBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b3 $waasConfigBtn 0.5
          pack .ftop.input.r1.b3 -side right -padx 5 -pady 2
        }
        
        if {$changeRadioBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $changeRadioBtn 0.5
          pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        }

        if {$changeImplBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b5 $changeImplBtn 0.5
          pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        }
        
        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packToolsMenu {returnBtn chooseLbl dataLoggingBtn implSteeringBtn examSteeringBtn\
            examineGPSBtn satvuBtn measBtn databaseCompareBtn \
	    dataSyncBtn} {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $chooseLbl -font $huge_font

        SnazzyButton::setText .ftop.input.r1.b1 $measBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b3 $satvuBtn 0.5         
        pack .ftop.input.r1.b3 -side right -padx 5 -pady 5

        if {$databaseCompareBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b2 $databaseCompareBtn 0.5         
          pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        }

       if {$examSteeringBtn != "!"} {
        SnazzyButton::setText .ftop.input.r1.b8b $examSteeringBtn 0.5
        pack .ftop.input.r1.b8b -side right -padx 5 -pady 5
       }

        SnazzyButton::setText .ftop.input.r2.b4 $examineGPSBtn 0.5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

        if {$dataLoggingBtn != "!"} {
            SnazzyButton::setText .ftop.input.r2.b5 $dataLoggingBtn 0.5
            pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        }

	SnazzyButton::setText .ftop.input.r2.b6 $dataSyncBtn 0.5         
        pack .ftop.input.r2.b6 -side right -padx 5 -pady 5

        if {$implSteeringBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b7 $implSteeringBtn 0.5
          pack .ftop.input.r2.b7 -side right -padx 5 -pady 2
        }

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5

    }

    proc packServiceMenu {returnBtn sysLbl moreBtn  \
                          examAttBtn examPosBtn controllerTuningBtn \
                          calibrationBtn adjustleverarmBtn \
	                      changetractorBtn implChangeBtn} {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $sysLbl -font $huge_font
        
        SnazzyButton::setImage .ftop.input.r1.b0 btnKhakiU btnKhakiD 0.5
        SnazzyButton::setText .ftop.input.r1.b0 $moreBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b1 $examPosBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b2 $examAttBtn 0.5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b3 $implChangeBtn 0.5
        pack .ftop.input.r1.b3 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r2.b4 $controllerTuningBtn 0.5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r2.b5 $calibrationBtn 0.5
        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r2.b6 $adjustleverarmBtn 0.5
        pack .ftop.input.r2.b6 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r2.b7 $changetractorBtn 0.5
        pack .ftop.input.r2.b7 -side right -padx 5 -pady 5

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
    }

    proc packServiceMenuMore {returnBtn sysLbl diagRMBtn diagSAMBtn \
                              pingVehBtn systemInternalsMenu \
                              delfeaturecodeBtn implTuningBtn \
                              rmFeatureCodeBtn } {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $sysLbl -font $huge_font
        
        SnazzyButton::setText .ftop.input.r1.b0 $systemInternalsMenu 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b1 $delfeaturecodeBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        if {$diagRMBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b2 $diagRMBtn 0.5
          pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        }

        if {$diagSAMBtn != "!"} {
          SnazzyButton::setText .ftop.input.r1.b3 $diagSAMBtn 0.5
          pack .ftop.input.r1.b3 -side right -padx 5 -pady 5
        }

        pack .ftop.input.r1 -side bottom -anchor se
        if {$pingVehBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $pingVehBtn 0.5
          pack .ftop.input.r2.b4 -side right -padx 5 -pady 2
        }
        
        if {$implTuningBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b5 $implTuningBtn 0.5
          pack .ftop.input.r2.b5 -side right -padx 5 -pady 2
        }
        
        if {$rmFeatureCodeBtn != "!"} {
          SnazzyButton::setText .ftop.input.r2.b7 $rmFeatureCodeBtn 0.5
          pack .ftop.input.r2.b7 -side right -padx 5 -pady 2
        }

        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
    }

  
    proc packImplementSteeringWarning { title warningText riskStatement furtherStatement acceptBtn rejectBtn} {

        global huge_font color3
        global big_font
        pack forget .navDisplay
        pack forget .configDisplay

        # spacer
        #frame .ftop.display.spacer -height 220 -width 0
        #pack .ftop.display.spacer -side left

        .ftop.display.l0 configure -text $title -font $huge_font
        .ftop.display.l1 configure -text $warningText  -font $huge_font -foreground red
        .ftop.display.l2 configure -text "  "  -font $huge_font
        .ftop.display.l3 configure -text $riskStatement -font $huge_font
        .ftop.display.l4 configure -text "  "  -font $huge_font
        .ftop.display.l5 configure -text $furtherStatement -font $big_font -justify left

	# Accept button
	SnazzyButton::setText .ftop.input.r1.bA $acceptBtn 0.2
	pack .ftop.input.r1.bA -side right -padx 5 -pady 5

        #Reject button
	SnazzyButton::setText .ftop.input.r1.bR $rejectBtn 0.25
	pack .ftop.input.r1.bR -side right -padx 5 -pady 5

        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
        pack .ftop.display.l1 -side top -pady 5
        pack .ftop.display.l2 -side top -pady 5
        pack .ftop.display.l3 -side top -pady 5
        pack .ftop.display.l4 -side top -pady 5
        pack .ftop.display.l5 -side top 

     }

    proc packImplementSteeringWizardBase {returnBtn sysLbl NewImplBtn GPSAntLocBtn \
			      HwValidBtn CalInstBtn GuessRowBtn CurrentWizard} {

        global huge_font color3
        pack forget .navDisplay
        pack forget .configDisplay

        pack .wizardTopDisplay -in .ftop -side left -anchor nw -padx 10 -pady 10
        raise .wizardTopDisplay

        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $sysLbl -font $huge_font

        if {$CurrentWizard == 4} {
	    # blue button
	    SnazzyButton::setText .ftop.input.r1.bwb0 $CalInstBtn 0.5
	    pack .ftop.input.r1.bwb0 -side right -padx 5 -pady 5
        } elseif {$CurrentWizard > 4} {
	    # checked blue button
	    SnazzyButton::setText .ftop.input.r1.bwc0 $CalInstBtn 0.5
	    pack .ftop.input.r1.bwc0 -side right -padx 5 -pady 5
        } else {   
	    #gray button
	    SnazzyButton::setText .ftop.input.r1.bwg0 $CalInstBtn 0.5
	    pack .ftop.input.r1.bwg0 -side right -padx 5 -pady 5
        }

        if {$CurrentWizard == 3} {
	    # blue button
	    SnazzyButton::setText .ftop.input.r1.bwb1 $HwValidBtn 0.5
	    pack .ftop.input.r1.bwb1 -side right -padx 5 -pady 5
        } elseif {$CurrentWizard > 3} {
	    # checked blue button
	    SnazzyButton::setText .ftop.input.r1.bwc1 $HwValidBtn 0.5
	    pack .ftop.input.r1.bwc1 -side right -padx 5 -pady 5
        } else {   
	    #gray button
	    SnazzyButton::setText .ftop.input.r1.bwg1 $HwValidBtn 0.5
	    pack .ftop.input.r1.bwg1 -side right -padx 5 -pady 5
        }

        if {$CurrentWizard == 2} {
	    # blue button    
      	    SnazzyButton::setText .ftop.input.r1.bwb2 $GPSAntLocBtn 0.5
	    pack .ftop.input.r1.bwb2 -side right -padx 5 -pady 5
        } elseif {$CurrentWizard > 2} {
	    # checked blue button
	    SnazzyButton::setText .ftop.input.r1.bwc2 $GPSAntLocBtn 0.5
	    pack .ftop.input.r1.bwc2 -side right -padx 5 -pady 5     
        } else {
	    # gray button
	    SnazzyButton::setText .ftop.input.r1.bwg2 $GPSAntLocBtn 0.5
	    pack .ftop.input.r1.bwg2 -side right -padx 5 -pady 5
        }

        if {$CurrentWizard == 1} {
	    # blue button
	    SnazzyButton::setText .ftop.input.r1.bwb3 $NewImplBtn 0.5
	    pack .ftop.input.r1.bwb3 -side right -padx 5 -pady 5
        } elseif {$CurrentWizard > 1} {
	    # checked blue button
	    SnazzyButton::setText .ftop.input.r1.bwc3 $NewImplBtn 0.5
	    pack .ftop.input.r1.bwc3 -side right -padx 5 -pady 5 
        }

        pack .ftop.input.r1 -side bottom -anchor se
        
        if {$CurrentWizard == 5} {
	    # blue button
	    SnazzyButton::setText .ftop.input.r2.bwb6 $GuessRowBtn 0.5
	    pack .ftop.input.r2.bwb6 -side right -padx 5 -pady 2
       } elseif {$CurrentWizard > 5} {
	    # checked blue button
	    SnazzyButton::setText .ftop.input.r2.bwc6 $GuessRowBtn 0.5
	    pack .ftop.input.r2.bwc6 -side right -padx 5 -pady 5  
        } else {
	    #gray button
	    SnazzyButton::setText .ftop.input.r2.bwg6 $GuessRowBtn 0.5
	    pack .ftop.input.r2.bwg6 -side right -padx 5 -pady 2
        }

        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
    }


    proc packCalibSelMenu {returnBtn sysLbl vehCalibBtn impDvaCalibBtn } {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $sysLbl -font $huge_font
        
        SnazzyButton::setText .ftop.input.r1.b0 $vehCalibBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b2 $impDvaCalibBtn 0.5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5

        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
    }

    proc actSelectImplementCalib {impCalibSelLbl ocCalibBtn \
                                  biasCalibBtn} {

        global huge_font color3
        
        pack forget .ftop.input.r1.b0
        pack forget .ftop.input.r1.b1

        .ftop.display.l0 configure -text $impCalibSelLbl -font $huge_font
        
        SnazzyButton::setText .ftop.input.r1.b2 $ocCalibBtn 0.5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r2.b4 $biasCalibBtn 0.5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r2 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
    }

    proc packSelSAMDevice {returnBtn titleLbl okBtn} {
        global huge_font big_font color3

        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $titleLbl -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        SnazzyButton::setText .ftop.input.r1.b0 $okBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side right -anchor se

        .ftop.input.lbox configure -width 35 -height 10 -font $big_font
        pack .ftop.input.sbar -side right -anchor s -fill y
        pack .ftop.input.lbox -side right -anchor s -fill y
    }

    proc packLeverArmSelMenu {returnBtn sysLbl vehLevArmBtn impLevArmBtn} {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        .ftop.display.l0 configure -text $sysLbl -font $huge_font
        
        SnazzyButton::setText .ftop.input.r1.b0 $vehLevArmBtn 0.5
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .ftop.input.r1.b1 $impLevArmBtn 0.5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5

        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
    }

    proc packRMDiagnostics { rmDiagnosticsLbl returnBtn rmAssertBtn \
                             rmWouldAssertBtn rmQ2AssertBtn } {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons and text
        
        SnazzyButton::setText .ftop.input.r1.b0 $rmAssertBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $rmWouldAssertBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $rmQ2AssertBtn 0.5

        pack .ftop.input.r1 -side bottom -anchor se
        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        
        .ftop.display.l0 configure -text $rmDiagnosticsLbl -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

    }

    proc packControllerTuning {titleLbl returnBtn steeringcontrolBtn \
            headingcontrolBtn lateralerrorBtn lineacquisitionBtn \
            responseratesliderBtn hardcoreBtn isteerBtn} {

        global huge_font color3
        
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        .ftop.display.l0 configure -text $titleLbl -font $huge_font

        SnazzyButton::setText .ftop.input.r1.b0 $steeringcontrolBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $headingcontrolBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $lateralerrorBtn 0.5        

        SnazzyButton::setText .ftop.input.r2.b4 $lineacquisitionBtn 0.5
        SnazzyButton::setText .ftop.input.r2.b5 $responseratesliderBtn 0.5                
        SnazzyButton::setText .ftop.input.r2.b6 $hardcoreBtn 0.5                

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        if {$isteerBtn != "!"} {
	    SnazzyButton::setText .ftop.input.r2.b7 $isteerBtn 0.5
	    pack .ftop.input.r2.b7 -side right -padx 5 -pady 5
	}

        pack .ftop.input.r2.b6 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b5 -side right -padx 5 -pady 5
        pack .ftop.input.r2.b4 -side right -padx 5 -pady 5
        pack .ftop.input.r2 -side bottom -anchor se
        
        pack .ftop.input.r1.b0 -side left -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side left -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side left -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se
        
        pack .ftop.display.l0 -side top -pady 5

    }
    
    proc packImplementSelect {returnBtn selLbl selBtn addBtn delBtn editBtn} {

        global huge_font big_font color3 color5

        # spacer
        frame .ftop.input.spacer -height 220 -width 0
        pack .ftop.input.spacer -side left

        # configure and pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # Pack the text
        .ftop.display.l0 configure -text $selLbl -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        # Pack the list box
        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        # configure and pack buttons
        SnazzyButton::setText .ftop.input.r1.b0 $selBtn 0.5        
        pack .ftop.input.r1.b0 -side left -anchor nw -padx 5 -pady 5

        if {$addBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b1 $addBtn 0.5         
            pack .ftop.input.r1.b1 -side left -anchor n -padx 5 -pady 5
        }
        
        if {$delBtn != "!"} { 
            SnazzyButton::setText .ftop.input.r2.b4 $delBtn 0.5        
            pack .ftop.input.r2.b4 -side left -padx 5 -pady 5
        }
        
        if {$editBtn != "!"} { 
            SnazzyButton::setText .ftop.input.r2.b5 $editBtn 0.5
            pack .ftop.input.r2.b5 -side left -padx 5 -pady 5
            pack .ftop.input.r2 -side bottom -fill x
        }

        pack .ftop.input.r1 -side bottom -fill both -expand yes

        
    }
    
    proc packTractorSelect {returnBtn selLbl selBtn addBtn delBtn copyBtn } {

        global huge_font big_font color3 color5

        # spacer
        frame .ftop.input.spacer -height 220 -width 0
        pack .ftop.input.spacer -side left

        # configure and pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # Pack the text
        .ftop.display.l0 configure -text $selLbl \
                -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        # Pack the list box
        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        # configure and pack buttons
        SnazzyButton::setText .ftop.input.r1.b0 $selBtn 0.5        
        pack .ftop.input.r1.b0 -side left -anchor s -padx 5 -pady 5

        if {$addBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b1 $addBtn 0.5         
            pack .ftop.input.r1.b1 -side left -anchor s -padx 5 -pady 5
        }
        
        if {$delBtn != "!"} { 
            SnazzyButton::setText .ftop.input.r2.b4 $delBtn 0.5
            pack .ftop.input.r2.b4 -side left -padx 5 -pady 5
            pack .ftop.input.r2 -side bottom -fill x
        }

        if {$copyBtn != "!"} { 
            SnazzyButton::setText .ftop.input.r2.b5 $copyBtn 0.5
            pack .ftop.input.r2.b5 -side left -padx 5 -pady 5
            pack .ftop.input.r2 -side bottom -fill x
        }

        pack .ftop.input.r1 -side bottom -fill both -expand yes
    }

    proc packFieldSelect {returnBtn selLbl selBtn addBtn delBtn editBtn} {

        global huge_font big_font color3 color5

        # spacer
        frame .ftop.input.spacer -height 220 -width 0
        pack .ftop.input.spacer -side left

        # configure and pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # Pack the text
        .ftop.display.l0 configure -text $selLbl \
                -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        # Pack the list box
        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        # configure and pack buttons
        SnazzyButton::setText .ftop.input.r1.b0 $selBtn 0.5        
        pack .ftop.input.r1.b0 -side left -anchor s -padx 5 -pady 5

        if {$addBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b1 $addBtn 0.5         
            pack .ftop.input.r1.b1 -side left -anchor s -padx 5 -pady 5
        }

        if {$delBtn != "!"} {
            SnazzyButton::setText .ftop.input.r2.b4 $delBtn 0.5
            pack .ftop.input.r2.b4 -side left -padx 5 -pady 5
        }
        
        if {$editBtn != "!"} {
            SnazzyButton::setText .ftop.input.r2.b5 $editBtn 0.5
            pack .ftop.input.r2.b5 -side left -padx 5 -pady 5
            pack .ftop.input.r2 -side bottom -fill x
        }

        pack .ftop.input.r1 -side bottom -fill both -expand yes

    }

    proc packJobSelect {returnBtn selLbl selBtn addBtn delBtn editBtn} {

        global huge_font big_font color3 color5

        # spacer
        frame .ftop.input.spacer -height 220 -width 0
        pack .ftop.input.spacer -side left

        # configure and pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # Pack the text
        .ftop.display.l0 configure -text $selLbl \
                -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

        # Pack the list box
        pack .ftop.input.lbox -side left -pady 5 -fill both
        pack .ftop.input.sbar -side left -pady 5 -fill y

        # configure and pack buttons
        SnazzyButton::setText .ftop.input.r1.b0 $selBtn 0.5        
        pack .ftop.input.r1.b0 -side left -anchor s -padx 5 -pady 5

        if {$addBtn != "!"} {
            SnazzyButton::setText .ftop.input.r1.b1 $addBtn 0.5         
            pack .ftop.input.r1.b1 -side left -anchor s -padx 5 -pady 5
        }

        if {$delBtn != "!"} {
            SnazzyButton::setText .ftop.input.r2.b4 $delBtn 0.5        
            pack .ftop.input.r2.b4 -side left -padx 5 -pady 5
        }
        
        if {$editBtn != "!"} {
            SnazzyButton::setText .ftop.input.r2.b5 $editBtn 0.5
            pack .ftop.input.r2.b5 -side left -padx 5 -pady 5
            pack .ftop.input.r2 -side bottom -fill x
        }

        pack .ftop.input.r1 -side bottom -fill both -expand yes

    }

    proc packFieldPoints {chooseLbl northLbl eastLbl cancelBtn pickBtn\
            finishedBtn cancelBoundaryBtn pointsLbl} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $chooseLbl -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 5
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 5
        .ftop.display.r2.l0 configure -text $pointsLbl -font $huge_font \
                -width 30
        .ftop.display.r2.e0 configure -font $big_font \
                -width 10 -relief sunken -borderwidth 2 -anchor w
        
        
        SnazzyButton::setText .ftop.input.r1.b0 $cancelBoundaryBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $finishedBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $pickBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left
        pack .ftop.display.r2 -side top -anchor w -padx 87
        pack .ftop.display.r2.l0 -side left 
        pack .ftop.display.r2.e0 -side left

    }

    proc packStraightStart {title northLbl eastLbl cancelBtn setBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        SnazzyButton::setText .ftop.input.r1.b2 $setBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packStraightEnd {title northLbl eastLbl cancelBtn \
            setRowHeadingBtn setEndPointBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        
        SnazzyButton::setText .ftop.input.r1.b0 $setEndPointBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $setRowHeadingBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packFanStart {title northLbl eastLbl cancelBtn setBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        SnazzyButton::setText .ftop.input.r1.b2 $setBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packFanEnd {title northLbl eastLbl cancelBtn \
            setRowHeadingBtn setEndPointBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        SnazzyButton::setText .ftop.input.r1.b0 $setEndPointBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $setRowHeadingBtn 0.5       

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        #pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packFanAdjustSpacing {title wideEnd narrowEnd nRows \
            incBtn decBtn doneBtn cancelBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5

        .ftop.display.l0 configure -text $title -font $huge_font
        .ftop.display.l1 configure -text $wideEnd -font $big_font
        .ftop.display.l2 configure -text $narrowEnd -font $big_font
        .ftop.display.l3 configure -text $nRows -font $big_font
        
        SnazzyButton::setText .ftop.input.r1.b0 $doneBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $decBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b2 $incBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 10
        pack .ftop.display.l1 -side top -pady 5
        pack .ftop.display.l2 -side top -pady 5
        pack .ftop.display.l3 -side top -pady 5

    }
    
    proc packBoxStart {title northLbl eastLbl cancelBtn setBtn} {

        global huge_font big_font colorGood color3 color0

        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5       
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7

        SnazzyButton::setText .ftop.input.r1.b2 $setBtn 0.5       

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packBoxEnd {title northLbl eastLbl cancelBtn \
            setRowHeadingBtn setEndPointBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        SnazzyButton::setText .ftop.input.r1.b0 $setEndPointBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $setRowHeadingBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packCircleStart {title northLbl eastLbl cancelBtn beginBtn} {

        global huge_font big_font colorGood color3 color0
        
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        SnazzyButton::setText .ftop.input.r1.b2 $beginBtn 0.5

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b2 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packCircleRecord {title northLbl eastLbl cancelBtn endBtn} {

        global huge_font big_font colorGood color3 color0

        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5       
        .ftop.display.l0 configure -text $title -font $huge_font

        .ftop.display.r1.l0 configure -text $northLbl -font $huge_font \
                -width 7
        .ftop.display.r1.l1 configure -text $eastLbl -font $huge_font \
                -width 7
        
        SnazzyButton::setText .ftop.input.r1.b0 $endBtn 0.5      

        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top
        pack .ftop.display.r1 -side top 
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r1.l1 -side left
        pack .ftop.display.r1.e1 -side left

    }
    
    proc packJobAddHeading {title northBtn eastBtn southBtn westBtn \
            currentBtn manualBtn returntomainBtn} {

        global huge_font big_font colorGood color3 color0

        SnazzyButton::setText .ftop.input.cancel $returntomainBtn 0.5
        .ftop.display.l0 configure -text $title -font $huge_font

        SnazzyButton::setText .ftop.input.headingselect.col1.b0 $northBtn 0.5
        SnazzyButton::setText .ftop.input.headingselect.col1.b1 $eastBtn 0.5
        SnazzyButton::setText .ftop.input.headingselect.col1.b2 $southBtn 0.5
        SnazzyButton::setText .ftop.input.headingselect.col1.b3 $westBtn 0.5
        SnazzyButton::setText .ftop.input.headingselect.col2.b4 $currentBtn 0.5
        if { $manualBtn != "!" } {
          SnazzyButton::setText .ftop.input.headingselect.col2.b5 $manualBtn 0.5
        }

        pack .ftop.input.cancel -side left -padx 20 -pady 3 -anchor sw

        pack .ftop.input.headingselect.col1.b0 -side top -padx 5
        pack .ftop.input.headingselect.col1.b1 -side top -padx 5
        pack .ftop.input.headingselect.col1.b2 -side top -padx 5
        pack .ftop.input.headingselect.col1.b3 -side top -padx 5
        pack .ftop.input.headingselect.col2.b4 -side top -padx 5
        if { $manualBtn != "!" } {
          pack .ftop.input.headingselect.col2.b5 -side right -padx 5
        }
        pack .ftop.input.headingselect.col1 -side left
        pack .ftop.input.headingselect.col2 -side right -anchor ne
        pack .ftop.input.headingselect -side right -padx 20
        
        pack .ftop.input.c -side right -padx 10

        pack .ftop.display.l0 -side top

    }
    

    proc packMeasureDistance {title distanceLbl maxDistLbl slopeLbl slopedir \
            pickFirstBtn toggleUnitsBtn returntomainBtn} {

        global huge_font big_font colorGood color3 color0
        
        .ftop.display.l0 configure -text $title -font $big_font

        .ftop.display.r1.l0 configure -text $distanceLbl -font $big_font \
                -width 20 -anchor e
        .ftop.display.r1.e0 configure -font $big_font \
                -width 20 -relief sunken -borderwidth 2 -anchor e
        .ftop.display.r2.l0 configure -text $maxDistLbl -font $big_font \
                -width 20 -anchor e
        .ftop.display.r2.e0 configure -font $big_font \
                -width 20 -relief sunken -borderwidth 2 -anchor e
        .ftop.display.r3.l0 configure -text $slopeLbl -font $big_font \
                -width 20 -anchor e
        .ftop.display.r3.e0 configure -font $big_font \
                -width 20 -relief sunken -borderwidth 2 -anchor e
        .ftop.display.r4.l0 configure -text $slopedir -font $big_font \
                -width 20 -anchor e
        .ftop.display.r4.e0 configure -font $big_font \
                -width 20 -relief sunken -borderwidth 2 -anchor e
        
        SnazzyButton::setText .ftop.input.cancel $returntomainBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        
        SnazzyButton::setText .ftop.input.r1.b0 $pickFirstBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b1 $toggleUnitsBtn 0.5

        pack .ftop.input.r1.b0 -side right -padx 5 -pady 5
        pack .ftop.input.r1.b1 -side right -padx 5 -pady 5
        pack .ftop.input.r1 -side bottom -anchor se

        pack .ftop.display.l0 -side top -pady 5
        pack .ftop.display.r1 -side top -pady 5
        pack .ftop.display.r1.l0 -side left 
        pack .ftop.display.r1.e0 -side left
        pack .ftop.display.r2 -side top -pady 5
        pack .ftop.display.r2.l0 -side left 
        pack .ftop.display.r2.e0 -side left
        pack .ftop.display.r3 -side top -pady 5
        pack .ftop.display.r3.l0 -side left 
        pack .ftop.display.r3.e0 -side left
        pack .ftop.display.r4 -side top -pady 5
        pack .ftop.display.r4.l0 -side left 
        pack .ftop.display.r4.e0 -side left

    }

    proc packCalibMenu {calibDeereTrackLbl returnBtn} {

        global huge_font color3

        # pack the cancel button
        SnazzyButton::setText .ftop.input.cancel $returnBtn 0.5        
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # configure and pack buttons rows
        pack .ftop.input.r2 -side bottom -anchor se
        pack .ftop.input.r1 -side bottom -anchor se

        .ftop.display.l0 configure -text $calibDeereTrackLbl -font $huge_font
        pack .ftop.display.l0 -side top -pady 5

    }
    
    proc packWaitMessage {messageLblText__} {

        global huge_font color3

        pack forget .navDisplay
        pack forget .configDisplay
         
        .ftop.display.l0 configure -text $messageLblText__ -font $huge_font
        pack .ftop.display.l0 -side top -pady 50

    }

    proc actDispUtTemp {tempLbl} {
        global big_font
    
        pack .ftop.display.l0 -side top -pady 0
        .ftop.display.l1 configure -text $tempLbl -font $big_font
        pack .ftop.display.l1 -side top -pady 0
    }

}
