##############################################################################
#
# vc/src/tcl/rmReceiver.tcl
#
# Roof Module Receiver Type Checking
#
# 20060221 RAA - created
#
# Copyright (c) 2006 Novariant Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames
    # components) 
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

    # Display Frame - displays up to 3 lines of text
    label .ftop.display.l0 -text " " -font $huge_font
    label .ftop.display.l1 -text " " -font $medium_font

    # Exit button
    SnazzyButton::create .ftop.input.exit btnExitKhakiU btnExitKhakiD 0.2 \
                         "beepOnce; guiExit"

    # Return to Previous button
    SnazzyButton::create .ftop.input.cancel btnKhakiU btnKhakiD 0.2 \
                         "beepOnce; post $DISP_BTN9_SIG 9"

    # OK button
    SnazzyButton::create .ftop.input.ok btnKhakiU btnKhakiD 0.2 \
                         "beepOnce; post $DISP_BTN0_SIG 0"

    # Continue button
    SnazzyButton::create .ftop.input.cont btnKhakiU btnKhakiD 0.2 \
                         "beepOnce; post $DISP_BTN1_SIG 1"

    # Pack the display and input frames
    pack .ftop.display.l0 -side top -pady 5 -fill both -expand yes
    pack .ftop.display.l1 -side top -pady 5 -fill both -expand yes
    pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw
    pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
    pack .ftop.input.ok -side left -padx 5 -pady 5 -anchor se

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { commLbl } {
        global big_font
        .ftop.display.l1 configure -text $commLbl -font $big_font
        .ftop.input.cancel configure -state disabled
        .ftop.input.ok configure -state disabled
        pack .ftop -fill both -expand yes
    }


    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

# Not Used
#    proc actDispInfoStrg { infoLbl } {
#         global big_font
#        .ftop.display.l1 configure -text $infoLbl -font $big_font
#    }

    proc actShowReturnBtn {} {
        pack forget .ftop.input.ok
        .ftop.input.cancel configure -state normal
        SnazzyButton::setText .ftop.input.cancel "Return to\nPrevious\nMenu" 0.5
    }

# Not used
#    proc actShowOkBtn {} {
#        pack forget .ftop.input.cancel
#        .ftop.input.ok configure -state normal
#        SnazzyButton::setText .ftop.input.ok "OK" 0.5
#    }

    proc actRmWarning {respLbl exitBtn contBtn} {
		global huge_font

        pack forget .ftop.input.cancel
        pack forget .ftop.input.ok

        .ftop.display.l1 configure -text $respLbl -font $huge_font
        SnazzyButton::setText .ftop.input.cont $contBtn 0.5
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
        pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw
        pack .ftop.input.cont -side right -padx 5 -pady 5 -anchor se
    }

    proc actRmError { errLbl actionLbl exitBtn } {
        global huge_font
        global big_font
	
        .ftop.display.l0 configure -text $errLbl -font $huge_font
        .ftop.display.l1 configure -text $actionLbl -font $big_font
        .ftop.input.exit configure -state normal
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
    }
}

