##############################################################################
#
# vc/src/tcl/satel.tcl
#
# Screen to show SATEL frequencies
#
# 20050513 SSJ - created
#
# Copyright (c) 2005 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Satel Frequency"

    frame .ftop.input
    
    frame .ftop.input.display

    # Display Frame - displays up to 3 lines of text at a time
    label .ftop.input.display.l0 -text "line 0"
    label .ftop.input.display.l1 -text "line 1"
    label .ftop.input.display.l2 -text "line 2"
    #label .ftop.input.display.l3 -text "line 3"
    #label .ftop.input.display.l4 -text "line 4"

	#frequecy list box
    frame .ftop.input.listfreqframe
    scrollbar .ftop.input.listfreqframe.sbar -orient vertical -width 30 \
            -command { .ftop.input.listfreqframe.lbox yview }
    listbox .ftop.input.listfreqframe.lbox -background white -font $huge_font\
            -yscrollcommand {.ftop.input.listfreqframe.sbar set} \
			-width 20 -height 15
    pack .ftop.input.listfreqframe.sbar -side right -fill y
    pack .ftop.input.listfreqframe.lbox -side right

    # Cancel frame
    frame .ftop.l1
    SnazzyButton::create .ftop.l1.cancel \
                 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;"
    pack .ftop.l1.cancel -side left

    # Set Frequency frame
    frame .ftop.r1
    SnazzyButton::create .ftop.r1.setfreq \
                 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;"
    pack .ftop.r1.setfreq -side right

    # Pack .ftop
    pack .ftop.title -side top -pady 10 -anchor n
    pack .ftop.l1 -side left -anchor sw -padx 5 -pady 5
    pack .ftop.r1 -side right -anchor se -padx 5 -pady 5
	pack .ftop.input.display.l0 -side top -anchor n
	pack .ftop.input.display.l1 -side top -anchor n
	pack .ftop.input.display.l2 -side top -anchor n
    pack .ftop.input.display -side top -fill both -expand yes -anchor n
    pack .ftop.input.listfreqframe -side top -fill both -expand yes
    pack .ftop.input -side bottom -padx 5 -pady 5 -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { titleLbl cancelBtn setfreqBtn cfLbl foffLbl fspaceLbl } {
		global medium_font

        .ftop.title configure -text $titleLbl
        .ftop.input.display.l0 configure -text $cfLbl -font $medium_font
        .ftop.input.display.l1 configure -text $foffLbl -font $medium_font
        .ftop.input.display.l2 configure -text $fspaceLbl -font $medium_font
        SnazzyButton::setText .ftop.l1.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.r1.setfreq $setfreqBtn 0.5
 
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actListboxInsert { item } {
        .ftop.input.listfreqframe.lbox insert end $item
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.input.listfreqframe.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.input.listfreqframe.lbox selection set $index
        .ftop.input.listfreqframe.lbox see $index
    }

    #bind .ftop.input.listfreqframe.lbox <ButtonPress-1> {
    #  beepOnce; post $DISP_BTN1_SIG 1;  
    #} 

    proc actListboxGetCurselection {} {
        if { [.ftop.input.listfreqframe.lbox index end] != 0} {
            set index [lindex [.ftop.input.listfreqframe.lbox curselection] 0]
            return [.ftop.input.listfreqframe.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }

    proc actListboxGetCurindex {} {
      if { [.ftop.input.listfreqframe.lbox index end] != 0} {
          return [lindex [.ftop.input.listfreqframe.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }

    proc actSettingSatelFrequency { pfLbl } {
		global big_font

		pack forget .ftop.input.display.l2

        .ftop.input.display.l0 configure -text $pfLbl -font $big_font
        .ftop.input.listfreqframe.lbox delete 0 end
        .ftop.l1.cancel configure -state disabled
        .ftop.r1.setfreq configure -state disabled
    }
    
	proc actUpdateTimer { tLbl } {
		global big_font

		.ftop.input.display.l1 configure -text $tLbl -font $big_font
	}
    
    proc actUnpackListBox {} {
      pack forget .ftop.input.listfreqframe.lbox
      pack forget .ftop.input.listfreqframe.sbar
      pack forget .ftop.l1.cancel
      pack forget .ftop.r1.setfreq
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
