##############################################################################
#
# vc/src/tcl/warning.tcl
#
# Indemnity warning screen,
#
# 20020724 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # (Screen has custom display and input frames
    # components) 
    #-------------------------------------------------------------------------
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side top -fill both -expand yes

    # Display Frame - displays up to 3 lines of text
    #-------------------------------------------------------------------------
    label .ftop.display.title -font $huge_font
    label .ftop.display.info -font $large_font
    frame .ftop.display.dateinfo
    frame .ftop.display.daysremaining
    label .ftop.display.dateinfo.timeout -font $huge_font
    label .ftop.display.dateinfo.date -font $huge_font
    label .ftop.display.daysremaining.txt -font $huge_font
    label .ftop.display.daysremaining.days -font $huge_font
    pack .ftop.display.dateinfo.timeout -side left -anchor w
    pack .ftop.display.dateinfo.date -side left -anchor w -expand yes -fill both
    pack .ftop.display.daysremaining.txt -side left -anchor w
    pack .ftop.display.daysremaining.days -side left -anchor w 
    
    # Divider between title and content
    #-------------------------------------------------------------------------
    label .ftop.display.divider -image imgDivider

    # Exit button
    #-------------------------------------------------------------------------
    SnazzyButton::create .ftop.input.exit btnExitKhakiU btnExitKhakiD 0.2 \
                         "beepOnce; guiExit"

    # Input frame 
    #-------------------------------------------------------------------------
    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.b0 btnAcceptU btnAcceptD 0.2 \
                         "beepOnce; post $DISP_BTN0_SIG 0"

    SnazzyButton::create .ftop.input.r1.b1 btnRejectU btnRejectD 0.25 \
                         "beepOnce; post $DISP_BTN1_SIG 1"

    # Pack the display and input frames
    #-------------------------------------------------------------------------
    pack .ftop.display.title -side top -pady 8 -fill x
    pack .ftop.display.divider -side top -pady 2 -fill x
    pack .ftop.display.info -side top -pady 5 -fill x
    pack .ftop.display.dateinfo -side top -pady 10
    pack .ftop.display.daysremaining -side top -pady 5
    pack .ftop.input.exit -side left -padx 0 -pady 2 -anchor sw
    pack .ftop.input.r1 -side bottom -anchor se
    pack .ftop.input.r1.b0 -side right -padx 0 -pady 2
    pack .ftop.input.r1.b1 -side right -padx 2 -pady 2

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {title info timeout date remainingtxt remaining exitBtn \
                   acceptBtn rejectBtn} {
        .ftop.display.title configure -text $title
        .ftop.display.info configure -text $info
        .ftop.display.dateinfo.timeout configure -text $timeout
        .ftop.display.dateinfo.date configure -text $date
        .ftop.display.daysremaining.txt configure -text $remainingtxt
        .ftop.display.daysremaining.days configure -text $remaining
        .ftop.input.r1.b0 configure -state disabled
        SnazzyButton::setText .ftop.input.exit $exitBtn 0.2
        SnazzyButton::setText .ftop.input.r1.b0 $acceptBtn 0.2
        SnazzyButton::setText .ftop.input.r1.b1 $rejectBtn 0.25
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    #-------------------------------------------------------------------------
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actDisplayTimeoutDate {timeout remaining} {
      .ftop.display.dateinfo.date configure -text $timeout 
      .ftop.display.daysremaining.days configure -text $remaining  
    }
    
    proc actDisplayInvalidTimeoutDate { reason } {
      pack forget .ftop.display.daysremaining
      pack forget .ftop.display.dateinfo.date
      .ftop.display.dateinfo.timeout configure -text $reason  
    }
    
    proc actEnableAcceptButton {} {
      .ftop.input.r1.b0 configure -state active  
    }
    
    proc actSoftwareTimeout {text} {
      pack forget .ftop.display.daysremaining.days
      .ftop.display.daysremaining.txt configure -text $text      
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------



    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
