##############################################################################
#
# vc/src/tcl/userinterrupterror.tcl
#
# User Interrupt Error Info Screen
#
# 20050212 QC - created
#
# Copyright (c) 2005 Novariant Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop -bg red

    # Define and pack the screen layout
    # (Screen has custom display and input frames
    # and uses .configDisplay, and .navDisplay components)
    frame .ftop.input
    frame .ftop.display
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

    # Display frame - displays up to 5 lines of text
    label .ftop.display.l0 -text "line 0"
    label .ftop.display.l1 -text "line 1" -font $big_font
    label .ftop.display.l2 -text "line 2" -font $big_font
    label .ftop.display.l3 -text "line 3" -font $big_font
    label .ftop.display.l4 -text "line 4" -font $big_font

    # Input frame 
    #   - Cancel button 
    SnazzyButton::create .ftop.input.cancel btnKhakiU btnKhakiD 0.5 \
                         "beepOnce; post $DISP_BTN9_SIG 9" "Cancel"
    SnazzyButton::create .ftop.input.continue btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN0_SIG 0" "Continue"
    SnazzyButton::create .ftop.input.ok btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN1_SIG 1" "ACK"

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
        eval $packProc__
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr
    proc actConfigureL1 { line1__ } {
        global big_font
        .ftop.display.l1 configure -text $line1__ -font $big_font
    }

    proc actConfigBg { color__ } {
        beepOnce;
        .ftop.input configure -bg $color__
        .ftop.display configure -bg $color__
        .ftop.display.l0 configure -bg $color__
        .ftop.display.l1 configure -bg $color__
    }

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    proc packUserInterruptError {title ackBtn} {

        global huge_font big_font
        SnazzyButton::setText .ftop.input.ok $ackBtn 0.5
        pack .ftop.input.ok -side bottom -pady 5
        .ftop.display.l0 configure -text "$title" -font $huge_font -pady 20
        pack .ftop.display.l0 -side top -pady 2
       
    }

}
