##############################################################################
#
# vc/src/tcl/waascpfset.tcl
#
# Screen to set waas cpf.
#
# 20050508 QC - created
#
# Copyright (c) 2005 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Space for title"

    # Input frame
    frame .ftop.input

    # Row 1
    frame .ftop.input.r1
    label .ftop.input.r1.l -text "Short Distances:" -font $big_font \
                -anchor e
    label .ftop.input.r1.e -text "2" -font $big_font \
                -width 16 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r1.l -side left -pady 5
    pack .ftop.input.r1.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r1.b btnBlueMU btnBlueMD 0.5 \
                "beepOnce; post $DISP_BTN1_SIG 0;" "Toggle"
    pack .ftop.input.r1.b -side right
             
    # Row 2
    frame .ftop.input.r2
    label .ftop.input.r2.l -text "Long Distances:" -font $big_font \
                                                   -width 16 -anchor e
    label .ftop.input.r2.e -text "134" -font $big_font \
                  -width 16 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r2.l -side left -pady 5 -anchor e -fill x -expand yes
    pack .ftop.input.r2.e -side left -padx 10 -pady 5 -anchor e
    SnazzyButton::create .ftop.input.r2.b btnBlueMU btnBlueMD 0.5 \
                  "beepOnce; post $DISP_BTN2_SIG 2;" "Enter\nPRN#"
    pack .ftop.input.r2.b -side right     
    
    # Row 3
    frame .ftop.input.r3
    label .ftop.input.r3.l -text "Areas:" -font $big_font -width 16 -anchor e
    label .ftop.input.r3.e -text "122" -font $big_font \
                  -width 16 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r3.l -side left -pady 5 -anchor e -fill x -expand yes
    pack .ftop.input.r3.e -side left -padx 10 -pady 5 -anchor e
    SnazzyButton::create .ftop.input.r3.b btnBlueMU btnBlueMD 0.5 \
                  "beepOnce; post $DISP_BTN3_SIG 3;" "Enter\nPRN#"
    pack .ftop.input.r3.b -side right  
    
    # Row 4: WAAS Convergence Bar
    frame .ftop.input.r4
    set barWidth 147
    set barHeight 20
    label .ftop.input.r4.label -text "WAAS Percent Converged:" -font $big_font \
                                                   -width 16 -anchor e
    label .ftop.input.r4.spacer -text "  " -font $big_font \
                                           -width 8 -anchor e
    canvas .ftop.input.r4.bar -background $color6 \
            -width $barWidth -height $barHeight -relief sunken -borderwidth 2
    incr barHeight        
    .ftop.input.r4.bar create rectangle 0 0 0 $barHeight \
            -outline black -fill $colorMedium -tags gauge
    .ftop.input.r4.bar create text [expr $barWidth/2] 4 \
            -font $small_font -anchor nw -text "0%" -tags value 
    pack .ftop.input.r4.spacer -side right -padx 8 
    pack .ftop.input.r4.bar -side right -padx 10 -anchor ne 
    pack .ftop.input.r4.label -side right -fill x -expand yes -anchor nw
    
    # Pack rows
    pack .ftop.input.r1 -side top -anchor w -fill x
    
    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To Previous Menu"
    SnazzyButton::create .ftop.input2.accept btnBlueU btnBlueD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;" "Accept"            
        
    pack .ftop.input2.cancel -side left -padx 5 -pady 5 -anchor sw
    pack .ftop.input2.accept -side right -padx 5 -pady 5 -anchor se

    # Pack .ftop
    pack .ftop.title -side top -pady 10 -fill both -expand yes
    pack .ftop.input -side top -pady 10 -pady 5
    pack .ftop.input2 -side bottom -anchor se -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {titleLbl numPRNLbl prn1Lbl prn2Lbl waasLbl\
                   toggleBtn changeBtn cancelBtn acceptBtn} {
        .ftop.title configure -text $titleLbl
        .ftop.input.r1.l configure -text $numPRNLbl
        .ftop.input.r2.l configure -text $prn1Lbl
        .ftop.input.r3.l configure -text $prn2Lbl
        .ftop.input.r4.label configure -text $waasLbl
        SnazzyButton::setText .ftop.input.r1.b $toggleBtn 0.5
        SnazzyButton::setText .ftop.input.r2.b $changeBtn 0.5
        SnazzyButton::setText .ftop.input.r3.b $changeBtn 0.5
        SnazzyButton::setText .ftop.input2.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.input2.accept $acceptBtn 0.5
        
        pack .ftop -fill both -expand yes
    }


    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actDisplayCurrentSettings {numPRN prn1 prn2} {
      
      if {$numPRN == "1"} {
        pack .ftop.input.r2 -side top -anchor w -fill x -pady 5
        pack .ftop.input.r4 -side top -anchor w -fill x -pady 5
      }
      if {$numPRN == "2"} {
        pack .ftop.input.r2 -side top -anchor w -fill x -pady 5
        pack .ftop.input.r3 -side top -anchor w -fill x -pady 5
        pack .ftop.input.r4 -side top -anchor w -fill x -pady 5
      }
      
      .ftop.input.r1.e configure -text $numPRN
      .ftop.input.r2.e configure -text $prn1
      .ftop.input.r3.e configure -text $prn2
    }
    
    proc actDisplayPRN {prn1 prn2} {
      .ftop.input.r2.e configure -text $prn1
      .ftop.input.r3.e configure -text $prn2
    }

    proc actDisplayNumWaasPRN {numPRN} {
      .ftop.input.r1.e configure -text $numPRN
      if {$numPRN == "0"} {
        pack forget .ftop.input.r2
        pack forget .ftop.input.r3
        pack forget .ftop.input.r4
      }
      if {$numPRN == "1"} {
        pack .ftop.input.r2 -side top -anchor w -fill x -pady 5
        pack .ftop.input.r4 -side top -anchor w -fill x -pady 5
      }
      if {$numPRN == "2"} {
        pack .ftop.input.r3 -side top -anchor w -fill x -pady 5
        pack .ftop.input.r4 -side top -anchor w -fill x -pady 5
      }
    }
    
    proc actPosPercent { percentComplete } {
      global colorGood
      .ftop.input.r4.bar itemconfigure gauge \
        -fill $colorGood
      .ftop.input.r4.bar itemconfigure value \
        -text "$percentComplete%"

      # MLE-040301: Tcl doing math!! Not allowed; fix this...
      .ftop.input.r4.bar coords gauge 1 1 \
        [expr 0.0100*$percentComplete*$Screen::barWidth] $Screen::barHeight
    }
    
    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
