##############################################################################
#
# sim.tcl
#
# Tcl/Tk script for trsim...
#
# 20020826 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################

# GUI initialization
proc guiInit {{isRealTime__ 1}} {

    # Set the main window geometry
    global screenWidth screenHeight
    set maxSize [wm maxsize .]      ;# get the max allowable window dimensions 

    if {$isRealTime__} {                  ;# Real time: fill the entire screen
        set screenWidth [expr [lindex $maxSize 0]+25]
        set screenHeight [expr [lindex $maxSize 1]+35]
        set offset "-2-20"
    } else {                 ;# Non real time: set a size similar to real time
        set screenWidth 500
        set screenHeight 550
        set offset "+500+200"
    }
    wm geometry . "${screenWidth}x${screenHeight}${offset}"
    wm resizable . 0 0                          ;# Don't allow window resizing

}

guiInit 0                                    ;# {MLE-020327: Fix this hack!!!}

# Colors and fonts
source colorsandfonts.tcl

# Canvas for the field
frame .ftop
pack .ftop -side top -fill both -expand yes

label .ftop.title -text "TRSIM Top View" -font $big_font
pack .ftop.title -side top -padx 5 -pady 5

frame .ftop.input
label .ftop.input.ppml -text "Pixels/Meter:" -font $medium_font
entry .ftop.input.ppme -state disabled -textvariable ppm -width 5
button .ftop.input.b1 -text "Reset" \
            -height 1 -width 6 \
            -background $color3 -activebackground $color3 \
            -command { reset; }
button .ftop.input.b2 -text "Zoom In" \
            -height 1 -width 6 \
            -background $color3 -activebackground $color3 \
            -command { zoomIn; }
button .ftop.input.b3 -text "Zoom Out" \
            -height 1 -width 6 \
            -background $color3 -activebackground $color3 \
            -command { zoomOut; }

pack .ftop.input.ppml -side left -padx 5 -pady 5
pack .ftop.input.ppme -side left -padx 5 -pady 5
pack .ftop.input.b1 -side left -padx 5 -pady 5
pack .ftop.input.b2 -side left -padx 5 -pady 5
pack .ftop.input.b3 -side left -padx 5 -pady 5
pack .ftop.input -side top

frame .ftop.disp

frame .ftop.disp.xruler
frame .ftop.disp.xruler.spacer -width 60 -height 20
pack propagate .ftop.disp.xruler.spacer 0
pack .ftop.disp.xruler.spacer -side left
label .ftop.disp.xruler.l -text "l" -font $small_font
label .ftop.disp.xruler.c -text "c" -font $small_font
label .ftop.disp.xruler.r -text "r" -font $small_font
pack .ftop.disp.xruler.l -side left -anchor w
pack .ftop.disp.xruler.c -side left -anchor center -fill x -expand yes
pack .ftop.disp.xruler.r -side right -anchor e

frame .ftop.disp.yruler
label .ftop.disp.yruler.t -text "t" -font $small_font
label .ftop.disp.yruler.c -text "c" -font $small_font
label .ftop.disp.yruler.b -text "b" -font $small_font
pack .ftop.disp.yruler.t -side top -anchor n
pack .ftop.disp.yruler.c -side top -anchor center -fill y -expand yes
pack .ftop.disp.yruler.b -side bottom -anchor s

set e 2000
set w 425
set h 425
set x0 0
set y0 0
set vw [expr int(round($w/50))]
set vh [expr int(round($h/50))]
set al [expr int(round($h/25))]
set ppm 1.0                                                ;# meters per pixel
set kk 1

canvas .ftop.disp.c -width $w -height $h -relief sunken \
    -borderwidth 2 -background goldenrod \
    -scrollregion "[expr -$e] [expr -$e] $e $e" \
    -confine 0
#    -xscrollcommand ".ftop.xs set" 
#    -yscrollcommand ".ftop.ys set"
#scrollbar .ftop.ys -command ".ftop.disp.c yview" 
#pack .ftop.ys -side left -fill y
#scrollbar .ftop.xs -orient horizontal -command ".ftop.disp.c xview"
#pack .ftop.xs -side bottom -fill x

pack .ftop.disp.xruler -side top -fill x -anchor s -expand yes
pack .ftop.disp.yruler -side left -fill y -anchor e -expand yes
pack .ftop.disp.c -side right -padx 5 -pady 5 -anchor se
pack .ftop.disp -side bottom -fill both -expand yes

.ftop.disp.c create polygon 15 50 75 50 75 35 80 35 70 20 45 10 20 20 10 35 15 35 \
        -outline white -width 2 -fill red
.ftop.disp.c create polygon 35 50 35 35 45 35 45 50 \
        -outline white -width 2 -fill brown

set base [.ftop.disp.c create oval \
        [expr $x0-4] [expr $y0-4] [expr $x0+4] [expr $y0+4] \
        -fill blue -outline black];
set vehicle [.ftop.disp.c create rectangle 0 0 $vw $vh \
        -fill $colorGood -outline black]
set vehicleDirn [.ftop.disp.c create line 0 0 0 $al \
        -fill $colorGood -width 2 -arrow last \
        -arrowshape {7 10 4}]

proc vehiclePos { north__ east__ yaw__ } {

    global vehicle vehicleDirn e w h vw vh al x0 y0 ppm medium_font kk

    set orgN 0.0         ;# -149.06
    set orgE 0.0         ;# 1162.10
    set north [expr ($north__ - $orgN)]
    set east [expr ($east__ - $orgE)]

    set pixX [expr $x0 + int(round($east*$ppm))]
    set pixY [expr $y0 - int(round($north*$ppm))]

    set xleft [expr ($pixX - $w/2 + $e)/(2.0*$e)]
    set ytop [expr ($pixY - $h/2 + $e)/(2.0*$e)]
    .ftop.disp.c xview moveto $xleft
    .ftop.disp.c yview moveto $ytop


    .ftop.disp.xruler.l configure -text \
        [expr round(($east__ - $w/2.0/$ppm)*100 + 0.5)/100.0]
    .ftop.disp.xruler.c configure -text [expr round($east__*100 + 0.5)/100.0]
    .ftop.disp.xruler.r configure -text \
        [expr round(($east__ + $w/2.0/$ppm)*100 + 0.5)/100.0]
    .ftop.disp.yruler.t configure -text \
        [expr round(($north__ + $h/2.0/$ppm)*100 + 0.5)/100.0]
    .ftop.disp.yruler.c configure -text [expr round($north__*100 + 0.5)/100.0]
    .ftop.disp.yruler.b configure -text \
        [expr round(($north__ - $h/2.0/$ppm)*100 + 0.5)/100.0]

    set kk [expr $kk-1]
    if {$kk == 0} {
        set kk 1
        .ftop.disp.c create text $pixX $pixY -text "." -font $medium_font
    }
    .ftop.disp.c coords $vehicle \
            [expr $pixX - $vw/2] \
            [expr $pixY - $vh/2] \
            [expr $pixX + $vw/2] \
            [expr $pixY + $vh/2]

    .ftop.disp.c coords $vehicleDirn \
            $pixX \
            $pixY \
            [expr $pixX + $al*sin($yaw__)] \
            [expr $pixY - $al*cos($yaw__)]
    
}


proc reset {} { 
    global ppm
    set ppm 1.0
}


proc zoomIn {} {
    global ppm
    set ppm [expr $ppm*2]
}


proc zoomOut {} { 
    global ppm
    #if {$ppm >= 2} {
        set ppm [expr $ppm/2]
    #}
}
