#!/bin/sh

# Restore script.
# There are lots of cases to deal with here.
# Independent variables:
# - UT Hardware version (Rev C, Rev A/B)
# - Currently installed OS (Rev C, Rev A/B)
# - Backup version (Rev C, Rev A/B, or no backup at all).
# 
# Logic Summary Table:
#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev B         Rev B         Not Supported
#        Rev B           Rev B         Rev C         FI C, Restore
#        Rev B           Rev B         None          Backup not found
#
#        Rev B           Rev C         Rev B         Not Supported
#        Rev B           Rev C         Rev C         Restore
#        Rev B           Rev C         None          Backup not found
#
#        Rev C           Rev C         Rev B         Backup not found
#        Rev C           Rev C         Rev C         Restore
#        Rev C           Rev C         None          Backup not found
#   


mount none /mnt/sandisk -o remount
mount none / -o remount

# jobComplete is a file that acts as a flag
# it is read by the user program
rm /mnt/sandisk/upgrade/apps/softwareupgrade/restoreComplete
rm /mnt/sandisk/upgrade/apps/softwareupgrade/restoreFailed
rm /mnt/sandisk/upgrade/apps/softwareupgrade/backupNotFound

cd /mnt/sandisk/upgrade/apps/softwareupgrade

##### STEP 1: Get all independent variables


# Get UT Version.
# Returns UT_TYPE set to REV_C, REV_B, or UNKNOWN

. ./utVersion.sh


# Bail out if not known version

if [ $UT_TYPE = UNKNOWN ]; then
   touch /mnt/sandisk/upgrade/apps/softwareupgrade/restoreFailed
   # change mount permissions?
   exit;
fi
   
# Check generation currently installed
# Newer generations have /sbin/xset, older do not.
# Returns OS_VER set to REV_C or REV_B.

. ./utOSver.sh
echo OS Version is $OS_VER


# Check for type of backup file
# Remove link file
if [ -e /mnt/sandisk/upgrade/backup/backup_RevC.tar ]; then
  BACKUP=REV_C;
else
  BACKUP=NONE;
fi


##### STEP 2: Determine type of action to take

echo UT Hardware: $UT_TYPE, OS Type: $OS_VER, Backup Type: $BACKUP

# This is grossly inefficient but brain dead simple.  I believe it
# is more important to have clean, maintainable code in this case.

#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev B         Rev B         Restore
if [ $UT_TYPE = REV_B ]; then
   if [ $OS_VER = REV_B ]; then
      if [ $BACKUP = REV_B ]; then
         ACTION=BACKUP_NOT_FOUND;	# Not Supported
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev B         Rev C         FI C, Restore
if [ $UT_TYPE = REV_B ]; then
   if [ $OS_VER = REV_B ]; then
      if [ $BACKUP = REV_C ]; then
         ACTION=FI_C_RESTORE;
      fi
   fi
fi


#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev B         None          Backup not found
if [ $UT_TYPE = REV_B ]; then
   if [ $OS_VER = REV_B ]; then
      if [ $BACKUP = NONE ]; then
         ACTION=BACKUP_NOT_FOUND;
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev C         Rev B         FI B, Restore
if [ $UT_TYPE = REV_B ]; then
   if [ $OS_VER = REV_C ]; then
      if [ $BACKUP = REV_B ]; then
         ACTION=BACKUP_NOT_FOUND;	# Not Supported
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev C         Rev C         Restore
if [ $UT_TYPE = REV_B ]; then
   if [ $OS_VER = REV_C ]; then
      if [ $BACKUP = REV_C ]; then
         ACTION=RESTORE;
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev B           Rev C         None          Backup not found
if [ $UT_TYPE = REV_B ]; then
   if [ $OS_VER = REV_C ]; then
      if [ $BACKUP = NONE ]; then
         ACTION=BACKUP_NOT_FOUND;
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev C           Rev C         Rev B         Backup not found
if [ $UT_TYPE = REV_C ]; then
   if [ $OS_VER = REV_C ]; then
      if [ $BACKUP = REV_B ]; then
         ACTION=BACKUP_NOT_FOUND;
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev C           Rev C         Rev C         Restore
if [ $UT_TYPE = REV_C ]; then
   if [ $OS_VER = REV_C ]; then
      if [ $BACKUP = REV_C ]; then
         ACTION=RESTORE;
      fi
   fi
fi

#    UT Hardware      UT Software    Backup Type     Action
#        Rev C           Rev C         None          Backup not found
if [ $UT_TYPE = REV_C ]; then
   if [ $OS_VER = REV_C ]; then
      if [ $BACKUP = NONE ]; then
         ACTION=BACKUP_NOT_FOUND;
      fi
   fi
fi


##### STEP 3: Take action depending on state of independent variables

# If no backup, then set flag and bail
if [ $ACTION = BACKUP_NOT_FOUND ]; then
  touch /mnt/sandisk/upgrade/apps/softwareupgrade/restoreFailed
  touch /mnt/sandisk/upgrade/apps/softwareupgrade/backupNotFound
  exit;
fi


# If Install Rev C, first install then restore
if [ $ACTION = FI_C_RESTORE ]; then
    rm /mnt/sandisk/upgrade/apps/softwareupgrade/installComplete
    rm /mnt/sandisk/upgrade/apps/softwareupgrade/installFailed
    cd /mnt/sandisk
    echo "About to install Rev C OS"
    sleep 1
    ./freshinstall.sh
    cd /mnt/sandisk/upgrade/apps/softwareupgrade
    if [ -e installFailed ]; then
       touch /mnt/sandisk/upgrade/apps/softwareupgrade/restoreFailed
       exit;
    else
       ACTION=RESTORE;
    fi
fi


# If Restore, then do it
if [ $ACTION = RESTORE ]; then
   mount none / -o remount
   mkdir -p /configuration/currdir0
   mount -t jffs2 /dev/mtdblock4 /configuration/currdir0

   mkdir  /ut
   mount -t jffs2 /dev/mtdblock3 /ut
   cd /

   tar -xf /mnt/sandisk/upgrade/backup/backup_RevC.tar 2> /tmp/tarout;

   # Sadly, failure of tar cannot be checked using $?.  We have to grep
   # the tar output for Error exit.
   ERROR=$(grep "Error exit" /tmp/tarout | cut -d " " -f 2)
   # Check for success of tar
   if [ $ERROR = Error ]; then
      touch /mnt/sandisk/upgrade/apps/softwareupgrade/restoreFailed;
   else 
      touch /mnt/sandisk/upgrade/apps/softwareupgrade/restoreComplete;
   fi

   umount /configuration/currdir0
   rm -rf /configuration/currdir0
   umount /ut
   rm -rf /ut;
   exit;
fi


