##############################################################################
#
# vc/src/tcl/globalsetup.tcl
#
# Global namespace setup script for the GUI Tk display
#
# Contains variables and procedures that persist throughout all screens
#
# 20020314 MLE and m_s - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################

# error recovery policy
proc bgerror {error} {
    global DISP_ERROR_SIG errorInfo
    post $DISP_ERROR_SIG $error $errorInfo
}

# GUI exit
proc guiExit {{status 0}} {
    global DISP_EXIT_SIG
    post $DISP_EXIT_SIG $status
}

proc guiWithdraw {} {
    wm withdraw .
}

# NOTE: globals tclPath and isUserDisplay are set from the C
#       before executing this script

# Set the main window attributes
if {$isUserDisplay} {            ;# User display used : fill the entire screen
    set screenWidth [winfo screenwidth .]
    set screenHeight [winfo screenheight .]
    set winWidth [expr $screenWidth + 0]
    set winHeight [expr $screenHeight + 0]
    set offset "+0+0"

    # Custom mouse cursor
    set myCursor [list @${tclPath}nocursor "black"]
    . configure -cursor $myCursor
} else {                       ;# No user display (we're running a simulation)
    set winWidth 650
    set winHeight 485
    set offset "+0+0"

    # Custom mouse cursor
    . configure -cursor hand2
}

wm geometry . "${winWidth}x${winHeight}${offset}"
wm resizable . 0 0                              ;# Don't allow window resizing

# Colors and fonts
source ${tclPath}colorsandfonts.tcl

# Global catch-all for deferred Tcl design decisions
source ${tclPath}tbd.tcl

# Reusable common objects
source ${tclPath}commonobjects.tcl
source ${tclPath}tractordisptemp.tcl

